@@ -1,6 +1,5 @@
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
  * Copyright by The HDF Group.                                               *
- * Copyright by the Board of Trustees of the University of Illinois.         *
  * All rights reserved.                                                      *
  *                                                                           *
  * This file is part of HDF5.  The full HDF5 copyright notice, including     *
@@ -11,11 +10,7 @@
  * help@hdfgroup.org.                                                        *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 
-#ifdef OLD_HEADER_FILENAME
-#include <iostream.h>
-#else
 #include <iostream>
-#endif
 #include <string>
 
 #include "H5Include.h"
@@ -24,10 +19,8 @@
 #include "H5DataSpace.h"
 
 namespace H5 {
-#ifndef H5_NO_STD
 using std::cerr;
 using std::endl;
-#endif // H5_NO_STD
 
 #ifndef DOXYGEN_SHOULD_SKIP_THIS
 // This DOXYGEN_SHOULD_SKIP_THIS block is a work-around approach to control
@@ -75,8 +68,7 @@ DataSpace::getConstant()
 void
 DataSpace::deleteConstants()
 {
-    if (ALL_ != 0)
-        delete ALL_;
+    delete ALL_;
 }
 
 //--------------------------------------------------------------------------
@@ -95,9 +87,8 @@ const DataSpace &DataSpace::ALL = *getConstant();
 ///\exception   H5::DataSpaceIException
 // Programmer   Binh-Minh Ribler - 2000
 //--------------------------------------------------------------------------
-DataSpace::DataSpace(H5S_class_t type) : IdComponent()
+DataSpace::DataSpace(H5S_class_t type) : IdComponent(), id{H5Screate(type)}
 {
-    id = H5Screate(type);
     if (id < 0) {
         throw DataSpaceIException("DataSpace constructor", "H5Screate failed");
     }
@@ -112,9 +103,9 @@ DataSpace::DataSpace(H5S_class_t type) : IdComponent()
 ///\exception   H5::DataSpaceIException
 // Programmer   Binh-Minh Ribler - 2000
 //--------------------------------------------------------------------------
-DataSpace::DataSpace(int rank, const hsize_t *dims, const hsize_t *maxdims) : IdComponent()
+DataSpace::DataSpace(int rank, const hsize_t *dims, const hsize_t *maxdims)
+    : IdComponent(), id{H5Screate_simple(rank, dims, maxdims)}
 {
-    id = H5Screate_simple(rank, dims, maxdims);
     if (id < 0) {
         throw DataSpaceIException("DataSpace constructor", "H5Screate_simple failed");
     }
@@ -135,7 +126,7 @@ DataSpace::DataSpace(const hid_t existing_id) : IdComponent(), id(existing_id)
 
 //--------------------------------------------------------------------------
 // Function:    DataSpace copy constructor
-///\brief       Copy constructor: makes a copy of the original DataSpace object.
+///\brief       Copy constructor: same HDF5 object as \a original
 ///\param       original - IN: DataSpace object to copy
 // Programmer   Binh-Minh Ribler - 2000
 //--------------------------------------------------------------------------
@@ -292,7 +283,6 @@ hssize_t
 DataSpace::getSimpleExtentNpoints() const
 {
     hssize_t num_elements = H5Sget_simple_extent_npoints(id);
-
     if (num_elements > -1)
         return (num_elements);
     else {
@@ -326,8 +316,6 @@ DataSpace::getSimpleExtentType() const
 ///\param       dest_space  - IN: Dataspace to copy from
 ///\exception   H5::DataSpaceIException
 // Programmer   Binh-Minh Ribler - 2000
-// Modification
-//              Replaced the version without const parameter - Apr, 2014
 //--------------------------------------------------------------------------
 void
 DataSpace::extentCopy(const DataSpace &dest_space) const
@@ -475,9 +463,8 @@ DataSpace::getSelectElemNpoints() const
 ///\param       buf - IN: List of element points selected
 ///\exception   H5::DataSpaceIException
 ///\par Description
-///             For more information, please refer to the C layer Reference
-///             Manual at:
-/// https://support.hdfgroup.org/HDF5/doc/RM/RM_H5S.html#Dataspace-SelectElemPointList
+///             For information, please refer to the C API
+///             H5Sget_select_elem_pointlist in the HDF5 C Reference Manual.
 // Programmer   Binh-Minh Ribler - 2000
 //--------------------------------------------------------------------------
 void
@@ -498,9 +485,8 @@ DataSpace::getSelectElemPointlist(hsize_t startpoint, hsize_t numpoints, hsize_t
 ///             the coordinates of the diagonally opposite corner
 ///\exception   H5::DataSpaceIException
 ///\par Description
-///             For more information, please refer to the C layer Reference
-///             Manual at:
-/// https://support.hdfgroup.org/HDF5/doc/RM/RM_H5S.html#Dataspace-SelectBounds
+///             For information, please refer to the H5Sget_select_bounds API in
+///             the HDF5 C Reference Manual.
 // Programmer   Binh-Minh Ribler - 2000
 //--------------------------------------------------------------------------
 void
@@ -523,9 +509,8 @@ DataSpace::getSelectBounds(hsize_t *start, hsize_t *end) const
 ///             specifying the coordinates of the elements being selected
 ///\exception   H5::DataSpaceIException
 ///\par Description
-///             For more information, please refer to the C layer Reference
-///             Manual at:
-/// https://support.hdfgroup.org/HDF5/doc/RM/RM_H5S.html#Dataspace-SelectElements
+///             For information, please refer to the H5Sselect_elements API in
+///             the HDF5 C Reference Manual.
 // Programmer   Binh-Minh Ribler - 2000
 //--------------------------------------------------------------------------
 void
@@ -602,9 +587,8 @@ DataSpace::selectValid() const
 ///\param       block - IN: Size of block in the hyperslab - default to \c NULL
 ///\exception   H5::DataSpaceIException
 ///\par Description
-///             For more information, please refer to the C layer Reference
-///             Manual at:
-/// https://support.hdfgroup.org/HDF5/doc/RM/RM_H5S.html#Dataspace-SelectHyperslab
+///             For information, please refer to the H5Sselect_hyperslab API in
+///             the HDF5 C Reference Manual.
 // Programmer   Binh-Minh Ribler - 2000
 //--------------------------------------------------------------------------
 void
@@ -644,7 +628,7 @@ DataSpace::getId() const
 ///\exception   H5::IdComponentException when the attempt to close the HDF5
 ///             object fails
 // Description:
-//              The underlaying reference counting in the C library ensures
+//              The underlying reference counting in the C library ensures
 //              that the current valid id of this object is properly closed.
 //              Then the object's id is reset to the new id.
 // Programmer   Binh-Minh Ribler - 2000
@@ -704,4 +688,5 @@ DataSpace::~DataSpace()
         cerr << "DataSpace::~DataSpace - " << close_error.getDetailMsg() << endl;
     }
 }
+
 } // namespace H5
