@@ -1,6 +1,5 @@
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
  * Copyright by The HDF Group.                                               *
- * Copyright by the Board of Trustees of the University of Illinois.         *
  * All rights reserved.                                                      *
  *                                                                           *
  * This file is part of HDF5.  The full HDF5 copyright notice, including     *
@@ -11,7 +10,6 @@
  * help@hdfgroup.org.                                                        *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 
-#include <cstring>
 #include <string>
 
 #include "H5Include.h"
@@ -323,12 +321,16 @@ DSetMemXferPropList::getDataTransform() const
 
     // If expression exists, calls C routine again to get it
     else if (exp_len > 0) {
+
+        // The actual size is the cast value + 1 for the terminal ASCII NUL
+        // (unfortunate in/out type sign mismatch)
+        size_t actual_exp_len = static_cast<size_t>(exp_len) + 1;
+
         // Temporary buffer for char* expression
-        char *exp_C = new char[exp_len + 1];
-        memset(exp_C, 0, exp_len + 1);
+        char *exp_C = new char[actual_exp_len]();
 
         // Used overloaded function
-        exp_len = getDataTransform(exp_C, exp_len + 1);
+        exp_len = getDataTransform(exp_C, actual_exp_len);
 
         // Convert the C expression to return
         expression = exp_C;
