@@ -1,6 +1,5 @@
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
  * Copyright by The HDF Group.                                               *
- * Copyright by the Board of Trustees of the University of Illinois.         *
  * All rights reserved.                                                      *
  *                                                                           *
  * This file is part of HDF5.  The full HDF5 copyright notice, including     *
@@ -25,7 +24,7 @@ const char Exception::DEFAULT_MSG[] = "No detailed information provided";
 ///\brief       Default constructor.
 // Programmer   Binh-Minh Ribler - 2000
 //--------------------------------------------------------------------------
-Exception::Exception() : detail_message(""), func_name("")
+Exception::Exception() : detail_message{""}, func_name{""}
 {
 }
 
@@ -44,7 +43,7 @@ Exception::Exception(const H5std_string &func, const H5std_string &message)
 
 //--------------------------------------------------------------------------
 // Function:    Exception copy constructor
-///\brief       Copy constructor: makes a copy of the original Exception object.
+///\brief       Copy constructor: same HDF5 object as \a original
 ///\param       orig - IN: Exception instance to copy
 // Programmer   Binh-Minh Ribler - 2000
 //--------------------------------------------------------------------------
@@ -73,9 +72,14 @@ Exception::getMajorString(hid_t err_major) const
     if (mesg_size < 0)
         throw IdComponentException("Exception::getMajorString", "H5Eget_msg failed");
 
+    // The actual message size is the cast value + 1 for the terminal ASCII NUL
+    // (unfortunate in/out type sign mismatch)
+    size_t actual_mesg_size = static_cast<size_t>(mesg_size) + 1;
+
     // Call H5Eget_msg again to get the actual message
-    char *mesg_C = new char[mesg_size + 1]; // temporary C-string for C API
-    mesg_size    = H5Eget_msg(err_major, NULL, mesg_C, mesg_size + 1);
+    char *mesg_C = new char[actual_mesg_size]; // temporary C-string for C API
+
+    mesg_size = H5Eget_msg(err_major, NULL, mesg_C, actual_mesg_size);
 
     // Check for failure again
     if (mesg_size < 0) {
@@ -110,9 +114,14 @@ Exception::getMinorString(hid_t err_minor) const
     if (mesg_size < 0)
         throw IdComponentException("Exception::getMinorString", "H5Eget_msg failed");
 
+    // The actual message size is the cast value + 1 for the terminal ASCII NUL
+    // (unfortunate in/out type sign mismatch)
+    size_t actual_mesg_size = static_cast<size_t>(mesg_size) + 1;
+
     // Call H5Eget_msg again to get the actual message
-    char *mesg_C = new char[mesg_size + 1]; // temporary C-string for C API
-    mesg_size    = H5Eget_msg(err_minor, NULL, mesg_C, mesg_size + 1);
+    char *mesg_C = new char[actual_mesg_size]; // temporary C-string for C API
+
+    mesg_size = H5Eget_msg(err_minor, NULL, mesg_C, actual_mesg_size);
 
     // Check for failure again
     if (mesg_size < 0) {
@@ -172,9 +181,9 @@ Exception::dontPrint()
 ///\brief       Retrieves the current settings for the automatic error
 ///             stack traversal function and its data.
 ///\param       func        - OUT: Current setting for the function to be
-///                                     called upon an error condition
+///                                called upon an error condition
 ///\param       client_data - OUT: Current setting for the data passed to
-///                                     the error function
+///                                the error function
 // Programmer   Binh-Minh Ribler - 2000
 //--------------------------------------------------------------------------
 void
@@ -309,7 +318,7 @@ Exception::getCFuncName() const
 ///\brief       Prints the error stack in a default manner.
 ///\param       stream    - IN: File pointer, default to stderr
 ///\param       err_stack - IN: Error stack ID, default to H5E_DEFAULT(0)
-// Programmer   Binh-Minh Ribler - Apr, 2014 (1.8.13)
+// Programmer   Binh-Minh Ribler - 2000
 //--------------------------------------------------------------------------
 void
 Exception::printErrorStack(FILE *stream, hid_t err_stack)
@@ -330,12 +339,12 @@ Exception::printErrorStack(FILE *stream, hid_t err_stack)
 //              This function can be removed in next major release.
 //              -BMR, 2014/04/24
 //              Removed from documentation. -BMR, 2016/03/23
+//              Removed from code. -BMR, 2017/08/11 1.8.20 and 1.10.2
 //--------------------------------------------------------------------------
-void
-Exception::printError(FILE *stream) const
-{
-    Exception::printErrorStack(stream, H5E_DEFAULT);
-}
+// void Exception::printError(FILE* stream) const
+//{
+//    Exception::printErrorStack(stream, H5E_DEFAULT);
+//}
 
 //--------------------------------------------------------------------------
 // Function:    Exception destructor
@@ -347,32 +356,32 @@ Exception::~Exception() throw()
 }
 
 //--------------------------------------------------------------------------
-// Subclass:    LocationException
-// Programmer   Binh-Minh Ribler - 2014
+// Subclass:    FileIException
+// Programmer   Binh-Minh Ribler - 2000
 //--------------------------------------------------------------------------
 //--------------------------------------------------------------------------
-// Function:    LocationException default constructor
+// Function:    FileIException default constructor
 ///\brief       Default constructor.
 //--------------------------------------------------------------------------
-LocationException::LocationException() : Exception()
+FileIException::FileIException() : Exception()
 {
 }
 //--------------------------------------------------------------------------
-// Function:    LocationException overloaded constructor
-///\brief       Creates a LocationException with the name of the function,
+// Function:    FileIException overloaded constructor
+///\brief       Creates a FileIException with the name of the function,
 ///             in which the failure occurs, and an optional detailed message.
 ///\param       func - IN: Name of the function where failure occurs
 ///\param       message   - IN: Message on the failure
 //--------------------------------------------------------------------------
-LocationException::LocationException(const H5std_string &func, const H5std_string &message)
+FileIException::FileIException(const H5std_string &func, const H5std_string &message)
     : Exception(func, message)
 {
 }
 //--------------------------------------------------------------------------
-// Function:    LocationException destructor
+// Function:    FileIException destructor
 ///\brief       Noop destructor.
 //--------------------------------------------------------------------------
-LocationException::~LocationException() throw()
+FileIException::~FileIException() throw()
 {
 }
 
@@ -384,7 +393,7 @@ LocationException::~LocationException() throw()
 // Function:    GroupIException default constructor
 ///\brief       Default constructor.
 //--------------------------------------------------------------------------
-GroupIException::GroupIException() : LocationException()
+GroupIException::GroupIException() : Exception()
 {
 }
 //--------------------------------------------------------------------------
@@ -395,7 +404,7 @@ GroupIException::GroupIException() : LocationException()
 ///\param       message   - IN: Message on the failure
 //--------------------------------------------------------------------------
 GroupIException::GroupIException(const H5std_string &func, const H5std_string &message)
-    : LocationException(func, message)
+    : Exception(func, message)
 {
 }
 //--------------------------------------------------------------------------
@@ -406,36 +415,6 @@ GroupIException::~GroupIException() throw()
 {
 }
 
-//--------------------------------------------------------------------------
-// Subclass:    FileIException
-// Programmer   Binh-Minh Ribler - 2000
-//--------------------------------------------------------------------------
-//--------------------------------------------------------------------------
-// Function:    FileIException default constructor
-///\brief       Default constructor.
-//--------------------------------------------------------------------------
-FileIException::FileIException() : GroupIException()
-{
-}
-//--------------------------------------------------------------------------
-// Function:    FileIException overloaded constructor
-///\brief       Creates a FileIException with the name of the function,
-///             in which the failure occurs, and an optional detailed message.
-///\param       func - IN: Name of the function where failure occurs
-///\param       message   - IN: Message on the failure
-//--------------------------------------------------------------------------
-FileIException::FileIException(const H5std_string &func, const H5std_string &message)
-    : GroupIException(func, message)
-{
-}
-//--------------------------------------------------------------------------
-// Function:    FileIException destructor
-///\brief       Noop destructor.
-//--------------------------------------------------------------------------
-FileIException::~FileIException() throw()
-{
-}
-
 //--------------------------------------------------------------------------
 // Subclass:    DataSpaceIException
 // Programmer   Binh-Minh Ribler - 2000
@@ -474,7 +453,7 @@ DataSpaceIException::~DataSpaceIException() throw()
 // Function:    DataTypeIException default constructor
 ///\brief       Default constructor.
 //--------------------------------------------------------------------------
-DataTypeIException::DataTypeIException() : LocationException()
+DataTypeIException::DataTypeIException() : Exception()
 {
 }
 //--------------------------------------------------------------------------
@@ -485,7 +464,7 @@ DataTypeIException::DataTypeIException() : LocationException()
 ///\param       message   - IN: Message on the failure
 //--------------------------------------------------------------------------
 DataTypeIException::DataTypeIException(const H5std_string &func, const H5std_string &message)
-    : LocationException(func, message)
+    : Exception(func, message)
 {
 }
 //--------------------------------------------------------------------------
@@ -496,6 +475,36 @@ DataTypeIException::~DataTypeIException() throw()
 {
 }
 
+//--------------------------------------------------------------------------
+// Subclass:    ObjHeaderIException
+// Programmer   Binh-Minh Ribler - 2000
+//--------------------------------------------------------------------------
+//--------------------------------------------------------------------------
+// Function:    ObjHeaderIException default constructor
+///\brief       Default constructor.
+//--------------------------------------------------------------------------
+ObjHeaderIException::ObjHeaderIException() : Exception()
+{
+}
+//--------------------------------------------------------------------------
+// Function:    ObjHeaderIException overloaded constructor
+///\brief       Creates an ObjHeaderIException with the name of the function,
+///             in which the failure occurs, and an optional detailed message.
+///\param       func - IN: Name of the function where failure occurs
+///\param       message   - IN: Message on the failure
+//--------------------------------------------------------------------------
+ObjHeaderIException::ObjHeaderIException(const H5std_string &func, const H5std_string &message)
+    : Exception(func, message)
+{
+}
+//--------------------------------------------------------------------------
+// Function:    ObjHeaderIException destructor
+///\brief       Noop destructor.
+//--------------------------------------------------------------------------
+ObjHeaderIException::~ObjHeaderIException() throw()
+{
+}
+
 //--------------------------------------------------------------------------
 // Subclass:    PropListIException
 // Programmer   Binh-Minh Ribler - 2000
@@ -534,7 +543,7 @@ PropListIException::~PropListIException() throw()
 // Function:    DataSetIException default constructor
 ///\brief       Default constructor.
 //--------------------------------------------------------------------------
-DataSetIException::DataSetIException() : LocationException()
+DataSetIException::DataSetIException() : Exception()
 {
 }
 //--------------------------------------------------------------------------
@@ -545,7 +554,7 @@ DataSetIException::DataSetIException() : LocationException()
 ///\param       message   - IN: Message on the failure
 //--------------------------------------------------------------------------
 DataSetIException::DataSetIException(const H5std_string &func, const H5std_string &message)
-    : LocationException(func, message)
+    : Exception(func, message)
 {
 }
 //--------------------------------------------------------------------------
@@ -564,7 +573,7 @@ DataSetIException::~DataSetIException() throw()
 // Function:    AttributeIException default constructor
 ///\brief       Default constructor.
 //--------------------------------------------------------------------------
-AttributeIException::AttributeIException() : LocationException()
+AttributeIException::AttributeIException() : Exception()
 {
 }
 //--------------------------------------------------------------------------
@@ -575,7 +584,7 @@ AttributeIException::AttributeIException() : LocationException()
 ///\param       message   - IN: Message on the failure
 //--------------------------------------------------------------------------
 AttributeIException::AttributeIException(const H5std_string &func, const H5std_string &message)
-    : LocationException(func, message)
+    : Exception(func, message)
 {
 }
 //--------------------------------------------------------------------------
@@ -646,6 +655,36 @@ LibraryIException::~LibraryIException() throw()
 {
 }
 
+//--------------------------------------------------------------------------
+// Subclass:    LocationException
+// Programmer   Binh-Minh Ribler - 2014
+//--------------------------------------------------------------------------
+//--------------------------------------------------------------------------
+// Function:    LocationException default constructor
+///\brief       Default constructor.
+//--------------------------------------------------------------------------
+LocationException::LocationException() : Exception()
+{
+}
+//--------------------------------------------------------------------------
+// Function:    LocationException overloaded constructor
+///\brief       Creates a LocationException with the name of the function,
+///             in which the failure occurs, and an optional detailed message.
+///\param       func - IN: Name of the function where failure occurs
+///\param       message   - IN: Message on the failure
+//--------------------------------------------------------------------------
+LocationException::LocationException(const H5std_string &func, const H5std_string &message)
+    : Exception(func, message)
+{
+}
+//--------------------------------------------------------------------------
+// Function:    LocationException destructor
+///\brief       Noop destructor.
+//--------------------------------------------------------------------------
+LocationException::~LocationException() throw()
+{
+}
+
 //--------------------------------------------------------------------------
 // Subclass:    IdComponentException
 // Programmer   Binh-Minh Ribler - 2000
@@ -675,4 +714,5 @@ IdComponentException::IdComponentException(const H5std_string &func, const H5std
 IdComponentException::~IdComponentException() throw()
 {
 }
+
 } // namespace H5
