@@ -20,111 +20,6 @@
 
 #include "H5f90.h"
 
-/****if* H5Df/h5dcreate_c
- * NAME
- *  h5dcreate_c
- * PURPOSE
- *  Call H5Dcreate2 to create a dataset
- * INPUTS
- *  loc_id   - file or group identifier
- *  name     - name of the dataset
- *  namelen  - name length
- *  type_id  - datatype identifier
- *  space_id - dataspace identifier
- *  crt_pr   - identifier of creation property list
- * OUTPUTS
- *  dset_id  - dataset identifier
- * RETURNS
- *  0 on success, -1 on failure
- * AUTHOR
- *  Elena Pourmal
- *  Wednesday, August 4, 1999
- * HISTORY
- *   - Added optional parameters introduced in version 1.8
- *     February, 2008
- * SOURCE
- */
-int_f
-h5dcreate_c(hid_t_f *loc_id, _fcd name, int_f *namelen, hid_t_f *type_id, hid_t_f *space_id, hid_t_f *lcpl_id,
-            hid_t_f *dcpl_id, hid_t_f *dapl_id, hid_t_f *dset_id)
-/******/
-{
-    char *c_name = NULL;
-    hid_t c_dset_id;
-    int   ret_value = -1;
-
-    /*
-     * Convert FORTRAN name to C name
-     */
-    if (NULL == (c_name = (char *)HD5f2cstring(name, (size_t)*namelen)))
-        goto DONE;
-
-    /*
-     * Call H5Dcreate2 function.
-     */
-    if ((c_dset_id = H5Dcreate2((hid_t)*loc_id, c_name, (hid_t)*type_id, (hid_t)*space_id, (hid_t)*lcpl_id,
-                                (hid_t)*dcpl_id, (hid_t)*dapl_id)) < 0)
-        goto DONE;
-    *dset_id = (hid_t_f)c_dset_id;
-
-    ret_value = 0;
-
-DONE:
-    if (c_name)
-        HDfree(c_name);
-    return ret_value;
-}
-
-/****if* H5Df/h5dopen_c
- * NAME
- *  h5dopen_c
- * PURPOSE
- *  Call H5Dopen2 to open a dataset
- * INPUTS
- *  loc_id - file or group identifier
- *  name - name of the dataset
- *  namelen - name length
- *  dapl_id	- Dataset access property list
- * OUTPUTS
- *  dset_id - dataset identifier
- * RETURNS
- *  0 on success, -1 on failure
- * AUTHOR
- *  Elena Pourmal
- *  Wednesday, August 4, 1999
- * HISTORY
- *  Added 1.8 parameter: dapl_id
- * SOURCE
- */
-int_f
-h5dopen_c(hid_t_f *loc_id, _fcd name, int_f *namelen, hid_t_f *dapl_id, hid_t_f *dset_id)
-/******/
-{
-    char *c_name = NULL;
-    hid_t c_dset_id;
-    int   ret_value = -1;
-
-    /*
-     * Convert FORTRAN name to C name
-     */
-    if (NULL == (c_name = (char *)HD5f2cstring(name, (size_t)*namelen)))
-        goto DONE;
-
-    /*
-     * Call H5Dopen2 function.
-     */
-    if ((c_dset_id = H5Dopen2((hid_t)*loc_id, c_name, (hid_t)*dapl_id)) < 0)
-        goto DONE;
-
-    *dset_id  = (hid_t_f)c_dset_id;
-    ret_value = 0;
-
-DONE:
-    if (c_name)
-        HDfree(c_name);
-    return ret_value;
-}
-
 /****if* H5Df/h5dwrite_ref_reg_c
  * NAME
  *  h5dwrite_ref_reg_c
@@ -268,71 +163,6 @@ h5dread_ref_reg_c(hid_t_f *dset_id, hid_t_f *mem_type_id, hid_t_f *mem_space_id,
     return ret_value;
 }
 
-/****if* H5Df/h5dclose_c
- * NAME
- *  h5dclose_c
- * PURPOSE
- *  Call H5Dclose to close a dataset
- * INPUTS
- *  dset_id - identifier of the dataset to be closed
- * RETURNS
- *  0 on success, -1 on failure
- * AUTHOR
- *  Elena Pourmal
- *  Wednesday, August 4, 1999
- * HISTORY
- *
- * SOURCE
- */
-
-int_f
-h5dclose_c(hid_t_f *dset_id)
-/******/
-{
-    int   ret_value = 0;
-    hid_t c_dset_id;
-    c_dset_id = (hid_t)*dset_id;
-    if (H5Dclose(c_dset_id) < 0)
-        ret_value = -1;
-    return ret_value;
-}
-
-/****if* H5Df/h5dget_space_c
- * NAME
- *  h5dget_space_c
- * PURPOSE
- *  Call H5Dget_space to obtain dataspace of a dataset
- * INPUTS
- *  dset_id - identifier of the dataset
- * OUTPUTS
- *  space_id - identifier of the dataset's dataspace
- * RETURNS
- *  0 on success, -1 on failure
- * AUTHOR
- *  Elena Pourmal
- *  Thursday, August 19, 1999
- * HISTORY
- *
- * SOURCE
- */
-
-int_f
-h5dget_space_c(hid_t_f *dset_id, hid_t_f *space_id)
-/******/
-{
-    int   ret_value = -1;
-    hid_t c_dset_id;
-    hid_t c_space_id;
-
-    c_dset_id  = (hid_t)*dset_id;
-    c_space_id = H5Dget_space(c_dset_id);
-    if (c_space_id < 0)
-        return ret_value;
-    ret_value = 0;
-    *space_id = (hid_t_f)c_space_id;
-    return ret_value;
-}
-
 /****if* H5Df/h5dget_type_c
  * NAME
  *  h5dget_type_c
@@ -410,60 +240,6 @@ h5dget_create_plist_c(hid_t_f *dset_id, hid_t_f *plist_id)
     return ret_value;
 }
 
-/****if* H5Df/h5dset_extent_c
- * NAME
- *  h5dset_extent_c
- * PURPOSE
- *  Call H5Dset_extent to extend dataset with unlimited dimensions
- * INPUTS
- *  dset_id - identifier of the dataset
- * OUTPUTS
- *  dims - array with the dimension sizes
- * RETURNS
- *  0 on success, -1 on failure
- * AUTHOR
- *  Elena Pourmal
- *  Thursday, August 19, 1999
- *
- * HISTORY
- *  Changed name from the now obsolete h5dextend
- *  to h5dset_extent in order to match new fortran interface.
- *                -MSB- March 14, 2008
- * SOURCE
- */
-
-int_f
-h5dset_extent_c(hid_t_f *dset_id, hsize_t_f *dims)
-/******/
-{
-    hid_t   c_space_id;
-    hsize_t c_dims[H5S_MAX_RANK];
-    int     rank;
-    int     i;
-    int     status;
-    int     ret_value = -1;
-
-    if ((c_space_id = H5Dget_space((hid_t)*dset_id)) < 0)
-        return ret_value;
-
-    rank = H5Sget_simple_extent_ndims(c_space_id);
-    H5Sclose(c_space_id);
-    if (rank < 0)
-        return ret_value;
-
-    /*
-     * Reverse dimensions due to C-FORTRAN storage order.
-     */
-    for (i = 0; i < rank; i++)
-        c_dims[i] = (hsize_t)dims[rank - i - 1];
-
-    status = H5Dset_extent((hid_t)*dset_id, c_dims);
-
-    if (status >= 0)
-        ret_value = 0;
-    return ret_value;
-}
-
 /****if* H5Df/h5dget_storage_size_c
  * NAME
  *  h5dget_storage_size_c
