@@ -5,7 +5,6 @@
  * COPYRIGHT
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
  * Copyright by The HDF Group.                                               *
- * Copyright by the Board of Trustees of the University of Illinois.         *
  * All rights reserved.                                                      *
  *                                                                           *
  * This file is part of HDF5.  The full HDF5 copyright notice, including     *
@@ -145,277 +144,6 @@ done:
     return ret_value;
 }
 
-/****if* H5Lf/h5ldelete_c
- * NAME
- *  h5ldelete_c
- * PURPOSE
- *  Call H5Ldelete
- * INPUTS
- *
- *
- *  loc_id  - Identifier of the file or group containing the object
- *  name    - Name of the link to delete
- *  lapl_id - Link access property list identifier
- *  namelen - length of name
- *
- * RETURNS
- *  0 on success, -1 on failure
- * AUTHOR
- *  M. Scot Breitenfeld
- *  January, 2008
- * SOURCE
- */
-
-int_f
-h5ldelete_c(hid_t_f *loc_id, _fcd name, size_t_f *namelen, hid_t_f *lapl_id)
-/******/
-{
-    char *c_name    = NULL;
-    int_f ret_value = 0;
-
-    /*
-     * Convert FORTRAN name to C name
-     */
-    if ((c_name = HD5f2cstring(name, (size_t)*namelen)) == NULL)
-        HGOTO_DONE(FAIL);
-
-    /*
-     * Call H5Ldelete function.
-     */
-    if (H5Ldelete((hid_t)*loc_id, c_name, (hid_t)*lapl_id) < 0)
-        HGOTO_DONE(FAIL);
-
-done:
-    if (c_name)
-        HDfree(c_name);
-
-    return ret_value;
-}
-
-/****if* H5Lf/h5lcreate_soft_c
- * NAME
- *  h5lcreate_soft_c
- * PURPOSE
- *  Call H5Lcreate_soft
- * INPUTS
- *
- *
- *  target_path - Path to the target object, which is not required to exist.
- *  link_loc_id - The file or group identifier for the new link.
- *  link_name   - The name of the new link.
- *  lcpl_id     - Link creation property list identifier.
- *  lapl_id     - Link access property list identifier.
- *
- * RETURNS
- *  0 on success, -1 on failure
- * AUTHOR
- *  M. Scot Breitenfeld
- *  February 20, 2008
- * SOURCE
- */
-
-int_f
-h5lcreate_soft_c(_fcd target_path, size_t_f *target_path_len, hid_t_f *link_loc_id, _fcd link_name,
-                 size_t_f *link_name_len, hid_t_f *lcpl_id, hid_t_f *lapl_id)
-/******/
-{
-    char *c_target_path = NULL;
-    char *c_link_name   = NULL;
-    int_f ret_value     = 0;
-
-    /*
-     * Convert FORTRAN name to C name
-     */
-    if ((c_target_path = HD5f2cstring(target_path, (size_t)*target_path_len)) == NULL)
-        HGOTO_DONE(FAIL);
-    if ((c_link_name = HD5f2cstring(link_name, (size_t)*link_name_len)) == NULL)
-        HGOTO_DONE(FAIL);
-
-    /*
-     * Call H5Adelete function.
-     */
-    if (H5Lcreate_soft(c_target_path, (hid_t)*link_loc_id, c_link_name, (hid_t)*lcpl_id, (hid_t)*lapl_id) < 0)
-        HGOTO_DONE(FAIL);
-
-done:
-    if (c_target_path)
-        HDfree(c_target_path);
-    if (c_link_name)
-        HDfree(c_link_name);
-
-    return ret_value;
-}
-
-/****if* H5Lf/h5lcreate_hard_c
- * NAME
- *  h5lcreate_hard_c
- * PURPOSE
- *  Call H5Lcreate_hard
- * INPUTS
- *
- *  obj_loc_id  - The file or group identifier for the target object.
- *  obj_name    - Name of the target object, which must already exist.
- *  obj_namelen - Name length
- *  link_loc_id - The file or group identifier for the new link.
- *  link_name   - The name of the new link.
- *  link_namelen- Name length
- *  lcpl_id     - Link creation property list identifier.
- *  lapl_id     - Link access property list identifier.
- *
- * RETURNS
- *  0 on success, -1 on failure
- * AUTHOR
- *  M. Scot Breitenfeld
- *  February 27, 2008
- * SOURCE
- */
-int_f
-h5lcreate_hard_c(hid_t_f *obj_loc_id, _fcd obj_name, size_t_f *obj_namelen, hid_t_f *link_loc_id,
-                 _fcd link_name, size_t_f *link_namelen, hid_t_f *lcpl_id, hid_t_f *lapl_id)
-/******/
-{
-    char *c_obj_name  = NULL;
-    char *c_link_name = NULL;
-    int_f ret_value   = 0;
-
-    /*
-     * Convert FORTRAN name to C name
-     */
-    if ((c_obj_name = HD5f2cstring(obj_name, (size_t)*obj_namelen)) == NULL)
-        HGOTO_DONE(FAIL);
-    if ((c_link_name = HD5f2cstring(link_name, (size_t)*link_namelen)) == NULL)
-        HGOTO_DONE(FAIL);
-
-    /*
-     * Call H5Lcreate_hard function.
-     */
-    if (H5Lcreate_hard((hid_t)*obj_loc_id, c_obj_name, (hid_t)*link_loc_id, c_link_name, (hid_t)*lcpl_id,
-                       (hid_t)*lapl_id) < 0)
-        HGOTO_DONE(FAIL);
-
-done:
-    if (c_obj_name)
-        HDfree(c_obj_name);
-    if (c_link_name)
-        HDfree(c_link_name);
-
-    return ret_value;
-}
-
-/****if* H5Lf/h5ldelete_by_idx_c
- * NAME
- *  h5ldelete_by_idx_c
- * PURPOSE
- *  Calls h5ldelete_by_idx
- * INPUTS
- *
- *  loc_id - File or group identifier specifying location of subject group
- *  group_name - Name of subject group
- *  group_namelen - Name length
- *  index_field - Type of index; Possible values are:
- *                    H5_INDEX_UNKNOWN_F = -1  - Unknown index type
- *                    H5_INDEX_NAME_F          - Index on names
- *                    H5_INDEX_CRT_ORDER_F     - Index on creation order
- *                    H5_INDEX_N_F	       - Number of indices defined
- *  order - Order within field or index; Possible values are:
- *                    H5_ITER_UNKNOWN_F   - Unknown order
- *                    H5_ITER_INC_F       - Increasing order
- *                    H5_ITER_DEC_F       - Decreasing order
- *                    H5_ITER_NATIVE_F    - No particular order, whatever is fastest
- *                    H5_ITER_N_F	  - Number of iteration orders
- *  n - Link for which to retrieve information
- *  lapl_id - Link access property list
- *
- * OUTPUTS
- *     N/A
- * RETURNS
- *  0 on success, -1 on failure
- * AUTHOR
- *  M. Scot Breitenfeld
- *  February 29, 2008
- * HISTORY
- * N/A
- * SOURCE
- */
-int_f
-h5ldelete_by_idx_c(hid_t_f *loc_id, _fcd group_name, size_t_f *group_namelen, int_f *index_field,
-                   int_f *order, hsize_t_f *n, hid_t_f *lapl_id)
-/******/
-{
-    char *          c_group_name = NULL; /* Buffer to hold C string */
-    H5_index_t      c_index_field;
-    H5_iter_order_t c_order;
-    int_f           ret_value = 0; /* Return value */
-
-    /*
-     * Convert FORTRAN name to C name
-     */
-    if ((c_group_name = HD5f2cstring(group_name, (size_t)*group_namelen)) == NULL)
-        HGOTO_DONE(FAIL);
-
-    c_index_field = (H5_index_t)*index_field;
-    c_order       = (H5_iter_order_t)*order;
-
-    /*
-     * Call H5Ldelete_by_name function.
-     */
-    if (H5Ldelete_by_idx((hid_t)*loc_id, c_group_name, c_index_field, c_order, (hsize_t)*n, (hid_t)*lapl_id) <
-        0)
-        HGOTO_DONE(FAIL);
-
-done:
-    if (c_group_name)
-        HDfree(c_group_name);
-    return ret_value;
-}
-
-/****if* H5Lf/h5lexists_c
- * NAME
- *  h5lexists_c
- * PURPOSE
- *  Calls H5Lexists
- * INPUTS
- *
- *  loc_id - Identifier of the file or group to query.
- *  name - Link name to check
- *  lapl_id - Link access property list identifier.
- * OUTPUTS
- *
- *  link_exists_c  - returns a positive value, for TRUE, or 0 (zero), for FALSE.
- * RETURNS
- *  0 on success, -1 on failure
- * AUTHOR
- *  M. Scot Breitenfeld
- *  February 29, 2008
- * HISTORY
- *
- * SOURCE
- */
-int_f
-h5lexists_c(hid_t_f *loc_id, _fcd name, size_t_f *namelen, hid_t_f *lapl_id, int_f *link_exists)
-/******/
-{
-    char *c_name    = NULL; /* Buffer to hold C string */
-    int_f ret_value = 0;    /* Return value */
-
-    /*
-     * Convert FORTRAN name to C name
-     */
-    if ((c_name = HD5f2cstring(name, (size_t)*namelen)) == NULL)
-        HGOTO_DONE(FAIL);
-
-    /*
-     * Call H5Lexists function.
-     */
-    if ((*link_exists = (int_f)H5Lexists((hid_t)*loc_id, c_name, (hid_t)*lapl_id)) < 0)
-        HGOTO_DONE(FAIL);
-
-done:
-    if (c_name)
-        HDfree(c_name);
-    return ret_value;
-}
-
 /****if* H5Lf/h5lget_info_c
  * NAME
  *  h5lget_info_c
@@ -455,7 +183,7 @@ h5lget_info_c(hid_t_f *link_loc_id, _fcd link_name, size_t_f *link_namelen, int_
               int_f *corder_valid, int_f *link_type, H5O_token_t *token, size_t_f *val_size, hid_t_f *lapl_id)
 /******/
 {
-    char *      c_link_name = NULL; /* Buffer to hold C string */
+    char       *c_link_name = NULL; /* Buffer to hold C string */
     int_f       ret_value   = 0;    /* Return value */
     H5L_info2_t link_buff;
 
@@ -504,7 +232,7 @@ done:
  *  lapl_id - Link access property list
  * OUTPUTS
  *
- *  corder_valid - Indicates whether the the creation order data is valid for this attribute
+ *  corder_valid - Indicates whether the creation order data is valid for this attribute
  *  corder - Is a positive integer containing the creation order of the attribute
  *  cset - Indicates the character set used for the attribute’s name
  *  data_size - indicates the size, in the number of characters, of the attribute
@@ -524,7 +252,7 @@ h5lget_info_by_idx_c(hid_t_f *loc_id, _fcd group_name, size_t_f *group_namelen,
                      int_f *cset, H5O_token_t *token, size_t_f *val_size, hid_t_f *lapl_id)
 /******/
 {
-    char *          c_group_name = NULL; /* Buffer to hold C string */
+    char           *c_group_name = NULL; /* Buffer to hold C string */
     H5_index_t      c_index_field;
     H5_iter_order_t c_order;
     int_f           ret_value = 0; /* Return value */
@@ -698,8 +426,8 @@ h5lget_name_by_idx_c(hid_t_f *loc_id, _fcd group_name, size_t_f *group_namelen,
                      int_f *order, hsize_t_f *n, size_t_f *size, _fcd name, hid_t_f *lapl_id)
 /******/
 {
-    char *  c_group_name = NULL; /* Buffer to hold C string */
-    char *  c_name       = NULL; /* Buffer to hold C string */
+    char   *c_group_name = NULL; /* Buffer to hold C string */
+    char   *c_name       = NULL; /* Buffer to hold C string */
     size_t  c_size;
     ssize_t c_size_link;
     int_f   ret_value = 0; /* Return value */
@@ -954,55 +682,6 @@ done:
     return ret_value;
 }
 
-/****if* H5Lf/h5literate_c
- * NAME
- *  h5literate_c
- * PURPOSE
- *  Calls H5Literate
- * INPUTS
- *
- *  group_id - Identifier specifying subject group
- *  index_type - Type of index which determines the order
- *  order - Order within index
- *  idx - Iteration position at which to start
- *  op - Callback function passing data regarding the link to the calling application
- *  op_data - User-defined pointer to data required by the application for its processing of the link
- *
- * OUTPUTS
- *
- *  idx - Position at which an interrupted iteration may be restarted
- *
- * RETURNS
- *  >0 on success, 0< on failure
- * AUTHOR
- *  M. Scot Breitenfeld
- *  July 8, 2008
- * SOURCE
- */
-int_f
-h5literate_c(hid_t_f *group_id, int_f *index_type, int_f *order, hsize_t_f *idx, H5L_iterate2_t op,
-             void *op_data)
-/******/
-{
-    int_f   ret_value = -1; /* Return value */
-    herr_t  func_ret_value; /* H5Linterate return value */
-    hsize_t idx_c = 0;
-
-    idx_c = (hsize_t)*idx;
-
-    /*
-     * Call H5Linterate
-     */
-
-    func_ret_value =
-        H5Literate2((hid_t)*group_id, (H5_index_t)*index_type, (H5_iter_order_t)*order, &idx_c, op, op_data);
-
-    ret_value = (int_f)func_ret_value;
-    *idx      = (hsize_t_f)idx_c;
-
-    return ret_value;
-}
-
 /****if* H5Lf/h5literate_by_name_c
  * NAME
  *  h5literate_by_name_c
@@ -1039,7 +718,7 @@ h5literate_by_name_c(hid_t_f *loc_id, _fcd name, size_t_f *namelen, int_f *index
     int_f   ret_value = -1; /* Return value */
     herr_t  func_ret_value; /* H5Linterate return value */
     hsize_t idx_c  = 0;
-    char *  c_name = NULL; /* Buffer to hold C string */
+    char   *c_name = NULL; /* Buffer to hold C string */
 
     /*
      * Convert FORTRAN name to C name
