@@ -386,6 +386,7 @@ h5close_types_c(hid_t_f *types, int_f *lentypes, hid_t_f *floatingtypes, int_f *
  *  h5d_size_flags  - H5D interface flags of type size_t
  *  h5e_flags       - H5E interface flags
  *  h5e_hid_flags   - H5E interface flags of type hid_t
+ *  h5es_flags      - H5ES interface flags
  *  h5f_flags       - H5F interface flags
  *  h5fd_flags      - H5FD interface flags
  *  h5fd_hid_flags  - H5FD interface flags of type hid_t
@@ -424,10 +425,11 @@ h5close_types_c(hid_t_f *types, int_f *lentypes, hid_t_f *floatingtypes, int_f *
  */
 int_f
 h5init_flags_c(int_f *h5d_flags, size_t_f *h5d_size_flags, int_f *h5e_flags, hid_t_f *h5e_hid_flags,
-               int_f *h5f_flags, int_f *h5fd_flags, hid_t_f *h5fd_hid_flags, int_f *h5g_flags,
-               int_f *h5i_flags, int_f *h5l_flags, int_f *h5o_flags, hid_t_f *h5p_flags, int_f *h5p_flags_int,
-               int_f *h5r_flags, int_f *h5s_flags, hid_t_f *h5s_hid_flags, hsize_t_f *h5s_hsize_flags,
-               int_f *h5t_flags, int_f *h5z_flags, int_f *h5_generic_flags, haddr_t_f *h5_haddr_generic_flags)
+               H5ES_status_t *h5es_flags, hid_t_f *h5es_hid_flags, int_f *h5f_flags, int_f *h5fd_flags,
+               hid_t_f *h5fd_hid_flags, int_f *h5g_flags, int_f *h5i_flags, int_f *h5l_flags,
+               int_f *h5o_flags, hid_t_f *h5p_flags, int_f *h5p_flags_int, int_f *h5r_flags, int_f *h5s_flags,
+               hid_t_f *h5s_hid_flags, hsize_t_f *h5s_hsize_flags, int_f *h5t_flags, int_f *h5z_flags,
+               int_f *h5_generic_flags, haddr_t_f *h5_haddr_generic_flags)
 /******/
 {
     /*
@@ -465,6 +467,9 @@ h5init_flags_c(int_f *h5d_flags, size_t_f *h5d_size_flags, int_f *h5e_flags, hid
     h5d_flags[26] = (int_f)H5D_VDS_FIRST_MISSING;
     h5d_flags[27] = (int_f)H5D_VDS_LAST_AVAILABLE;
     h5d_flags[28] = (int_f)H5D_VIRTUAL;
+    h5d_flags[29] = (int_f)H5D_SELECTION_IO_MODE_DEFAULT;
+    h5d_flags[30] = (int_f)H5D_SELECTION_IO_MODE_OFF;
+    h5d_flags[31] = (int_f)H5D_SELECTION_IO_MODE_ON;
 
     /*
      *  H5E flags
@@ -475,6 +480,15 @@ h5init_flags_c(int_f *h5d_flags, size_t_f *h5d_size_flags, int_f *h5e_flags, hid
     h5e_flags[1] = (int_f)H5E_MINOR;
     h5e_flags[2] = (int_f)H5E_WALK_UPWARD;
     h5e_flags[3] = (int_f)H5E_WALK_DOWNWARD;
+    /*
+     *  H5ES flags
+     */
+    h5es_hid_flags[0] = (hid_t_f)H5ES_NONE;
+
+    h5es_flags[0] = H5ES_STATUS_IN_PROGRESS;
+    h5es_flags[1] = H5ES_STATUS_SUCCEED;
+    h5es_flags[2] = H5ES_STATUS_CANCELED;
+    h5es_flags[3] = H5ES_STATUS_FAIL;
 
     /*
      *  H5F flags
