@@ -1,6 +1,5 @@
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
  * Copyright by The HDF Group.                                               *
- * Copyright by the Board of Trustees of the University of Illinois.         *
  * All rights reserved.                                                      *
  *                                                                           *
  * This file is part of HDF5.  The full HDF5 copyright notice, including     *
@@ -24,21 +23,18 @@
  *
  * Return: Success: 0, Failure: -1
  *
- * Programmer: pvn@ncsa.uiuc.edu
+ * Programmer: Pedro Vicente
  *
  * Date: October 05, 2004
  *
  * Comments:
  *
- * Modifications:
- *
- *
  *-------------------------------------------------------------------------
  */
 
 int_f
-nh5immake_image_8bit_c(hid_t_f *loc_id, size_t_f *namelen, _fcd name, hsize_t_f *width, hsize_t_f *height,
-                       int_f *buf)
+h5immake_image_8bit_c(hid_t_f *loc_id, size_t_f *namelen, _fcd name, hsize_t_f *width, hsize_t_f *height,
+                      int_f *buf)
 {
     int     ret_value = -1;
     herr_t  ret;
@@ -67,7 +63,7 @@ nh5immake_image_8bit_c(hid_t_f *loc_id, size_t_f *namelen, _fcd name, hsize_t_f
 
 done:
     if (c_name != NULL)
-        free(c_name);
+        HDfree(c_name);
 
     return ret_value;
 }
@@ -79,20 +75,17 @@ done:
  *
  * Return: Success: 0, Failure: -1
  *
- * Programmer: pvn@ncsa.uiuc.edu
+ * Programmer: Pedro Vicente
  *
  * Date: October 05, 2004
  *
  * Comments:
  *
- * Modifications:
- *
- *
  *-------------------------------------------------------------------------
  */
 
 int_f
-nh5imread_image_c(hid_t_f *loc_id, size_t_f *namelen, _fcd name, int_f *buf)
+h5imread_image_c(hid_t_f *loc_id, size_t_f *namelen, _fcd name, int_f *buf)
 {
     int    ret_value = -1;
     herr_t ret;
@@ -117,7 +110,7 @@ nh5imread_image_c(hid_t_f *loc_id, size_t_f *namelen, _fcd name, int_f *buf)
 
 done:
     if (c_name != NULL)
-        free(c_name);
+        HDfree(c_name);
 
     return ret_value;
 }
@@ -129,21 +122,18 @@ done:
  *
  * Return: Success: 0, Failure: -1
  *
- * Programmer: pvn@ncsa.uiuc.edu
+ * Programmer: Pedro Vicente
  *
  * Date: October 05, 2004
  *
  * Comments:
  *
- * Modifications:
- *
- *
  *-------------------------------------------------------------------------
  */
 
 int_f
-nh5immake_image_24bit_c(hid_t_f *loc_id, size_t_f *namelen, _fcd name, size_t_f *ilen, _fcd il,
-                        hsize_t_f *width, hsize_t_f *height, void *buf)
+h5immake_image_24bit_c(hid_t_f *loc_id, size_t_f *namelen, _fcd name, size_t_f *ilen, _fcd il,
+                       hsize_t_f *width, hsize_t_f *height, void *buf)
 {
     int     ret_value = -1;
     herr_t  ret;
@@ -178,9 +168,9 @@ nh5immake_image_24bit_c(hid_t_f *loc_id, size_t_f *namelen, _fcd name, size_t_f
 
 done:
     if (c_name != NULL)
-        free(c_name);
+        HDfree(c_name);
     if (c_il != NULL)
-        free(c_il);
+        HDfree(c_il);
 
     return ret_value;
 }
@@ -192,21 +182,18 @@ done:
  *
  * Return: Success: 0, Failure: -1
  *
- * Programmer: pvn@ncsa.uiuc.edu
+ * Programmer: Pedro Vicente
  *
  * Date: October 05, 2004
  *
  * Comments:
  *
- * Modifications:
- *
- *
  *-------------------------------------------------------------------------
  */
 
 int_f
-nh5imget_image_info_c(hid_t_f *loc_id, size_t_f *namelen, _fcd name, hsize_t_f *width, hsize_t_f *height,
-                      hsize_t_f *planes, hsize_t_f *npals, size_t_f *ilen, _fcd interlace)
+h5imget_image_info_c(hid_t_f *loc_id, size_t_f *namelen, _fcd name, hsize_t_f *width, hsize_t_f *height,
+                     hsize_t_f *planes, hsize_t_f *npals, size_t_f *ilen, _fcd interlace)
 {
     int      ret_value = -1;
     herr_t   ret;
@@ -255,9 +242,9 @@ nh5imget_image_info_c(hid_t_f *loc_id, size_t_f *namelen, _fcd name, hsize_t_f *
 
 done:
     if (c_name != NULL)
-        free(c_name);
+        HDfree(c_name);
     if (c_buf != NULL)
-        free(c_buf);
+        HDfree(c_buf);
 
     return ret_value;
 }
@@ -269,20 +256,17 @@ done:
  *
  * Return: Success: 0, Failure: -1
  *
- * Programmer: pvn@ncsa.uiuc.edu
+ * Programmer: Pedro Vicente
  *
  * Date: October 06, 2004
  *
  * Comments:
  *
- * Modifications:
- *
- *
  *-------------------------------------------------------------------------
  */
 
 int_f
-nh5imis_image_c(hid_t_f *loc_id, size_t_f *namelen, _fcd name)
+h5imis_image_c(hid_t_f *loc_id, size_t_f *namelen, _fcd name)
 {
     hid_t  c_loc_id;
     char  *c_name = NULL;
@@ -303,7 +287,7 @@ nh5imis_image_c(hid_t_f *loc_id, size_t_f *namelen, _fcd name)
     ret = H5IMis_image(c_loc_id, c_name);
 
     if (c_name != NULL)
-        free(c_name);
+        HDfree(c_name);
 
     return ret;
 }
@@ -315,20 +299,17 @@ nh5imis_image_c(hid_t_f *loc_id, size_t_f *namelen, _fcd name)
  *
  * Return: Success: 0, Failure: -1
  *
- * Programmer: pvn@ncsa.uiuc.edu
+ * Programmer: Pedro Vicente
  *
  * Date: October 06, 2004
  *
  * Comments:
  *
- * Modifications:
- *
- *
  *-------------------------------------------------------------------------
  */
 
 int_f
-nh5immake_palette_c(hid_t_f *loc_id, size_t_f *namelen, _fcd name, hsize_t_f *dims, void *buf)
+h5immake_palette_c(hid_t_f *loc_id, size_t_f *namelen, _fcd name, hsize_t_f *dims, void *buf)
 {
     char   *c_name = NULL;
     hsize_t c_dims[H5S_MAX_RANK];
@@ -365,20 +346,17 @@ done:
  *
  * Return: Success: 0, Failure: -1
  *
- * Programmer: pvn@ncsa.uiuc.edu
+ * Programmer: Pedro Vicente
  *
  * Date: October 06, 2004
  *
  * Comments:
  *
- * Modifications:
- *
- *
  *-------------------------------------------------------------------------
  */
 
 int_f
-nh5imlink_palette_c(hid_t_f *loc_id, size_t_f *namelen, _fcd name, size_t_f *ilen, _fcd pal_name)
+h5imlink_palette_c(hid_t_f *loc_id, size_t_f *namelen, _fcd name, size_t_f *ilen, _fcd pal_name)
 {
     int    ret_value = -1;
     herr_t ret;
@@ -411,9 +389,9 @@ nh5imlink_palette_c(hid_t_f *loc_id, size_t_f *namelen, _fcd name, size_t_f *ile
 
 done:
     if (c_name != NULL)
-        free(c_name);
+        HDfree(c_name);
     if (c_namepal != NULL)
-        free(c_namepal);
+        HDfree(c_namepal);
 
     return ret_value;
 }
@@ -425,20 +403,17 @@ done:
  *
  * Return: Success: 0, Failure: -1
  *
- * Programmer: pvn@ncsa.uiuc.edu
+ * Programmer: Pedro Vicente
  *
  * Date: October 06, 2004
  *
  * Comments:
  *
- * Modifications:
- *
- *
  *-------------------------------------------------------------------------
  */
 
 int_f
-nh5imunlink_palette_c(hid_t_f *loc_id, size_t_f *namelen, _fcd name, size_t_f *ilen, _fcd pal_name)
+h5imunlink_palette_c(hid_t_f *loc_id, size_t_f *namelen, _fcd name, size_t_f *ilen, _fcd pal_name)
 {
     int    ret_value = -1;
     herr_t ret;
@@ -471,9 +446,9 @@ nh5imunlink_palette_c(hid_t_f *loc_id, size_t_f *namelen, _fcd name, size_t_f *i
 
 done:
     if (c_name != NULL)
-        free(c_name);
+        HDfree(c_name);
     if (c_namepal != NULL)
-        free(c_namepal);
+        HDfree(c_namepal);
 
     return ret_value;
 }
@@ -485,20 +460,17 @@ done:
  *
  * Return: Success: 0, Failure: -1
  *
- * Programmer: pvn@ncsa.uiuc.edu
+ * Programmer: Pedro Vicente
  *
  * Date: October 06 2004
  *
  * Comments:
  *
- * Modifications:
- *
- *
  *-------------------------------------------------------------------------
  */
 
 int_f
-nh5imget_npalettes_c(hid_t_f *loc_id, size_t_f *namelen, _fcd name, hsize_t_f *npals)
+h5imget_npalettes_c(hid_t_f *loc_id, size_t_f *namelen, _fcd name, hsize_t_f *npals)
 {
     int      ret_value = -1;
     herr_t   ret;
@@ -529,7 +501,7 @@ nh5imget_npalettes_c(hid_t_f *loc_id, size_t_f *namelen, _fcd name, hsize_t_f *n
 
 done:
     if (c_name != NULL)
-        free(c_name);
+        HDfree(c_name);
 
     return ret_value;
 }
@@ -541,20 +513,17 @@ done:
  *
  * Return: Success: 0, Failure: -1
  *
- * Programmer: pvn@ncsa.uiuc.edu
+ * Programmer: Pedro Vicente
  *
  * Date: October 06 2004
  *
  * Comments:
  *
- * Modifications:
- *
- *
  *-------------------------------------------------------------------------
  */
 
 int_f
-nh5imget_palette_info_c(hid_t_f *loc_id, size_t_f *namelen, _fcd name, int_f *pal_number, hsize_t_f *dims)
+h5imget_palette_info_c(hid_t_f *loc_id, size_t_f *namelen, _fcd name, int_f *pal_number, hsize_t_f *dims)
 {
     int     ret_value = -1;
     herr_t  ret;
@@ -588,7 +557,7 @@ nh5imget_palette_info_c(hid_t_f *loc_id, size_t_f *namelen, _fcd name, int_f *pa
 
 done:
     if (c_name != NULL)
-        free(c_name);
+        HDfree(c_name);
 
     return ret_value;
 }
@@ -600,20 +569,17 @@ done:
  *
  * Return: Success: 0, Failure: -1
  *
- * Programmer: pvn@ncsa.uiuc.edu
+ * Programmer: Pedro Vicente
  *
  * Date: October 06 2004
  *
  * Comments:
  *
- * Modifications:
- *
- *
  *-------------------------------------------------------------------------
  */
 
 int_f
-nh5imget_palette_c(hid_t_f *loc_id, size_t_f *namelen, _fcd name, int_f *pal_number, void *buf)
+h5imget_palette_c(hid_t_f *loc_id, size_t_f *namelen, _fcd name, int_f *pal_number, void *buf)
 {
     int    ret_value = -1;
     herr_t ret;
@@ -641,7 +607,7 @@ nh5imget_palette_c(hid_t_f *loc_id, size_t_f *namelen, _fcd name, int_f *pal_num
 
 done:
     if (c_name != NULL)
-        free(c_name);
+        HDfree(c_name);
 
     return ret_value;
 }
@@ -653,20 +619,17 @@ done:
  *
  * Return: true, false, fail
  *
- * Programmer: pvn@ncsa.uiuc.edu
+ * Programmer: Pedro Vicente
  *
  * Date: October 06, 2004
  *
  * Comments:
  *
- * Modifications:
- *
- *
  *-------------------------------------------------------------------------
  */
 
 int_f
-nh5imis_palette_c(hid_t_f *loc_id, size_t_f *namelen, _fcd name)
+h5imis_palette_c(hid_t_f *loc_id, size_t_f *namelen, _fcd name)
 {
     hid_t  c_loc_id;
     char  *c_name;
@@ -687,7 +650,7 @@ nh5imis_palette_c(hid_t_f *loc_id, size_t_f *namelen, _fcd name)
     ret = H5IMis_palette(c_loc_id, c_name);
 
     if (c_name != NULL)
-        free(c_name);
+        HDfree(c_name);
 
     return ret;
 }
