@@ -1860,8 +1860,6 @@ done:
  * Programmer:  John Mainzer
  *              April 28, 2010
  *
- * Changes:     None.
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
@@ -1890,12 +1888,9 @@ H5AC__rsp__p0_only__flush(H5F_t *f)
      * However, when flushing from within the close operation from a file,
      * it's possible to skip this barrier (on the second flush of the cache).
      */
-    if (!H5CX_get_mpi_file_flushing()) {
-
+    if (!H5CX_get_mpi_file_flushing())
         if (MPI_SUCCESS != (mpi_result = MPI_Barrier(aux_ptr->mpi_comm)))
-
             HMPI_GOTO_ERROR(FAIL, "MPI_Barrier failed", mpi_result)
-    }
 
     /* Flush data to disk, from rank 0 process */
     if (aux_ptr->mpi_rank == 0) {
@@ -2104,31 +2099,28 @@ H5AC__run_sync_point(H5F_t *f, int sync_point_op)
 
     /* Sanity checks */
     HDassert(f != NULL);
-
     cache_ptr = f->shared->cache;
-
     HDassert(cache_ptr != NULL);
-
     aux_ptr = (H5AC_aux_t *)H5C_get_aux_ptr(cache_ptr);
-
     HDassert(aux_ptr != NULL);
     HDassert(aux_ptr->magic == H5AC__H5AC_AUX_T_MAGIC);
     HDassert((sync_point_op == H5AC_SYNC_POINT_OP__FLUSH_TO_MIN_CLEAN) ||
              (sync_point_op == H5AC_METADATA_WRITE_STRATEGY__DISTRIBUTED));
 
 #ifdef H5AC_DEBUG_DIRTY_BYTES_CREATION
-    HDfprintf(stdout, "%d:H5AC_propagate...:%u: (u/uu/i/iu/m/mu) = %zu/%u/%zu/%u/%zu/%u\n", aux_ptr->mpi_rank,
+    HDfprintf(stdout, "%d:%s...:%u: (u/uu/i/iu/m/mu) = %zu/%u/%zu/%u/%zu/%u\n", aux_ptr->mpi_rank, __func__,
               aux_ptr->dirty_bytes_propagations, aux_ptr->unprotect_dirty_bytes,
               aux_ptr->unprotect_dirty_bytes_updates, aux_ptr->insert_dirty_bytes,
               aux_ptr->insert_dirty_bytes_updates, aux_ptr->move_dirty_bytes,
               aux_ptr->move_dirty_bytes_updates);
 #endif /* H5AC_DEBUG_DIRTY_BYTES_CREATION */
 
-    /* clear collective access flag on half of the entries in the
-       cache and mark them as independent in case they need to be
-       evicted later. All ranks are guaranteed to mark the same entries
-       since we don't modify the order of the collectively accessed
-       entries except through collective access. */
+    /* Clear collective access flag on half of the entries in the cache and
+     * mark them as independent in case they need to be evicted later. All
+     * ranks are guaranteed to mark the same entries since we don't modify the
+     * order of the collectively accessed entries except through collective
+     * access.
+     */
     if (H5C_clear_coll_entries(cache_ptr, TRUE) < 0)
         HGOTO_ERROR(H5E_CACHE, H5E_CANTGET, FAIL, "H5C_clear_coll_entries() failed.")
 
@@ -2190,7 +2182,6 @@ H5AC__run_sync_point(H5F_t *f, int sync_point_op)
 #endif /* H5AC_DEBUG_DIRTY_BYTES_CREATION */
 
 done:
-
     FUNC_LEAVE_NOAPI(ret_value)
 } /* H5AC__run_sync_point() */
 
