@@ -1,6 +1,5 @@
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
  * Copyright by The HDF Group.                                               *
- * Copyright by the Board of Trustees of the University of Illinois.         *
  * All rights reserved.                                                      *
  *                                                                           *
  * This file is part of HDF5.  The full HDF5 copyright notice, including     *
@@ -22,8 +21,8 @@
 /* Module Setup */
 /****************/
 
-#define H5B2_PACKAGE /*suppress error about including H5B2pkg  */
-#define H5B2_TESTING /*suppress warning about H5B2 testing funcs*/
+#include "H5B2module.h" /* This source code file is part of the H5B2 module */
+#define H5B2_TESTING    /*suppress warning about H5B2 testing funcs*/
 
 /***********/
 /* Headers */
@@ -53,34 +52,54 @@ typedef struct H5B2_test_ctx_t {
 /* Local Prototypes */
 /********************/
 
-static void  *H5B2_test_crt_context(void *udata);
-static herr_t H5B2_test_dst_context(void *ctx);
-static herr_t H5B2_test_store(void *nrecord, const void *udata);
-static herr_t H5B2_test_compare(const void *rec1, const void *rec2, int *result);
-static herr_t H5B2_test_encode(uint8_t *raw, const void *nrecord, void *ctx);
-static herr_t H5B2_test_decode(const uint8_t *raw, void *nrecord, void *ctx);
-static herr_t H5B2_test_debug(FILE *stream, const H5F_t *f, hid_t dxpl_id, int indent, int fwidth,
-                              const void *record, const void *_udata);
-static void  *H5B2_test_crt_dbg_context(H5F_t *f, hid_t dxpl_id, haddr_t addr);
+/* v2 B-tree driver callbacks for 'test' B-trees */
+static void  *H5B2__test_crt_context(void *udata);
+static herr_t H5B2__test_dst_context(void *ctx);
+static herr_t H5B2__test_store(void *nrecord, const void *udata);
+static herr_t H5B2__test_compare(const void *rec1, const void *rec2, int *result);
+static herr_t H5B2__test_encode(uint8_t *raw, const void *nrecord, void *ctx);
+static herr_t H5B2__test_decode(const uint8_t *raw, void *nrecord, void *ctx);
+static herr_t H5B2__test_debug(FILE *stream, int indent, int fwidth, const void *record, const void *_udata);
+
+/* v2 B-tree driver callbacks for 'test2' B-trees */
+static herr_t H5B2__test2_store(void *nrecord, const void *udata);
+static herr_t H5B2__test2_compare(const void *rec1, const void *rec2, int *result);
+static herr_t H5B2__test2_encode(uint8_t *raw, const void *nrecord, void *ctx);
+static herr_t H5B2__test2_decode(const uint8_t *raw, void *nrecord, void *ctx);
+static herr_t H5B2__test2_debug(FILE *stream, int indent, int fwidth, const void *record, const void *_udata);
 
 /*********************/
 /* Package Variables */
 /*********************/
 
+/* Class structure for testing simple B-tree records */
 const H5B2_class_t H5B2_TEST[1] = {{
     /* B-tree class information */
-    H5B2_TEST_ID,              /* Type of B-tree */
-    "H5B2_TEST_ID",            /* Name of B-tree class */
-    sizeof(hsize_t),           /* Size of native record */
-    H5B2_test_crt_context,     /* Create client callback context */
-    H5B2_test_dst_context,     /* Destroy client callback context */
-    H5B2_test_store,           /* Record storage callback */
-    H5B2_test_compare,         /* Record comparison callback */
-    H5B2_test_encode,          /* Record encoding callback */
-    H5B2_test_decode,          /* Record decoding callback */
-    H5B2_test_debug,           /* Record debugging callback */
-    H5B2_test_crt_dbg_context, /* Create debugging context */
-    H5B2_test_dst_context      /* Destroy debugging context */
+    H5B2_TEST_ID,           /* Type of B-tree */
+    "H5B2_TEST_ID",         /* Name of B-tree class */
+    sizeof(hsize_t),        /* Size of native record */
+    H5B2__test_crt_context, /* Create client callback context */
+    H5B2__test_dst_context, /* Destroy client callback context */
+    H5B2__test_store,       /* Record storage callback */
+    H5B2__test_compare,     /* Record comparison callback */
+    H5B2__test_encode,      /* Record encoding callback */
+    H5B2__test_decode,      /* Record decoding callback */
+    H5B2__test_debug        /* Record debugging callback */
+}};
+
+/* Class structure for testing key/value B-tree records */
+const H5B2_class_t H5B2_TEST2[1] = {{
+    /* B-tree class information */
+    H5B2_TEST2_ID,           /* Type of B-tree */
+    "H5B2_TEST2_ID",         /* Name of B-tree class */
+    sizeof(H5B2_test_rec_t), /* Size of native record */
+    H5B2__test_crt_context,  /* Create client callback context */
+    H5B2__test_dst_context,  /* Destroy client callback context */
+    H5B2__test2_store,       /* Record storage callback */
+    H5B2__test2_compare,     /* Record comparison callback */
+    H5B2__test2_encode,      /* Record encoding callback */
+    H5B2__test2_decode,      /* Record decoding callback */
+    H5B2__test2_debug        /* Record debugging callback */
 }};
 
 /*****************************/
@@ -95,7 +114,7 @@ const H5B2_class_t H5B2_TEST[1] = {{
 H5FL_DEFINE_STATIC(H5B2_test_ctx_t);
 
 /*-------------------------------------------------------------------------
- * Function:	H5B2_test_crt_context
+ * Function:	H5B2__test_crt_context
  *
  * Purpose:	Create client callback context
  *
@@ -108,13 +127,13 @@ H5FL_DEFINE_STATIC(H5B2_test_ctx_t);
  *-------------------------------------------------------------------------
  */
 static void *
-H5B2_test_crt_context(void *_f)
+H5B2__test_crt_context(void *_f)
 {
     H5F_t           *f = (H5F_t *)_f;  /* User data for building callback context */
     H5B2_test_ctx_t *ctx;              /* Callback context structure */
     void            *ret_value = NULL; /* Return value */
 
-    FUNC_ENTER_NOAPI_NOINIT
+    FUNC_ENTER_PACKAGE
 
     /* Sanity check */
     HDassert(f);
@@ -131,10 +150,10 @@ H5B2_test_crt_context(void *_f)
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
-} /* H5B2_test_crt_context() */
+} /* H5B2__test_crt_context() */
 
 /*-------------------------------------------------------------------------
- * Function:	H5B2_test_dst_context
+ * Function:	H5B2__test_dst_context
  *
  * Purpose:	Destroy client callback context
  *
@@ -147,11 +166,11 @@ done:
  *-------------------------------------------------------------------------
  */
 static herr_t
-H5B2_test_dst_context(void *_ctx)
+H5B2__test_dst_context(void *_ctx)
 {
     H5B2_test_ctx_t *ctx = (H5B2_test_ctx_t *)_ctx; /* Callback context structure */
 
-    FUNC_ENTER_NOAPI_NOINIT_NOERR
+    FUNC_ENTER_PACKAGE_NOERR
 
     /* Sanity check */
     HDassert(ctx);
@@ -160,10 +179,10 @@ H5B2_test_dst_context(void *_ctx)
     ctx = H5FL_FREE(H5B2_test_ctx_t, ctx);
 
     FUNC_LEAVE_NOAPI(SUCCEED)
-} /* H5B2_test_dst_context() */
+} /* H5B2__test_dst_context() */
 
 /*-------------------------------------------------------------------------
- * Function:	H5B2_test_store
+ * Function:	H5B2__test_store
  *
  * Purpose:	Store native information into record for B-tree
  *
@@ -176,17 +195,17 @@ H5B2_test_dst_context(void *_ctx)
  *-------------------------------------------------------------------------
  */
 static herr_t
-H5B2_test_store(void *nrecord, const void *udata)
+H5B2__test_store(void *nrecord, const void *udata)
 {
-    FUNC_ENTER_NOAPI_NOINIT_NOERR
+    FUNC_ENTER_PACKAGE_NOERR
 
     *(hsize_t *)nrecord = *(const hsize_t *)udata;
 
     FUNC_LEAVE_NOAPI(SUCCEED)
-} /* H5B2_test_store() */
+} /* H5B2__test_store() */
 
 /*-------------------------------------------------------------------------
- * Function:	H5B2_test_compare
+ * Function:	H5B2__test_compare
  *
  * Purpose:	Compare two native information records, according to some key
  *
@@ -200,17 +219,17 @@ H5B2_test_store(void *nrecord, const void *udata)
  *-------------------------------------------------------------------------
  */
 static herr_t
-H5B2_test_compare(const void *rec1, const void *rec2, int *result)
+H5B2__test_compare(const void *rec1, const void *rec2, int *result)
 {
-    FUNC_ENTER_NOAPI_NOINIT_NOERR
+    FUNC_ENTER_PACKAGE_NOERR
 
     *result = (int)(*(const hssize_t *)rec1 - *(const hssize_t *)rec2);
 
     FUNC_LEAVE_NOAPI(SUCCEED)
-} /* H5B2_test_compare() */
+} /* H5B2__test_compare() */
 
 /*-------------------------------------------------------------------------
- * Function:	H5B2_test_encode
+ * Function:	H5B2__test_encode
  *
  * Purpose:	Encode native information into raw form for storing on disk
  *
@@ -223,11 +242,11 @@ H5B2_test_compare(const void *rec1, const void *rec2, int *result)
  *-------------------------------------------------------------------------
  */
 static herr_t
-H5B2_test_encode(uint8_t *raw, const void *nrecord, void *_ctx)
+H5B2__test_encode(uint8_t *raw, const void *nrecord, void *_ctx)
 {
     H5B2_test_ctx_t *ctx = (H5B2_test_ctx_t *)_ctx; /* Callback context structure */
 
-    FUNC_ENTER_NOAPI_NOINIT_NOERR
+    FUNC_ENTER_PACKAGE_NOERR
 
     /* Sanity check */
     HDassert(ctx);
@@ -235,10 +254,10 @@ H5B2_test_encode(uint8_t *raw, const void *nrecord, void *_ctx)
     H5F_ENCODE_LENGTH_LEN(raw, *(const hsize_t *)nrecord, ctx->sizeof_size);
 
     FUNC_LEAVE_NOAPI(SUCCEED)
-} /* H5B2_test_encode() */
+} /* H5B2__test_encode() */
 
 /*-------------------------------------------------------------------------
- * Function:	H5B2_test_decode
+ * Function:	H5B2__test_decode
  *
  * Purpose:	Decode raw disk form of record into native form
  *
@@ -251,11 +270,11 @@ H5B2_test_encode(uint8_t *raw, const void *nrecord, void *_ctx)
  *-------------------------------------------------------------------------
  */
 static herr_t
-H5B2_test_decode(const uint8_t *raw, void *nrecord, void *_ctx)
+H5B2__test_decode(const uint8_t *raw, void *nrecord, void *_ctx)
 {
     H5B2_test_ctx_t *ctx = (H5B2_test_ctx_t *)_ctx; /* Callback context structure */
 
-    FUNC_ENTER_NOAPI_NOINIT_NOERR
+    FUNC_ENTER_PACKAGE_NOERR
 
     /* Sanity check */
     HDassert(ctx);
@@ -263,10 +282,10 @@ H5B2_test_decode(const uint8_t *raw, void *nrecord, void *_ctx)
     H5F_DECODE_LENGTH_LEN(raw, *(hsize_t *)nrecord, ctx->sizeof_size);
 
     FUNC_LEAVE_NOAPI(SUCCEED)
-} /* H5B2_test_decode() */
+} /* H5B2__test_decode() */
 
 /*-------------------------------------------------------------------------
- * Function:	H5B2_test_debug
+ * Function:	H5B2__test_debug
  *
  * Purpose:	Debug native form of record
  *
@@ -279,71 +298,162 @@ H5B2_test_decode(const uint8_t *raw, void *nrecord, void *_ctx)
  *-------------------------------------------------------------------------
  */
 static herr_t
-H5B2_test_debug(FILE *stream, const H5F_t H5_ATTR_UNUSED *f, hid_t H5_ATTR_UNUSED dxpl_id, int indent,
-                int fwidth, const void *record, const void H5_ATTR_UNUSED *_udata)
+H5B2__test_debug(FILE *stream, int indent, int fwidth, const void *record, const void H5_ATTR_UNUSED *_udata)
 {
-    FUNC_ENTER_NOAPI_NOINIT_NOERR
+    FUNC_ENTER_PACKAGE_NOERR
 
     HDassert(record);
 
     HDfprintf(stream, "%*s%-*s %" PRIuHSIZE "\n", indent, "", fwidth, "Record:", *(const hsize_t *)record);
 
     FUNC_LEAVE_NOAPI(SUCCEED)
-} /* H5B2_test_debug() */
+} /* H5B2__test_debug() */
 
 /*-------------------------------------------------------------------------
- * Function:	H5B2_test_crt_dbg_context
+ * Function:	H5B2__test2_store
  *
- * Purpose:	Create context for debugging callback
- *
- * Return:	Success:	non-NULL
- *		Failure:	NULL
- *
- * Programmer:	Quincey Koziol
- *              Tuesday, December 1, 2009
- *
- *-------------------------------------------------------------------------
- */
-static void *
-H5B2_test_crt_dbg_context(H5F_t *f, hid_t H5_ATTR_UNUSED dxpl_id, haddr_t H5_ATTR_UNUSED addr)
-{
-    H5B2_test_ctx_t *ctx;       /* Callback context structure */
-    void            *ret_value; /* Return value */
-
-    FUNC_ENTER_NOAPI_NOINIT
-
-    /* Sanity check */
-    HDassert(f);
-
-    /* Allocate callback context */
-    if (NULL == (ctx = H5FL_MALLOC(H5B2_test_ctx_t)))
-        HGOTO_ERROR(H5E_BTREE, H5E_CANTALLOC, NULL, "can't allocate callback context")
-
-    /* Determine the size of addresses & lengths in the file */
-    ctx->sizeof_size = H5F_SIZEOF_SIZE(f);
-
-    /* Set return value */
-    ret_value = ctx;
-
-done:
-    FUNC_LEAVE_NOAPI(ret_value)
-} /* H5B2_test_crt_dbg_context() */
-
-/*-------------------------------------------------------------------------
- * Function:	H5B2_get_root_addr_test
- *
- * Purpose:	Retrieve the root node's address
+ * Purpose:	Store native information into record for B-tree
  *
  * Return:	Success:	non-negative
  *		Failure:	negative
  *
  * Programmer:	Quincey Koziol
+ *              Friday, December 25, 2015
+ *
+ *-------------------------------------------------------------------------
+ */
+static herr_t
+H5B2__test2_store(void *nrecord, const void *udata)
+{
+    FUNC_ENTER_PACKAGE_NOERR
+
+    *(H5B2_test_rec_t *)nrecord = *(const H5B2_test_rec_t *)udata;
+
+    FUNC_LEAVE_NOAPI(SUCCEED)
+} /* H5B2__test2_store() */
+
+/*-------------------------------------------------------------------------
+ * Function:	H5B2__test2_compare
+ *
+ * Purpose:	Compare two native information records, according to some key
+ *
+ * Return:	<0 if rec1 < rec2
+ *              =0 if rec1 == rec2
+ *              >0 if rec1 > rec2
+ *
+ * Programmer:	Quincey Koziol
+ *              Friday, December 25, 2015
+ *
+ *-------------------------------------------------------------------------
+ */
+static herr_t
+H5B2__test2_compare(const void *rec1, const void *rec2, int *result)
+{
+    FUNC_ENTER_PACKAGE_NOERR
+
+    *result = (int)(((const H5B2_test_rec_t *)rec1)->key - ((const H5B2_test_rec_t *)rec2)->key);
+
+    FUNC_LEAVE_NOAPI(SUCCEED)
+} /* H5B2__test2_compare() */
+
+/*-------------------------------------------------------------------------
+ * Function:	H5B2__test2_encode
+ *
+ * Purpose:	Encode native information into raw form for storing on disk
+ *
+ * Return:	Success:	non-negative
+ *		Failure:	negative
+ *
+ * Programmer:	Quincey Koziol
+ *              Friday, December 25, 2015
+ *
+ *-------------------------------------------------------------------------
+ */
+static herr_t
+H5B2__test2_encode(uint8_t *raw, const void *nrecord, void *_ctx)
+{
+    H5B2_test_ctx_t *ctx = (H5B2_test_ctx_t *)_ctx; /* Callback context structure */
+
+    FUNC_ENTER_PACKAGE_NOERR
+
+    /* Sanity check */
+    HDassert(ctx);
+
+    H5F_ENCODE_LENGTH_LEN(raw, ((const H5B2_test_rec_t *)nrecord)->key, ctx->sizeof_size);
+    H5F_ENCODE_LENGTH_LEN(raw, ((const H5B2_test_rec_t *)nrecord)->val, ctx->sizeof_size);
+
+    FUNC_LEAVE_NOAPI(SUCCEED)
+} /* H5B2__test2_encode() */
+
+/*-------------------------------------------------------------------------
+ * Function:	H5B2__test2_decode
+ *
+ * Purpose:	Decode raw disk form of record into native form
+ *
+ * Return:	Success:	non-negative
+ *		Failure:	negative
+ *
+ * Programmer:	Quincey Koziol
+ *              Friday, December 25, 2015
+ *
+ *-------------------------------------------------------------------------
+ */
+static herr_t
+H5B2__test2_decode(const uint8_t *raw, void *nrecord, void *_ctx)
+{
+    H5B2_test_ctx_t *ctx = (H5B2_test_ctx_t *)_ctx; /* Callback context structure */
+
+    FUNC_ENTER_PACKAGE_NOERR
+
+    /* Sanity check */
+    HDassert(ctx);
+
+    H5F_DECODE_LENGTH_LEN(raw, ((H5B2_test_rec_t *)nrecord)->key, ctx->sizeof_size);
+    H5F_DECODE_LENGTH_LEN(raw, ((H5B2_test_rec_t *)nrecord)->val, ctx->sizeof_size);
+
+    FUNC_LEAVE_NOAPI(SUCCEED)
+} /* H5B2__test2_decode() */
+
+/*-------------------------------------------------------------------------
+ * Function:	H5B2__test2_debug
+ *
+ * Purpose:	Debug native form of record
+ *
+ * Return:	Success:	non-negative
+ *		Failure:	negative
+ *
+ * Programmer:	Quincey Koziol
+ *              Friday, December 25, 2015
+ *
+ *-------------------------------------------------------------------------
+ */
+static herr_t
+H5B2__test2_debug(FILE *stream, int indent, int fwidth, const void *record, const void H5_ATTR_UNUSED *_udata)
+{
+    FUNC_ENTER_PACKAGE_NOERR
+
+    HDassert(record);
+
+    HDfprintf(stream, "%*s%-*s (%" PRIuHSIZE ", %" PRIuHSIZE ")\n", indent, "", fwidth,
+              "Record:", ((const H5B2_test_rec_t *)record)->key, ((const H5B2_test_rec_t *)record)->val);
+
+    FUNC_LEAVE_NOAPI(SUCCEED)
+} /* H5B2__test2_debug() */
+
+/*-------------------------------------------------------------------------
+ * Function:    H5B2__get_root_addr_test
+ *
+ * Purpose:     Retrieve the root node's address
+ *
+ * Return:      SUCCEED/FAIL
+ *
+ * Programmer:	Quincey Koziol
  *              Saturday, February 26, 2005
  *
  *-------------------------------------------------------------------------
  */
 herr_t
-H5B2_get_root_addr_test(H5B2_t *bt2, haddr_t *root_addr)
+H5B2__get_root_addr_test(H5B2_t *bt2, haddr_t *root_addr)
 {
     FUNC_ENTER_NOAPI_NOINIT_NOERR
 
@@ -355,10 +465,10 @@ H5B2_get_root_addr_test(H5B2_t *bt2, haddr_t *root_addr)
     *root_addr = bt2->hdr->root.addr;
 
     FUNC_LEAVE_NOAPI(SUCCEED)
-} /* H5B2_get_root_addr_test() */
+} /* H5B2__get_root_addr_test() */
 
 /*-------------------------------------------------------------------------
- * Function:    H5B2_get_node_info_test
+ * Function:    H5B2__get_node_info_test
  *
  * Purpose:     Determine information about a node holding a record in the B-tree
  *
@@ -370,16 +480,17 @@ H5B2_get_root_addr_test(H5B2_t *bt2, haddr_t *root_addr)
  *-------------------------------------------------------------------------
  */
 herr_t
-H5B2_get_node_info_test(H5B2_t *bt2, hid_t dxpl_id, void *udata, H5B2_node_info_test_t *ninfo)
+H5B2__get_node_info_test(H5B2_t *bt2, void *udata, H5B2_node_info_test_t *ninfo)
 {
     H5B2_hdr_t     *hdr;                 /* Pointer to the B-tree header */
     H5B2_node_ptr_t curr_node_ptr;       /* Node pointer info for current node */
-    unsigned        depth;               /* Current depth of the tree */
+    void           *parent = NULL;       /* Parent of current node */
+    uint16_t        depth;               /* Current depth of the tree */
     int             cmp;                 /* Comparison value of records */
     unsigned        idx;                 /* Location of record which matches key */
     herr_t          ret_value = SUCCEED; /* Return value */
 
-    FUNC_ENTER_NOAPI(FAIL)
+    FUNC_ENTER_PACKAGE
 
     /* Check arguments. */
     HDassert(bt2);
@@ -393,6 +504,10 @@ H5B2_get_node_info_test(H5B2_t *bt2, hid_t dxpl_id, void *udata, H5B2_node_info_
     /* Make copy of the root node pointer to start search with */
     curr_node_ptr = hdr->root;
 
+    /* Set initial parent, if doing swmr writes */
+    if (hdr->swmr_write)
+        parent = hdr;
+
     /* Current depth of the tree */
     depth = hdr->depth;
 
@@ -407,13 +522,20 @@ H5B2_get_node_info_test(H5B2_t *bt2, hid_t dxpl_id, void *udata, H5B2_node_info_
         H5B2_node_ptr_t  next_node_ptr; /* Node pointer info for next node */
 
         /* Lock B-tree current node */
-        if (NULL == (internal = H5B2_protect_internal(hdr, dxpl_id, curr_node_ptr.addr,
-                                                      curr_node_ptr.node_nrec, depth, H5AC_READ)))
+        if (NULL == (internal = H5B2__protect_internal(hdr, parent, &curr_node_ptr, depth, FALSE,
+                                                       H5AC__READ_ONLY_FLAG)))
             HGOTO_ERROR(H5E_BTREE, H5E_CANTPROTECT, FAIL, "unable to load B-tree internal node")
 
+        /* Unpin parent if necessary */
+        if (parent) {
+            if (parent != hdr && H5AC_unpin_entry(parent) < 0)
+                HGOTO_ERROR(H5E_BTREE, H5E_CANTUNPIN, FAIL, "unable to unpin parent entry")
+            parent = NULL;
+        } /* end if */
+
         /* Locate node pointer for child */
-        if (H5B2_locate_record(hdr->cls, internal->nrec, hdr->nat_off, internal->int_native, udata, &idx,
-                               &cmp) < 0)
+        if (H5B2__locate_record(hdr->cls, internal->nrec, hdr->nat_off, internal->int_native, udata, &idx,
+                                &cmp) < 0)
             HGOTO_ERROR(H5E_BTREE, H5E_CANTCOMPARE, FAIL, "can't compare btree2 records")
 
         if (cmp > 0)
@@ -424,17 +546,20 @@ H5B2_get_node_info_test(H5B2_t *bt2, hid_t dxpl_id, void *udata, H5B2_node_info_
             next_node_ptr = internal->node_ptrs[idx];
 
             /* Unlock current node */
-            if (H5AC_unprotect(hdr->f, dxpl_id, H5AC_BT2_INT, curr_node_ptr.addr, internal,
-                               H5AC__NO_FLAGS_SET) < 0)
+            if (H5AC_unprotect(hdr->f, H5AC_BT2_INT, curr_node_ptr.addr, internal,
+                               (unsigned)(hdr->swmr_write ? H5AC__PIN_ENTRY_FLAG : H5AC__NO_FLAGS_SET)) < 0)
                 HGOTO_ERROR(H5E_BTREE, H5E_CANTUNPROTECT, FAIL, "unable to release B-tree node")
 
+            /* Keep track of parent if necessary */
+            if (hdr->swmr_write)
+                parent = internal;
+
             /* Set pointer to next node to load */
             curr_node_ptr = next_node_ptr;
         } /* end if */
         else {
             /* Unlock current node */
-            if (H5AC_unprotect(hdr->f, dxpl_id, H5AC_BT2_INT, curr_node_ptr.addr, internal,
-                               H5AC__NO_FLAGS_SET) < 0)
+            if (H5AC_unprotect(hdr->f, H5AC_BT2_INT, curr_node_ptr.addr, internal, H5AC__NO_FLAGS_SET) < 0)
                 HGOTO_ERROR(H5E_BTREE, H5E_CANTUNPROTECT, FAIL, "unable to release B-tree node")
 
             /* Fill in information about the node */
@@ -453,16 +578,22 @@ H5B2_get_node_info_test(H5B2_t *bt2, hid_t dxpl_id, void *udata, H5B2_node_info_
         H5B2_leaf_t *leaf; /* Pointer to leaf node in B-tree */
 
         /* Lock B-tree leaf node */
-        if (NULL ==
-            (leaf = H5B2_protect_leaf(hdr, dxpl_id, curr_node_ptr.addr, curr_node_ptr.node_nrec, H5AC_READ)))
+        if (NULL == (leaf = H5B2__protect_leaf(hdr, parent, &curr_node_ptr, FALSE, H5AC__READ_ONLY_FLAG)))
             HGOTO_ERROR(H5E_BTREE, H5E_CANTPROTECT, FAIL, "unable to protect B-tree leaf node")
 
+        /* Unpin parent if necessary */
+        if (parent) {
+            if (parent != hdr && H5AC_unpin_entry(parent) < 0)
+                HGOTO_ERROR(H5E_BTREE, H5E_CANTUNPIN, FAIL, "unable to unpin parent entry")
+            parent = NULL;
+        } /* end if */
+
         /* Locate record */
-        if (H5B2_locate_record(hdr->cls, leaf->nrec, hdr->nat_off, leaf->leaf_native, udata, &idx, &cmp) < 0)
+        if (H5B2__locate_record(hdr->cls, leaf->nrec, hdr->nat_off, leaf->leaf_native, udata, &idx, &cmp) < 0)
             HGOTO_ERROR(H5E_BTREE, H5E_CANTCOMPARE, FAIL, "can't compare btree2 records")
 
         /* Unlock current node */
-        if (H5AC_unprotect(hdr->f, dxpl_id, H5AC_BT2_LEAF, curr_node_ptr.addr, leaf, H5AC__NO_FLAGS_SET) < 0)
+        if (H5AC_unprotect(hdr->f, H5AC_BT2_LEAF, curr_node_ptr.addr, leaf, H5AC__NO_FLAGS_SET) < 0)
             HGOTO_ERROR(H5E_BTREE, H5E_CANTUNPROTECT, FAIL, "unable to release B-tree node")
 
         /* Indicate the depth that the record was found */
@@ -475,15 +606,21 @@ H5B2_get_node_info_test(H5B2_t *bt2, hid_t dxpl_id, void *udata, H5B2_node_info_
     ninfo->nrec  = curr_node_ptr.node_nrec;
 
 done:
+    if (parent) {
+        HDassert(ret_value < 0);
+        if (parent != hdr && H5AC_unpin_entry(parent) < 0)
+            HDONE_ERROR(H5E_BTREE, H5E_CANTUNPIN, FAIL, "unable to unpin parent entry")
+    } /* end if */
+
     FUNC_LEAVE_NOAPI(ret_value)
-} /* H5B2_get_node_info_test() */
+} /* H5B2__get_node_info_test() */
 
 /*-------------------------------------------------------------------------
- * Function:    H5B2_get_node_depth_test
+ * Function:    H5B2__get_node_depth_test
  *
  * Purpose:     Determine the depth of a node holding a record in the B-tree
  *
- * Note:        Just a simple wrapper around the H5B2_get_node_info_test() routine
+ * Note:        Just a simple wrapper around the H5B2__get_node_info_test() routine
  *
  * Return:      Success:    Non-negative depth of the node where the record
  *                          was found
@@ -496,23 +633,23 @@ done:
  *-------------------------------------------------------------------------
  */
 int
-H5B2_get_node_depth_test(H5B2_t *bt2, hid_t dxpl_id, void *udata)
+H5B2__get_node_depth_test(H5B2_t *bt2, void *udata)
 {
     H5B2_node_info_test_t ninfo;          /* Node information */
     int                   ret_value = -1; /* Return information */
 
-    FUNC_ENTER_NOAPI((-1))
+    FUNC_ENTER_PACKAGE
 
     /* Check arguments. */
     HDassert(bt2);
 
     /* Get information abou the node */
-    if (H5B2_get_node_info_test(bt2, dxpl_id, udata, &ninfo) < 0)
+    if (H5B2__get_node_info_test(bt2, udata, &ninfo) < 0)
         HGOTO_ERROR(H5E_BTREE, H5E_NOTFOUND, (-1), "error looking up node info")
 
     /* Set return value */
-    ret_value = ninfo.depth;
+    ret_value = (int)ninfo.depth;
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
-} /* H5B2_get_node_depth_test() */
+} /* H5B2__get_node_depth_test() */
