@@ -1,6 +1,5 @@
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
  * Copyright by The HDF Group.                                               *
- * Copyright by the Board of Trustees of the University of Illinois.         *
  * All rights reserved.                                                      *
  *                                                                           *
  * This file is part of HDF5.  The full HDF5 copyright notice, including     *
@@ -27,10 +26,19 @@
 
 #include "H5private.h"   /* Generic Functions			*/
 #include "H5CSprivate.h" /* Function stack			*/
-#include "H5MMprivate.h" /* Memory management			*/
+#include "H5Eprivate.h"  /* Error handling		  	*/
 
 #ifdef H5_HAVE_CODESTACK
 
+#define H5CS_MIN_NSLOTS 16 /* Minimum number of records in an function stack	*/
+
+/* A function stack */
+typedef struct H5CS_t {
+    unsigned     nused;  /* Number of records currently used in stack */
+    unsigned     nalloc; /* Number of records current allocated for stack */
+    const char **rec;    /* Array of function records */
+} H5CS_t;
+
 #ifdef H5_HAVE_THREADSAFE
 /*
  * The per-thread function stack. pthread_once() initializes a special
@@ -38,11 +46,11 @@
  * each thread individually. The association of stacks to threads will
  * be handled by the pthread library.
  *
- * In order for this macro to work, H5CS_get_my_stack() must be preceeded
+ * In order for this macro to work, H5CS_get_my_stack() must be preceded
  * by "H5CS_t *fstack =".
  */
-static H5CS_t *H5CS_get_stack(void);
-#define H5CS_get_my_stack() H5CS_get_stack()
+static H5CS_t *H5CS__get_stack(void);
+#define H5CS_get_my_stack() H5CS__get_stack()
 #else /* H5_HAVE_THREADSAFE */
 /*
  * The function stack.  Eventually we'll have some sort of global table so each
@@ -54,7 +62,7 @@ H5CS_t H5CS_stack_g[1];
 
 #ifdef H5_HAVE_THREADSAFE
 /*-------------------------------------------------------------------------
- * Function:	H5CS_get_stack
+ * Function:	H5CS__get_stack
  *
  * Purpose:	Support function for H5CS_get_my_stack() to initialize and
  *              acquire per-thread function stack.
@@ -69,11 +77,11 @@ H5CS_t H5CS_stack_g[1];
  *-------------------------------------------------------------------------
  */
 static H5CS_t *
-H5CS_get_stack(void)
+H5CS__get_stack(void)
 {
     H5CS_t *fstack;
 
-    FUNC_ENTER_NOAPI_NOERR_NOFS
+    FUNC_ENTER_PACKAGE_NOERR_NOFS
 
     fstack = H5TS_get_thread_local_value(H5TS_funcstk_key_g);
     if (!fstack) {
@@ -88,17 +96,19 @@ H5CS_get_stack(void)
         HDassert(fstack);
 
         /* Set the thread-specific info */
-        fstack->nused = 0;
+        fstack->nused  = 0;
+        fstack->nalloc = 0;
+        fstack->rec    = NULL;
 
         /* (It's not necessary to release this in this API, it is
          *      released by the "key destructor" set up in the H5TS
          *      routines.  See calls to pthread_key_create() in H5TS.c -QAK)
          */
         H5TS_set_thread_local_value(H5TS_funcstk_key_g, (void *)fstack);
-    }
+    } /* end if */
 
-    FUNC_LEAVE_NOAPI_NOFS(fstack);
-} /* end H5CS_get_stack() */
+    FUNC_LEAVE_NOAPI_NOFS(fstack)
+} /* end H5CS__get_stack() */
 #endif /* H5_HAVE_THREADSAFE */
 
 /*-------------------------------------------------------------------------
@@ -116,7 +126,7 @@ H5CS_get_stack(void)
 herr_t
 H5CS_print_stack(const H5CS_t *fstack, FILE *stream)
 {
-    const int indent = 2; /* Indention level */
+    const int indent = 2; /* Indentation level */
     int       i;          /* Local index ariable */
 
     /* Don't push this function on the function stack... :-) */
@@ -137,41 +147,11 @@ H5CS_print_stack(const H5CS_t *fstack, FILE *stream)
     HDfputc('\n', stream);
 
     for (i = fstack->nused - 1; i >= 0; --i)
-        HDfprintf(stream, "%*s#%03d: Routine: %s\n", indent, "", i, fstack->slot[i]);
+        HDfprintf(stream, "%*s#%03d: Routine: %s\n", indent, "", i, fstack->rec[i]);
 
-    FUNC_LEAVE_NOAPI_NOFS(SUCCEED);
+    FUNC_LEAVE_NOAPI_NOFS(SUCCEED)
 } /* end H5CS_print_stack() */
 
-/*-------------------------------------------------------------------------
- * Function:	H5CS_print
- *
- * Purpose:	Prints the default function stack in some default way.
- *
- * Return:	Non-negative on success/Negative on failure
- *
- * Programmer:	Quincey Koziol
- *              Thursday, February 6, 2003
- *
- * Modifications:
- *
- *-------------------------------------------------------------------------
- */
-herr_t
-H5CS_print(FILE *stream)
-{
-    H5CS_t *fstack = H5CS_get_my_stack(); /* Get the correct function stack */
-
-    /* Don't push this function on the function stack... :-) */
-    FUNC_ENTER_NOAPI_NOERR_NOFS
-
-    /* Sanity check */
-    HDassert(fstack);
-
-    H5CS_print_stack(fstack, stream);
-
-    FUNC_LEAVE_NOAPI_NOFS(SUCCEED);
-} /* end H5CS_print() */
-
 /*-------------------------------------------------------------------------
  * Function:	H5CS_push
  *
@@ -195,16 +175,27 @@ H5CS_push(const char *func_name)
 
     /* Sanity check */
     HDassert(fstack);
+    HDassert(fstack->nused <= fstack->nalloc);
     HDassert(func_name);
 
-    /*
-     * Push the function if there's room.  Otherwise just increment count
-     */
-    if (fstack->nused < H5CS_NSLOTS)
-        fstack->slot[fstack->nused] = func_name;
+    /* Check if we need to expand the stack of records */
+    if (fstack->nused == fstack->nalloc) {
+        size_t na = MAX((fstack->nalloc * 2), H5CS_MIN_NSLOTS);
+
+        /* Don't use H5MM_realloc here */
+        const char **x = (const char **)HDrealloc(fstack->rec, na * sizeof(const char *));
+
+        /* (Avoid returning an error from this routine, currently -QAK) */
+        HDassert(x);
+        fstack->rec    = x;
+        fstack->nalloc = na;
+    } /* end if */
+
+    /* Push the function name */
+    fstack->rec[fstack->nused] = func_name;
     fstack->nused++;
 
-    FUNC_LEAVE_NOAPI_NOFS(SUCCEED);
+    FUNC_LEAVE_NOAPI_NOFS(SUCCEED)
 } /* end H5CS_push() */
 
 /*-------------------------------------------------------------------------
@@ -249,30 +240,43 @@ H5CS_pop(void)
  *
  *-------------------------------------------------------------------------
  */
-herr_t
-H5CS_copy_stack(H5CS_t *new_stack)
+H5CS_t *
+H5CS_copy_stack(void)
 {
-    H5CS_t  *old_stack = H5CS_get_my_stack();
-    unsigned u; /* Local index variable */
+    H5CS_t  *old_stack = H5CS_get_my_stack(); /* Existing function stack for library */
+    H5CS_t  *new_stack;                       /* New function stack, for copy */
+    unsigned u;                               /* Local index variable */
+    H5CS_t  *ret_value = NULL;                /* Return value */
 
     /* Don't push this function on the function stack... :-) */
-    FUNC_ENTER_NOAPI_NOERR_NOFS
+    FUNC_ENTER_NOAPI_NOFS
 
     /* Sanity check */
     HDassert(old_stack);
 
-    /* Copy old stack to new one, duplicating the strings */
-    for (u = 0; u < old_stack->nused; u++)
-        new_stack->slot[u] = H5MM_strdup(old_stack->slot[u]);
-    new_stack->nused = old_stack->nused;
+    /* Allocate a new stack */
+    /* (Don't use library allocate code, since this code stack supports it) */
+    if (NULL == (new_stack = HDcalloc(1, sizeof(H5CS_t))))
+        HGOTO_ERROR(H5E_RESOURCE, H5E_CANTALLOC, NULL, "can't allocate function stack")
+    if (NULL == (new_stack->rec = HDcalloc(old_stack->nused, sizeof(const char *))))
+        HGOTO_ERROR(H5E_RESOURCE, H5E_CANTALLOC, NULL, "can't allocate function stack records")
 
-    FUNC_LEAVE_NOAPI_NOFS(SUCCEED);
+    /* Copy pointers on old stack to new one */
+    /* (Strings don't need to be duplicated, they are statically allocated) */
+    HDmemcpy(new_stack->rec, old_stack->rec, sizeof(char *) * old_stack->nused);
+    new_stack->nused = new_stack->nalloc = old_stack->nused;
+
+    /* Set the return value */
+    ret_value = new_stack;
+
+done:
+    FUNC_LEAVE_NOAPI_NOFS(ret_value)
 } /* end H5CS_copy_stack() */
 
 /*-------------------------------------------------------------------------
  * Function:	H5CS_close_stack
  *
- * Purpose:	Closes a copy of a stack
+ * Purpose:	Closes and frees a copy of a stack
  *
  * Return:	Non-negative on success/Negative on failure
  *
@@ -292,11 +296,18 @@ H5CS_close_stack(H5CS_t *stack)
     /* Sanity check */
     HDassert(stack);
 
-    /* Free strings on stack */
-    for (u = 0; u < stack->nused; u++)
-        stack->slot[u] = H5MM_xfree((void *)stack->slot[u]);
+    /* Free stack */
+    /* The function name string are statically allocated (by the compiler)
+     * and are not allocated, so there's no need to free them.
+     */
+    if (stack->rec) {
+        HDfree(stack->rec);
+        stack->rec = NULL;
+    } /* end if */
+    if (stack)
+        HDfree(stack);
 
-    FUNC_LEAVE_NOAPI_NOFS(SUCCEED);
+    FUNC_LEAVE_NOAPI_NOFS(SUCCEED)
 } /* end H5CS_close_stack() */
 
 #endif /* H5_HAVE_CODESTACK */
