@@ -24,9 +24,6 @@
 #define H5FLprivate_H
 
 /* Public headers needed by this file */
-#ifdef LATER
-#include "H5FLpublic.h" /*API prototypes			     */
-#endif                  /* LATER */
 
 /* Private headers needed by this file */
 
