@@ -1,6 +1,5 @@
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
  * Copyright by The HDF Group.                                               *
- * Copyright by the Board of Trustees of the University of Illinois.         *
  * All rights reserved.                                                      *
  *                                                                           *
  * This file is part of HDF5.  The full HDF5 copyright notice, including     *
@@ -54,10 +53,10 @@
 /* Struct used by change name callback function */
 typedef struct H5G_names_t {
     H5G_names_op_t op;              /* Operation performed on file */
-    H5F_t *        src_file;        /* Top file in src location's mounted file hier. */
-    H5RS_str_t *   src_full_path_r; /* Source location's full path */
-    H5F_t *        dst_file;        /* Destination location's file */
-    H5RS_str_t *   dst_full_path_r; /* Destination location's full path */
+    H5F_t         *src_file;        /* Top file in src location's mounted file hier. */
+    H5RS_str_t    *src_full_path_r; /* Source location's full path */
+    H5F_t         *dst_file;        /* Destination location's file */
+    H5RS_str_t    *dst_full_path_r; /* Destination location's full path */
 } H5G_names_t;
 
 /* Info to pass to the iteration function when building name */
@@ -87,9 +86,6 @@ static int         H5G__name_replace_cb(void *obj_ptr, hid_t obj_id, void *key);
 /* Package Variables */
 /*********************/
 
-/* Declare extern the PQ free list for the wrapped strings */
-H5FL_BLK_EXTERN(str_buf);
-
 /*****************************/
 /* Library Private Variables */
 /*****************************/
@@ -147,10 +143,10 @@ H5G__component(const char *name, size_t *size_p)
 char *
 H5G_normalize(const char *name)
 {
-    char *   norm;             /* Pointer to the normalized string */
+    char    *norm;             /* Pointer to the normalized string */
     size_t   s, d;             /* Positions within the strings */
     unsigned last_slash;       /* Flag to indicate last character was a slash */
-    char *   ret_value = NULL; /* Return value */
+    char    *ret_value = NULL; /* Return value */
 
     FUNC_ENTER_NOAPI_NOINIT
 
@@ -215,7 +211,7 @@ H5G__common_path(const H5RS_str_t *fullpath_r, const H5RS_str_t *prefix_r)
     size_t      nchars1, nchars2;  /* Number of characters in components */
     htri_t      ret_value = FALSE; /* Return value */
 
-    FUNC_ENTER_STATIC_NOERR
+    FUNC_ENTER_PACKAGE_NOERR
 
     /* Get component of each name */
     fullpath = H5RS_get_str(fullpath_r);
@@ -274,45 +270,20 @@ done:
 static H5RS_str_t *
 H5G__build_fullpath(const char *prefix, const char *name)
 {
-    char *      full_path;        /* Full user path built */
-    size_t      orig_path_len;    /* Original length of the path */
-    size_t      path_len;         /* Length of the path */
-    size_t      name_len;         /* Length of the name */
-    unsigned    need_sep;         /* Flag to indicate if separator is needed */
     H5RS_str_t *ret_value = NULL; /* Return value */
 
-    FUNC_ENTER_STATIC
+    FUNC_ENTER_PACKAGE
 
     /* Sanity check */
     HDassert(prefix);
     HDassert(name);
 
-    /* Get the length of the prefix */
-    orig_path_len = path_len = HDstrlen(prefix);
-
-    /* Determine if there is a trailing separator in the name */
-    if (prefix[path_len - 1] == '/')
-        need_sep = 0;
-    else
-        need_sep = 1;
-
-    /* Add in the length needed for the '/' separator and the relative path */
-    name_len = HDstrlen(name);
-    path_len += name_len + need_sep;
-
-    /* Allocate space for the path */
-    if (NULL == (full_path = (char *)H5FL_BLK_MALLOC(str_buf, path_len + 1)))
-        HGOTO_ERROR(H5E_RESOURCE, H5E_NOSPACE, NULL, "memory allocation failed")
-
-    /* Build full path */
-    HDstrncpy(full_path, prefix, orig_path_len + 1);
-    if (need_sep)
-        HDstrncat(full_path, "/", (size_t)1);
-    HDstrncat(full_path, name, name_len);
-
-    /* Create reference counted string for path */
-    if (NULL == (ret_value = H5RS_own(full_path)))
-        HGOTO_ERROR(H5E_RESOURCE, H5E_NOSPACE, NULL, "memory allocation failed")
+    /* Create full path */
+    if (NULL == (ret_value = H5RS_create(prefix)))
+        HGOTO_ERROR(H5E_SYM, H5E_CANTCREATE, NULL, "can't create ref-counted string")
+    if (prefix[HDstrlen(prefix) - 1] != '/')
+        H5RS_aputc(ret_value, '/'); /* Add separator, if the prefix doesn't end in one */
+    H5RS_acat(ret_value, name);
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
@@ -474,9 +445,10 @@ H5G_name_copy(H5G_name_t *dst, const H5G_name_t *src, H5_copy_depth_t depth)
         dst->user_path_r = H5RS_dup(src->user_path_r);
     }
     else {
-        /* Discarding 'const' qualifier OK - QAK */
+        H5_GCC_CLANG_DIAG_OFF("cast-qual")
         H5G_name_reset((H5G_name_t *)src);
-    } /* end if */
+        H5_GCC_CLANG_DIAG_ON("cast-qual")
+    }
 
     FUNC_LEAVE_NOAPI(SUCCEED)
 } /* end H5G_name_copy() */
@@ -496,11 +468,10 @@ H5G_name_copy(H5G_name_t *dst, const H5G_name_t *src, H5_copy_depth_t depth)
  *
  *-------------------------------------------------------------------------
  */
-ssize_t
-H5G_get_name(const H5G_loc_t *loc, char *name /*out*/, size_t size, hbool_t *cached)
+herr_t
+H5G_get_name(const H5G_loc_t *loc, char *name /*out*/, size_t size, size_t *name_len, hbool_t *cached)
 {
-    ssize_t len       = 0;  /* Length of object's name */
-    ssize_t ret_value = -1; /* Return value */
+    herr_t ret_value = SUCCEED; /* Return value */
 
     FUNC_ENTER_NOAPI(FAIL)
 
@@ -509,14 +480,20 @@ H5G_get_name(const H5G_loc_t *loc, char *name /*out*/, size_t size, hbool_t *cac
 
     /* If the user path is available and it's not "hidden", use it */
     if (loc->path->user_path_r != NULL && loc->path->obj_hidden == 0) {
+        size_t len; /* Length of object's name */
+
         len = H5RS_len(loc->path->user_path_r);
 
         if (name) {
-            HDstrncpy(name, H5RS_get_str(loc->path->user_path_r), MIN((size_t)(len + 1), size));
-            if ((size_t)len >= size)
+            HDstrncpy(name, H5RS_get_str(loc->path->user_path_r), MIN((len + 1), size));
+            if (len >= size)
                 name[size - 1] = '\0';
         } /* end if */
 
+        /* Set name length, if requested */
+        if (name_len)
+            *name_len = len;
+
         /* Indicate that the name is cached, if requested */
         /* (Currently only used for testing - QAK, 2010/07/26) */
         if (cached)
@@ -524,7 +501,7 @@ H5G_get_name(const H5G_loc_t *loc, char *name /*out*/, size_t size, hbool_t *cac
     } /* end if */
     else if (!loc->path->obj_hidden) {
         /* Search for name of object */
-        if ((len = H5G_get_name_by_addr(loc->oloc->file, loc->oloc, name, size)) < 0)
+        if (H5G_get_name_by_addr(loc->oloc->file, loc->oloc, name, size, name_len) < 0)
             HGOTO_ERROR(H5E_SYM, H5E_CANTGET, FAIL, "can't determine name")
 
         /* Indicate that the name is _not_ cached, if requested */
@@ -533,9 +510,6 @@ H5G_get_name(const H5G_loc_t *loc, char *name /*out*/, size_t size, hbool_t *cac
             *cached = FALSE;
     } /* end else */
 
-    /* Set return value */
-    ret_value = len;
-
 done:
     FUNC_LEAVE_NOAPI(ret_value)
 } /* end H5G_get_name() */
@@ -623,7 +597,7 @@ H5G__name_move_path(H5RS_str_t **path_r_ptr, const char *full_suffix, const char
     size_t      full_suffix_len;     /* Length of full suffix */
     herr_t      ret_value = SUCCEED; /* Return value */
 
-    FUNC_ENTER_STATIC
+    FUNC_ENTER_PACKAGE
 
     /* Check arguments */
     HDassert(path_r_ptr && *path_r_ptr);
@@ -640,27 +614,23 @@ H5G__name_move_path(H5RS_str_t **path_r_ptr, const char *full_suffix, const char
     path_len        = HDstrlen(path);
     if (full_suffix_len < path_len) {
         const char *dst_suffix;        /* Destination suffix that changes */
-        size_t      dst_suffix_len;    /* Length of destination suffix */
         const char *src_suffix;        /* Source suffix that changes */
         size_t      path_prefix_len;   /* Length of path prefix */
         const char *path_prefix2;      /* 2nd prefix for path */
         size_t      path_prefix2_len;  /* Length of 2nd path prefix */
-        const char *common_prefix;     /* Common prefix for src & dst paths */
         size_t      common_prefix_len; /* Length of common prefix */
-        char *      new_path;          /* Pointer to new path */
-        size_t      new_path_len;      /* Length of new path */
+        H5RS_str_t *rs;                /* Ref-counted string for new path */
 
-        /* Compute path prefix before full suffix*/
+        /* Compute path prefix before full suffix */
         path_prefix_len = path_len - full_suffix_len;
 
         /* Determine the common prefix for src & dst paths */
-        common_prefix     = src_path;
         common_prefix_len = 0;
         /* Find first character that is different */
         while (*(src_path + common_prefix_len) == *(dst_path + common_prefix_len))
             common_prefix_len++;
         /* Back up to previous '/' */
-        while (*(common_prefix + common_prefix_len) != '/')
+        while (*(src_path + common_prefix_len) != '/')
             common_prefix_len--;
         /* Include '/' */
         common_prefix_len++;
@@ -669,33 +639,28 @@ H5G__name_move_path(H5RS_str_t **path_r_ptr, const char *full_suffix, const char
         src_suffix = src_path + (common_prefix_len - 1);
 
         /* Determine destination suffix */
-        dst_suffix     = dst_path + (common_prefix_len - 1);
-        dst_suffix_len = HDstrlen(dst_suffix);
+        dst_suffix = dst_path + (common_prefix_len - 1);
 
-        /* Compute path prefix before src suffix*/
+        /* Compute path prefix before src suffix */
         path_prefix2     = path;
         path_prefix2_len = path_prefix_len - HDstrlen(src_suffix);
 
-        /* Allocate space for the new path */
-        new_path_len = path_prefix2_len + dst_suffix_len + full_suffix_len;
-        if (NULL == (new_path = (char *)H5FL_BLK_MALLOC(str_buf, new_path_len + 1)))
-            HGOTO_ERROR(H5E_RESOURCE, H5E_NOSPACE, FAIL, "memory allocation failed")
+        /* Allocate new ref-counted string */
+        if (NULL == (rs = H5RS_create(NULL)))
+            HGOTO_ERROR(H5E_SYM, H5E_CANTCREATE, FAIL, "can't create ref-counted string")
 
         /* Create the new path */
-        if (path_prefix2_len > 0) {
-            HDstrncpy(new_path, path_prefix2, path_prefix2_len + 1);
-            HDstrncpy(new_path + path_prefix2_len, dst_suffix, dst_suffix_len + 1);
-        } /* end if */
-        else
-            HDstrncpy(new_path, dst_suffix, dst_suffix_len + 1);
+        if (path_prefix2_len > 0)
+            H5RS_ancat(rs, path_prefix2, path_prefix2_len);
+        H5RS_acat(rs, dst_suffix);
         if (full_suffix_len > 0)
-            HDstrncat(new_path, full_suffix, full_suffix_len);
+            H5RS_acat(rs, full_suffix);
 
         /* Release previous path */
         H5RS_decr(*path_r_ptr);
 
         /* Take ownership of the new full path */
-        *path_r_ptr = H5RS_own(new_path);
+        *path_r_ptr = rs;
     } /* end if */
 
 done:
@@ -719,13 +684,13 @@ static int
 H5G__name_replace_cb(void *obj_ptr, hid_t obj_id, void *key)
 {
     const H5G_names_t *names = (const H5G_names_t *)key; /* Get operation's information */
-    H5O_loc_t *        oloc;         /* Object location for object that the ID refers to */
-    H5G_name_t *       obj_path;     /* Pointer to group hier. path for obj */
-    H5F_t *            top_obj_file; /* Top file in object's mounted file hier. */
+    H5O_loc_t         *oloc;         /* Object location for object that the ID refers to */
+    H5G_name_t        *obj_path;     /* Pointer to group hier. path for obj */
+    H5F_t             *top_obj_file; /* Top file in object's mounted file hier. */
     hbool_t obj_in_child = FALSE;    /* Flag to indicate that the object is in the child mount hier. */
     herr_t  ret_value    = SUCCEED;  /* Return value */
 
-    FUNC_ENTER_STATIC
+    FUNC_ENTER_PACKAGE
 
     HDassert(obj_ptr);
 
@@ -766,6 +731,7 @@ H5G__name_replace_cb(void *obj_ptr, hid_t obj_id, void *key)
         case H5I_ERROR_MSG:
         case H5I_ERROR_STACK:
         case H5I_SPACE_SEL_ITER:
+        case H5I_EVENTSET:
         case H5I_NTYPES:
         default:
             HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, FAIL, "unknown data object")
@@ -812,33 +778,24 @@ H5G__name_replace_cb(void *obj_ptr, hid_t obj_id, void *key)
         case H5G_NAME_MOUNT:
             /* Check if object is in child mount hier. */
             if (obj_in_child) {
-                const char *full_path;     /* Full path of current object */
-                const char *src_path;      /* Full path of source object */
-                size_t      src_path_len;  /* Length of source full path */
-                char *      new_full_path; /* New full path of object */
-                size_t      new_full_len;  /* Length of new full path */
+                const char *full_path; /* Full path of current object */
+                const char *src_path;  /* Full path of source object */
+                H5RS_str_t *rs;        /* Ref-counted string for new path */
 
                 /* Get pointers to paths of interest */
-                full_path    = H5RS_get_str(obj_path->full_path_r);
-                src_path     = H5RS_get_str(names->src_full_path_r);
-                src_path_len = HDstrlen(src_path);
+                full_path = H5RS_get_str(obj_path->full_path_r);
+                src_path  = H5RS_get_str(names->src_full_path_r);
 
-                /* Build new full path */
-
-                /* Allocate space for the new full path */
-                new_full_len = src_path_len + HDstrlen(full_path);
-                if (NULL == (new_full_path = (char *)H5FL_BLK_MALLOC(str_buf, new_full_len + 1)))
-                    HGOTO_ERROR(H5E_RESOURCE, H5E_NOSPACE, FAIL, "memory allocation failed")
-
-                /* Create the new full path */
-                HDstrncpy(new_full_path, src_path, src_path_len + 1);
-                HDstrncat(new_full_path, full_path, new_full_len);
+                /* Create new full path */
+                if (NULL == (rs = H5RS_create(src_path)))
+                    HGOTO_ERROR(H5E_SYM, H5E_CANTCREATE, FAIL, "can't create ref-counted string")
+                H5RS_acat(rs, full_path);
 
                 /* Release previous full path */
                 H5RS_decr(obj_path->full_path_r);
 
                 /* Take ownership of the new full path */
-                obj_path->full_path_r = H5RS_own(new_full_path);
+                obj_path->full_path_r = rs;
             } /* end if */
             /* Object must be in parent mount file hier. */
             else {
@@ -858,36 +815,30 @@ H5G__name_replace_cb(void *obj_ptr, hid_t obj_id, void *key)
          */
         case H5G_NAME_UNMOUNT:
             if (obj_in_child) {
-                const char *full_path;       /* Full path of current object */
-                const char *full_suffix;     /* Full path after source path */
-                size_t      full_suffix_len; /* Length of full path after source path */
-                const char *src_path;        /* Full path of source object */
-                char *      new_full_path;   /* New full path of object */
+                const char *full_path;   /* Full path of current object */
+                const char *full_suffix; /* Full path after source path */
+                const char *src_path;    /* Full path of source object */
+                H5RS_str_t *rs;          /* Ref-counted string for new path */
 
                 /* Get pointers to paths of interest */
                 full_path = H5RS_get_str(obj_path->full_path_r);
                 src_path  = H5RS_get_str(names->src_full_path_r);
 
                 /* Construct full path suffix */
-                full_suffix     = full_path + HDstrlen(src_path);
-                full_suffix_len = HDstrlen(full_suffix);
+                full_suffix = full_path + HDstrlen(src_path);
 
-                /* Build new full path */
-
-                /* Create the new full path */
-                if (NULL == (new_full_path = (char *)H5FL_BLK_MALLOC(str_buf, full_suffix_len + 1)))
-                    HGOTO_ERROR(H5E_RESOURCE, H5E_NOSPACE, FAIL, "memory allocation failed")
-                HDstrncpy(new_full_path, full_suffix, full_suffix_len + 1);
+                /* Create new full path suffix */
+                if (NULL == (rs = H5RS_create(full_suffix)))
+                    HGOTO_ERROR(H5E_SYM, H5E_CANTCREATE, FAIL, "can't create ref-counted string")
 
                 /* Release previous full path */
                 H5RS_decr(obj_path->full_path_r);
 
                 /* Take ownership of the new full path */
-                obj_path->full_path_r = H5RS_own(new_full_path);
+                obj_path->full_path_r = rs;
 
                 /* Check if the object's user path should be invalidated */
-                if (obj_path->user_path_r &&
-                    HDstrlen(new_full_path) < (size_t)H5RS_len(obj_path->user_path_r)) {
+                if (obj_path->user_path_r && H5RS_len(rs) < H5RS_len(obj_path->user_path_r)) {
                     /* Free user path */
                     H5RS_decr(obj_path->user_path_r);
                     obj_path->user_path_r = NULL;
@@ -922,53 +873,42 @@ H5G__name_replace_cb(void *obj_ptr, hid_t obj_id, void *key)
         case H5G_NAME_MOVE: /* Link move case, check for relative names case */
             /* Check if the src object moved is in the current object's path */
             if (H5G__common_path(obj_path->full_path_r, names->src_full_path_r)) {
-                const char *full_path;       /* Full path of current object */
-                const char *full_suffix;     /* Suffix of full path, after src_path */
-                size_t      full_suffix_len; /* Length of suffix of full path after src_path*/
-                char *      new_full_path;   /* New full path of object */
-                size_t      new_full_len;    /* Length of new full path */
-                const char *src_path;        /* Full path of source object */
-                const char *dst_path;        /* Full path of destination object */
-                size_t      dst_path_len;    /* Length of destination's full path */
+                const char *full_path;   /* Full path of current object */
+                const char *full_suffix; /* Suffix of full path, after src_path */
+                const char *src_path;    /* Full path of source object */
+                const char *dst_path;    /* Full path of destination object */
+                H5RS_str_t *rs;          /* Ref-counted string for new path */
 
                 /* Sanity check */
                 HDassert(names->dst_full_path_r);
 
                 /* Get pointers to paths of interest */
-                full_path    = H5RS_get_str(obj_path->full_path_r);
-                src_path     = H5RS_get_str(names->src_full_path_r);
-                dst_path     = H5RS_get_str(names->dst_full_path_r);
-                dst_path_len = HDstrlen(dst_path);
+                full_path = H5RS_get_str(obj_path->full_path_r);
+                src_path  = H5RS_get_str(names->src_full_path_r);
+                dst_path  = H5RS_get_str(names->dst_full_path_r);
 
                 /* Make certain that the source and destination names are full (not relative) paths */
                 HDassert(*src_path == '/');
                 HDassert(*dst_path == '/');
 
                 /* Get pointer to "full suffix" */
-                full_suffix     = full_path + HDstrlen(src_path);
-                full_suffix_len = HDstrlen(full_suffix);
+                full_suffix = full_path + HDstrlen(src_path);
 
                 /* Update the user path, if one exists */
                 if (obj_path->user_path_r)
                     if (H5G__name_move_path(&(obj_path->user_path_r), full_suffix, src_path, dst_path) < 0)
                         HGOTO_ERROR(H5E_SYM, H5E_PATH, FAIL, "can't build user path name")
 
-                /* Build new full path */
-
-                /* Allocate space for the new full path */
-                new_full_len = dst_path_len + full_suffix_len;
-                if (NULL == (new_full_path = (char *)H5FL_BLK_MALLOC(str_buf, new_full_len + 1)))
-                    HGOTO_ERROR(H5E_RESOURCE, H5E_NOSPACE, FAIL, "memory allocation failed")
-
-                /* Create the new full path */
-                HDstrncpy(new_full_path, dst_path, dst_path_len + 1);
-                HDstrncat(new_full_path, full_suffix, full_suffix_len);
+                /* Create new full path */
+                if (NULL == (rs = H5RS_create(dst_path)))
+                    HGOTO_ERROR(H5E_SYM, H5E_CANTCREATE, FAIL, "can't create ref-counted string")
+                H5RS_acat(rs, full_suffix);
 
                 /* Release previous full path */
                 H5RS_decr(obj_path->full_path_r);
 
                 /* Take ownership of the new full path */
-                obj_path->full_path_r = H5RS_own(new_full_path);
+                obj_path->full_path_r = rs;
             } /* end if */
             break;
 
@@ -1146,7 +1086,7 @@ H5G__get_name_by_addr_cb(hid_t gid, const char *path, const H5L_info2_t *linfo,
     hbool_t          obj_found = FALSE;                 /* Object at 'path' found */
     herr_t           ret_value = H5_ITER_CONT;          /* Return value */
 
-    FUNC_ENTER_STATIC
+    FUNC_ENTER_PACKAGE
 
     /* Sanity check */
     HDassert(path);
@@ -1214,28 +1154,29 @@ done:
  *
  *-------------------------------------------------------------------------
  */
-ssize_t
-H5G_get_name_by_addr(H5F_t *f, const H5O_loc_t *loc, char *name, size_t size)
+herr_t
+H5G_get_name_by_addr(H5F_t *f, const H5O_loc_t *loc, char *name, size_t size, size_t *name_len)
 {
-    H5G_gnba_iter_t udata;             /* User data for iteration  */
-    H5G_loc_t       root_loc;          /* Root group's location    */
-    hbool_t         found_obj = FALSE; /* If we found the object   */
-    herr_t          status;            /* Status from iteration    */
-    ssize_t         ret_value = -1;    /* Return value             */
+    H5G_gnba_iter_t udata;               /* User data for iteration  */
+    size_t          len;                 /* Length of path name */
+    H5G_loc_t       root_loc;            /* Root group's location    */
+    hbool_t         found_obj = FALSE;   /* If we found the object   */
+    herr_t          status;              /* Status from iteration    */
+    herr_t          ret_value = SUCCEED; /* Return value             */
 
     /* Portably clear udata struct (before FUNC_ENTER) */
     HDmemset(&udata, 0, sizeof(udata));
 
-    FUNC_ENTER_NOAPI((-1))
+    FUNC_ENTER_NOAPI(FAIL)
 
     /* Construct a group location for root group of the file */
     if (H5G_root_loc(f, &root_loc) < 0)
-        HGOTO_ERROR(H5E_SYM, H5E_CANTGET, (-1), "can't get root group's location")
+        HGOTO_ERROR(H5E_SYM, H5E_CANTGET, FAIL, "can't get root group's location")
 
     /* Check for root group being the object looked for */
     if (root_loc.oloc->addr == loc->addr && root_loc.oloc->file == loc->file) {
         if (NULL == (udata.path = H5MM_strdup("")))
-            HGOTO_ERROR(H5E_SYM, H5E_CANTALLOC, (-1), "can't duplicate path string")
+            HGOTO_ERROR(H5E_SYM, H5E_CANTALLOC, FAIL, "can't duplicate path string")
         found_obj = TRUE;
     } /* end if */
     else {
@@ -1246,7 +1187,7 @@ H5G_get_name_by_addr(H5F_t *f, const H5O_loc_t *loc, char *name, size_t size)
         /* Visit all the links in the file */
         if ((status = H5G_visit(&root_loc, "/", H5_INDEX_NAME, H5_ITER_NATIVE, H5G__get_name_by_addr_cb,
                                 &udata)) < 0)
-            HGOTO_ERROR(H5E_SYM, H5E_BADITER, (-1), "group traversal failed while looking for object name")
+            HGOTO_ERROR(H5E_SYM, H5E_BADITER, FAIL, "group traversal failed while looking for object name")
         else if (status > 0)
             found_obj = TRUE;
     } /* end else */
@@ -1254,7 +1195,7 @@ H5G_get_name_by_addr(H5F_t *f, const H5O_loc_t *loc, char *name, size_t size)
     /* Check for finding the object */
     if (found_obj) {
         /* Set the length of the full path */
-        ret_value = (ssize_t)(HDstrlen(udata.path) + 1); /* Length of path + 1 (for "/") */
+        len = HDstrlen(udata.path) + 1; /* Length of path + 1 (for "/") */
 
         /* If there's a buffer provided, copy into it, up to the limit of its size */
         if (name) {
@@ -1264,12 +1205,16 @@ H5G_get_name_by_addr(H5F_t *f, const H5O_loc_t *loc, char *name, size_t size)
             /* Append the rest of the path */
             /* (less one character, for the initial path separator) */
             HDstrncat(name, udata.path, (size - 2));
-            if ((size_t)ret_value >= size)
+            if (len >= size)
                 name[size - 1] = '\0';
         } /* end if */
     }     /* end if */
     else
-        ret_value = 0;
+        len = 0;
+
+    /* Set path name length, if given */
+    if (name_len)
+        *name_len = len;
 
 done:
     /* Release resources */
