@@ -1,6 +1,5 @@
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
  * Copyright by The HDF Group.                                               *
- * Copyright by the Board of Trustees of the University of Illinois.         *
  * All rights reserved.                                                      *
  *                                                                           *
  * This file is part of HDF5.  The full HDF5 copyright notice, including     *
@@ -49,7 +48,7 @@
 
 /* User data for direct block debugging iterator callback */
 typedef struct {
-    FILE *   stream;      /* Stream for output */
+    FILE    *stream;      /* Stream for output */
     int      indent;      /* Indentation amount */
     int      fwidth;      /* Field width mount */
     haddr_t  dblock_addr; /* Direct block's address */
@@ -62,7 +61,7 @@ typedef struct {
 /* User data for free space section iterator callback */
 typedef struct {
     H5FS_t *fspace; /* Free space manager */
-    FILE *  stream; /* Stream for output */
+    FILE   *stream; /* Stream for output */
     int     indent; /* Indentation amount */
     int     fwidth; /* Field width mount */
 } H5HF_debug_iter_ud2_t;
@@ -140,7 +139,7 @@ H5HF_id_print(H5HF_t *fh, const void *_id, FILE *stream, int indent, int fwidth)
         id_type = 'T';
     } /* end if */
     else {
-        HDfprintf(stderr, "%s: Heap ID type not supported yet!\n", FUNC);
+        HDfprintf(stderr, "%s: Heap ID type not supported yet!\n", __func__);
         HGOTO_ERROR(H5E_HEAP, H5E_UNSUPPORTED, FAIL, "heap ID type not supported yet")
     } /* end else */
 
@@ -175,7 +174,7 @@ done:
 static herr_t
 H5HF__dtable_debug(const H5HF_dtable_t *dtable, FILE *stream, int indent, int fwidth)
 {
-    FUNC_ENTER_STATIC_NOERR
+    FUNC_ENTER_PACKAGE_NOERR
 
     /*
      * Check arguments.
@@ -373,7 +372,7 @@ done:
 static herr_t
 H5HF_dblock_debug_cb(H5FS_section_info_t *_sect, void *_udata)
 {
-    H5HF_free_section_t *  sect  = (H5HF_free_section_t *)_sect;    /* Section to dump info */
+    H5HF_free_section_t   *sect  = (H5HF_free_section_t *)_sect;    /* Section to dump info */
     H5HF_debug_iter_ud1_t *udata = (H5HF_debug_iter_ud1_t *)_udata; /* User data for callbacks */
     haddr_t                sect_start, sect_end;     /* Section's beginning and ending offsets */
     haddr_t                dblock_start, dblock_end; /* Direct block's beginning and ending offsets */
@@ -456,11 +455,11 @@ herr_t
 H5HF_dblock_debug(H5F_t *f, haddr_t addr, FILE *stream, int indent, int fwidth, haddr_t hdr_addr,
                   size_t block_size)
 {
-    H5HF_hdr_t *   hdr    = NULL;       /* Fractal heap header info */
+    H5HF_hdr_t    *hdr    = NULL;       /* Fractal heap header info */
     H5HF_direct_t *dblock = NULL;       /* Fractal heap direct block info */
     size_t         blk_prefix_size;     /* Size of prefix for block */
     size_t         amount_free;         /* Amount of free space in block */
-    uint8_t *      marker    = NULL;    /* Track free space for block */
+    uint8_t       *marker    = NULL;    /* Track free space for block */
     herr_t         ret_value = SUCCEED; /* Return value */
 
     FUNC_ENTER_NOAPI(FAIL)
@@ -690,7 +689,7 @@ herr_t
 H5HF_iblock_debug(H5F_t *f, haddr_t addr, FILE *stream, int indent, int fwidth, haddr_t hdr_addr,
                   unsigned nrows)
 {
-    H5HF_hdr_t *     hdr         = NULL;    /* Fractal heap header info */
+    H5HF_hdr_t      *hdr         = NULL;    /* Fractal heap header info */
     H5HF_indirect_t *iblock      = NULL;    /* Fractal heap direct block info */
     hbool_t          did_protect = FALSE;   /* Whether we protected the indirect block or not */
     herr_t           ret_value   = SUCCEED; /* Return value */
@@ -746,7 +745,7 @@ done:
 static herr_t
 H5HF_sects_debug_cb(H5FS_section_info_t *_sect, void *_udata)
 {
-    H5HF_free_section_t *  sect      = (H5HF_free_section_t *)_sect;    /* Section to dump info */
+    H5HF_free_section_t   *sect      = (H5HF_free_section_t *)_sect;    /* Section to dump info */
     H5HF_debug_iter_ud2_t *udata     = (H5HF_debug_iter_ud2_t *)_udata; /* User data for callbacks */
     herr_t                 ret_value = SUCCEED;                         /* Return value */
 
