@@ -24,6 +24,15 @@
 #include "H5Tpkg.h"      /* Datatypes            */
 #include "H5VMprivate.h" /* Vectors and arrays   */
 
+/* Variant boundary-checking macro, used here since H5Tdecode() doesn't take a
+ * size parameter so we need to ignore the bounds checks.
+ *
+ * This is a separate macro since we don't want to inflict that behavior on
+ * the rest of the library.
+ */
+#define H5_DTYPE_IS_BUFFER_OVERFLOW(skip, ptr, size, buffer_end)                                             \
+    (skip ? FALSE : ((ptr) + (size)-1) > (buffer_end))
+
 /* PRIVATE PROTOTYPES */
 static herr_t H5O__dtype_encode(H5F_t *f, uint8_t *p, const void *mesg);
 static void  *H5O__dtype_decode(H5F_t *f, H5O_t *open_oh, unsigned mesg_flags, unsigned *ioflags,
@@ -108,35 +117,46 @@ const H5O_msg_class_t H5O_MSG_DTYPE[1] = {{
 }};
 
 /*-------------------------------------------------------------------------
- * Function:	H5O__dtype_decode_helper
+ * Function:    H5O__dtype_decode_helper
  *
- * Purpose:	Decodes a datatype
+ * Purpose:     Decodes a datatype
  *
- * Return:	TRUE if we can upgrade the parent type's version even
+ * Return:      TRUE if we can upgrade the parent type's version even
  *                  with strict format checks
  *              FALSE if we cannot
- *              Negative on failure
- *
- * Programmer:	Robb Matzke
- *		Monday, December  8, 1997
- *
+ *              NEGATIVE on failure
  *-------------------------------------------------------------------------
  */
 static htri_t
-H5O__dtype_decode_helper(unsigned *ioflags /*in,out*/, const uint8_t **pp, H5T_t *dt)
+H5O__dtype_decode_helper(unsigned *ioflags /*in,out*/, const uint8_t **pp, H5T_t *dt, hbool_t skip,
+                         const uint8_t *p_end)
 {
-    unsigned flags, version;
-    unsigned i;
-    size_t   z;
-    htri_t   ret_value = FALSE; /* Return value */
+    unsigned flags;
+    unsigned version;
+    htri_t   ret_value = FALSE;
 
     FUNC_ENTER_PACKAGE
 
-    /* check args */
     HDassert(pp && *pp);
     HDassert(dt && dt->shared);
 
+    /* XXX NOTE!
+     *
+     * H5Tencode() does not take a buffer size, so normal bounds checking in
+     * that case is impossible.
+     *
+     * Instead of using our normal H5_IS_BUFFER_OVERFLOW macro, use
+     * H5_DTYPE_IS_BUFFER_OVERFLOW, which will skip the check when the
+     * we're decoding a buffer from H5Tconvert().
+     *
+     * Even if this is fixed at some point in the future, as long as we
+     * support the old, size-less API call, we will need to use the modified
+     * macros.
+     */
+
     /* Version, class & flags */
+    if (H5_DTYPE_IS_BUFFER_OVERFLOW(skip, *pp, 4, p_end))
+        HGOTO_ERROR(H5E_OHDR, H5E_OVERFLOW, FAIL, "ran off end of input buffer while decoding");
     UINT32DECODE(*pp, flags);
     version = (flags >> 4) & 0x0f;
     if (version < H5O_DTYPE_VERSION_1 || version > H5O_DTYPE_VERSION_LATEST)
@@ -146,6 +166,8 @@ H5O__dtype_decode_helper(unsigned *ioflags /*in,out*/, const uint8_t **pp, H5T_t
     flags >>= 8;
 
     /* Size */
+    if (H5_DTYPE_IS_BUFFER_OVERFLOW(skip, *pp, 4, p_end))
+        HGOTO_ERROR(H5E_OHDR, H5E_OVERFLOW, FAIL, "ran off end of input buffer while decoding");
     UINT32DECODE(*pp, dt->shared->size);
 
     /* Check for invalid datatype size */
@@ -161,6 +183,8 @@ H5O__dtype_decode_helper(unsigned *ioflags /*in,out*/, const uint8_t **pp, H5T_t
             dt->shared->u.atomic.lsb_pad  = (flags & 0x2) ? H5T_PAD_ONE : H5T_PAD_ZERO;
             dt->shared->u.atomic.msb_pad  = (flags & 0x4) ? H5T_PAD_ONE : H5T_PAD_ZERO;
             dt->shared->u.atomic.u.i.sign = (flags & 0x8) ? H5T_SGN_2 : H5T_SGN_NONE;
+            if (H5_DTYPE_IS_BUFFER_OVERFLOW(skip, *pp, 2 + 2, p_end))
+                HGOTO_ERROR(H5E_OHDR, H5E_OVERFLOW, FAIL, "ran off end of input buffer while decoding");
             UINT16DECODE(*pp, dt->shared->u.atomic.offset);
             UINT16DECODE(*pp, dt->shared->u.atomic.prec);
             break;
@@ -178,7 +202,7 @@ H5O__dtype_decode_helper(unsigned *ioflags /*in,out*/, const uint8_t **pp, H5T_t
                 /* VAX order if both 1st and 6th bits are turned on*/
                 if (flags & 0x40)
                     dt->shared->u.atomic.order = H5T_ORDER_VAX;
-            } /* end if */
+            }
             dt->shared->u.atomic.lsb_pad = (flags & 0x2) ? H5T_PAD_ONE : H5T_PAD_ZERO;
             dt->shared->u.atomic.msb_pad = (flags & 0x4) ? H5T_PAD_ONE : H5T_PAD_ZERO;
             dt->shared->u.atomic.u.f.pad = (flags & 0x8) ? H5T_PAD_ONE : H5T_PAD_ZERO;
@@ -197,21 +221,40 @@ H5O__dtype_decode_helper(unsigned *ioflags /*in,out*/, const uint8_t **pp, H5T_t
 
                 default:
                     HGOTO_ERROR(H5E_DATATYPE, H5E_UNSUPPORTED, FAIL, "unknown floating-point normalization")
-            } /* end switch */
+            }
             dt->shared->u.atomic.u.f.sign = (flags >> 8) & 0xff;
+
+            if (H5_DTYPE_IS_BUFFER_OVERFLOW(skip, *pp, 2 + 2, p_end))
+                HGOTO_ERROR(H5E_OHDR, H5E_OVERFLOW, FAIL, "ran off end of input buffer while decoding");
             UINT16DECODE(*pp, dt->shared->u.atomic.offset);
             UINT16DECODE(*pp, dt->shared->u.atomic.prec);
+
+            if (H5_DTYPE_IS_BUFFER_OVERFLOW(skip, *pp, 1 + 1, p_end))
+                HGOTO_ERROR(H5E_OHDR, H5E_OVERFLOW, FAIL, "ran off end of input buffer while decoding");
             dt->shared->u.atomic.u.f.epos  = *(*pp)++;
             dt->shared->u.atomic.u.f.esize = *(*pp)++;
-            HDassert(dt->shared->u.atomic.u.f.esize > 0);
+            if (dt->shared->u.atomic.u.f.esize == 0)
+                HGOTO_ERROR(H5E_DATATYPE, H5E_BADVALUE, FAIL, "exponent size can't be zero")
+
+            if (H5_DTYPE_IS_BUFFER_OVERFLOW(skip, *pp, 1 + 1, p_end))
+                HGOTO_ERROR(H5E_OHDR, H5E_OVERFLOW, FAIL, "ran off end of input buffer while decoding");
             dt->shared->u.atomic.u.f.mpos  = *(*pp)++;
             dt->shared->u.atomic.u.f.msize = *(*pp)++;
-            HDassert(dt->shared->u.atomic.u.f.msize > 0);
+            if (dt->shared->u.atomic.u.f.msize == 0)
+                HGOTO_ERROR(H5E_DATATYPE, H5E_BADVALUE, FAIL, "mantissa size can't be zero")
+
+            if (H5_DTYPE_IS_BUFFER_OVERFLOW(skip, *pp, 4, p_end))
+                HGOTO_ERROR(H5E_OHDR, H5E_OVERFLOW, FAIL, "ran off end of input buffer while decoding");
             UINT32DECODE(*pp, dt->shared->u.atomic.u.f.ebias);
             break;
 
-        case H5T_TIME: /* Time datatypes */
+        case H5T_TIME:
+            /*
+             * Time datatypes...
+             */
             dt->shared->u.atomic.order = (flags & 0x1) ? H5T_ORDER_BE : H5T_ORDER_LE;
+            if (H5_DTYPE_IS_BUFFER_OVERFLOW(skip, *pp, 2, p_end))
+                HGOTO_ERROR(H5E_OHDR, H5E_OVERFLOW, FAIL, "ran off end of input buffer while decoding");
             UINT16DECODE(*pp, dt->shared->u.atomic.prec);
             break;
 
@@ -236,22 +279,35 @@ H5O__dtype_decode_helper(unsigned *ioflags /*in,out*/, const uint8_t **pp, H5T_t
             dt->shared->u.atomic.order   = (flags & 0x1) ? H5T_ORDER_BE : H5T_ORDER_LE;
             dt->shared->u.atomic.lsb_pad = (flags & 0x2) ? H5T_PAD_ONE : H5T_PAD_ZERO;
             dt->shared->u.atomic.msb_pad = (flags & 0x4) ? H5T_PAD_ONE : H5T_PAD_ZERO;
+            if (H5_DTYPE_IS_BUFFER_OVERFLOW(skip, *pp, 2 + 2, p_end))
+                HGOTO_ERROR(H5E_OHDR, H5E_OVERFLOW, FAIL, "ran off end of input buffer while decoding");
             UINT16DECODE(*pp, dt->shared->u.atomic.offset);
             UINT16DECODE(*pp, dt->shared->u.atomic.prec);
             break;
 
-        case H5T_OPAQUE:
+        case H5T_OPAQUE: {
+            size_t z;
+
             /*
              * Opaque types...
              */
+
+            /* The opaque tag flag field must be aligned */
             z = flags & (H5T_OPAQUE_TAG_MAX - 1);
-            HDassert(0 == (z & 0x7)); /*must be aligned*/
+            if (0 != (z & 0x7))
+                HGOTO_ERROR(H5E_OHDR, H5E_BADVALUE, FAIL, "opaque flag field must be aligned")
+
             if (NULL == (dt->shared->u.opaque.tag = (char *)H5MM_malloc(z + 1)))
                 HGOTO_ERROR(H5E_RESOURCE, H5E_NOSPACE, FAIL, "memory allocation failed")
+
+            if (H5_DTYPE_IS_BUFFER_OVERFLOW(skip, *pp, z, p_end))
+                HGOTO_ERROR(H5E_OHDR, H5E_OVERFLOW, FAIL, "ran off end of input buffer while decoding");
             H5MM_memcpy(dt->shared->u.opaque.tag, *pp, z);
             dt->shared->u.opaque.tag[z] = '\0';
+
             *pp += z;
             break;
+        }
 
         case H5T_COMPOUND: {
             unsigned nmembs;           /* Number of compound members */
@@ -274,15 +330,39 @@ H5O__dtype_decode_helper(unsigned *ioflags /*in,out*/, const uint8_t **pp, H5T_t
                 HGOTO_ERROR(H5E_DATATYPE, H5E_CANTALLOC, FAIL, "memory allocation failed")
             dt->shared->u.compnd.nalloc = nmembs;
 
-            HDassert(dt->shared->u.compnd.memb_size == 0);
+            if (dt->shared->u.compnd.memb_size != 0)
+                HGOTO_ERROR(H5E_DATATYPE, H5E_BADVALUE, FAIL, "member size not initialized to zero")
 
             for (dt->shared->u.compnd.nmembs = 0; dt->shared->u.compnd.nmembs < nmembs;
                  dt->shared->u.compnd.nmembs++) {
-                unsigned ndims = 0;             /* Number of dimensions of the array field */
-                htri_t   can_upgrade;           /* Whether we can upgrade this type's version */
-                hsize_t  dim[H5O_LAYOUT_NDIMS]; /* Dimensions of the array */
-                H5T_t   *array_dt;              /* Temporary pointer to the array datatype */
-                H5T_t   *temp_type;             /* Temporary pointer to the field's datatype */
+
+                size_t   actual_name_length = 0; /* Actual length of name */
+                unsigned ndims              = 0; /* Number of dimensions of the array field */
+                htri_t   can_upgrade;            /* Whether we can upgrade this type's version */
+                hsize_t  dim[H5O_LAYOUT_NDIMS];  /* Dimensions of the array */
+                H5T_t   *array_dt;               /* Temporary pointer to the array datatype */
+                H5T_t   *temp_type;              /* Temporary pointer to the field's datatype */
+
+                /* Get the length of the field name */
+                if (!skip) {
+                    /* There is a realistic buffer end, so check bounds */
+
+                    size_t max = (size_t)(p_end - *pp + 1); /* Max possible name length */
+
+                    actual_name_length = HDstrnlen((const char *)*pp, max);
+                    if (actual_name_length == max)
+                        HGOTO_ERROR(H5E_OHDR, H5E_NOSPACE, FAIL, "field name not null terminated")
+                }
+                else {
+                    /* The buffer end can't be determined when it's an unbounded buffer
+                     * passed via H5Tdecode(), so don't bounds check and hope for
+                     * the best.
+                     */
+                    actual_name_length = HDstrlen((const char *)*pp);
+                }
+
+                if (H5_DTYPE_IS_BUFFER_OVERFLOW(skip, *pp, actual_name_length, p_end))
+                    HGOTO_ERROR(H5E_OHDR, H5E_OVERFLOW, FAIL, "ran off end of input buffer while decoding");
 
                 /* Decode the field name */
                 if (NULL == (dt->shared->u.compnd.memb[dt->shared->u.compnd.nmembs].name =
@@ -291,26 +371,45 @@ H5O__dtype_decode_helper(unsigned *ioflags /*in,out*/, const uint8_t **pp, H5T_t
                                 "can't duplicate compound member name string")
 
                 /* Version 3 of the datatype message eliminated the padding to multiple of 8 bytes */
-                if (version >= H5O_DTYPE_VERSION_3)
+                if (version >= H5O_DTYPE_VERSION_3) {
                     /* Advance past name, including null terminator */
-                    *pp += HDstrlen((const char *)*pp) + 1;
-                else
+                    if (H5_DTYPE_IS_BUFFER_OVERFLOW(skip, *pp, actual_name_length + 1, p_end))
+                        HGOTO_ERROR(H5E_OHDR, H5E_OVERFLOW, FAIL,
+                                    "ran off end of input buffer while decoding");
+                    *pp += actual_name_length + 1;
+                }
+                else {
                     /* Advance multiple of 8 w/ null terminator */
-                    *pp += ((HDstrlen((const char *)*pp) + 8) / 8) * 8;
+                    if (H5_DTYPE_IS_BUFFER_OVERFLOW(skip, *pp, ((actual_name_length + 8) / 8) * 8, p_end))
+                        HGOTO_ERROR(H5E_OHDR, H5E_OVERFLOW, FAIL,
+                                    "ran off end of input buffer while decoding");
+                    *pp += ((actual_name_length + 8) / 8) * 8;
+                }
 
                 /* Decode the field offset */
                 /* (starting with version 3 of the datatype message, use the minimum # of bytes required) */
-                if (version >= H5O_DTYPE_VERSION_3)
+                if (version >= H5O_DTYPE_VERSION_3) {
+                    if (H5_DTYPE_IS_BUFFER_OVERFLOW(skip, *pp, offset_nbytes, p_end))
+                        HGOTO_ERROR(H5E_OHDR, H5E_OVERFLOW, FAIL,
+                                    "ran off end of input buffer while decoding");
                     UINT32DECODE_VAR(*pp, dt->shared->u.compnd.memb[dt->shared->u.compnd.nmembs].offset,
                                      offset_nbytes)
-                else
+                }
+                else {
+                    if (H5_DTYPE_IS_BUFFER_OVERFLOW(skip, *pp, 4, p_end))
+                        HGOTO_ERROR(H5E_OHDR, H5E_OVERFLOW, FAIL,
+                                    "ran off end of input buffer while decoding");
                     UINT32DECODE(*pp, dt->shared->u.compnd.memb[dt->shared->u.compnd.nmembs].offset)
+                }
 
                 /* Older versions of the library allowed a field to have
                  * intrinsic 'arrayness'.  Newer versions of the library
                  * use the separate array datatypes. */
                 if (version == H5O_DTYPE_VERSION_1) {
                     /* Decode the number of dimensions */
+                    if (H5_DTYPE_IS_BUFFER_OVERFLOW(skip, *pp, 1, p_end))
+                        HGOTO_ERROR(H5E_OHDR, H5E_OVERFLOW, FAIL,
+                                    "ran off end of input buffer while decoding");
                     ndims = *(*pp)++;
 
                     /* Check that ndims is valid */
@@ -320,18 +419,31 @@ H5O__dtype_decode_helper(unsigned *ioflags /*in,out*/, const uint8_t **pp, H5T_t
                         HGOTO_ERROR(H5E_DATATYPE, H5E_BADTYPE, FAIL, "invalid number of dimensions for array")
                     }
 
-                    *pp += 3; /*reserved bytes */
+                    /* Skip reserved bytes */
+                    if (H5_DTYPE_IS_BUFFER_OVERFLOW(skip, *pp, 3, p_end))
+                        HGOTO_ERROR(H5E_OHDR, H5E_OVERFLOW, FAIL,
+                                    "ran off end of input buffer while decoding");
+                    *pp += 3;
 
                     /* Skip dimension permutation */
+                    if (H5_DTYPE_IS_BUFFER_OVERFLOW(skip, *pp, 4, p_end))
+                        HGOTO_ERROR(H5E_OHDR, H5E_OVERFLOW, FAIL,
+                                    "ran off end of input buffer while decoding");
                     *pp += 4;
 
                     /* Skip reserved bytes */
+                    if (H5_DTYPE_IS_BUFFER_OVERFLOW(skip, *pp, 4, p_end))
+                        HGOTO_ERROR(H5E_OHDR, H5E_OVERFLOW, FAIL,
+                                    "ran off end of input buffer while decoding");
                     *pp += 4;
 
                     /* Decode array dimension sizes */
-                    for (i = 0; i < 4; i++)
+                    if (H5_DTYPE_IS_BUFFER_OVERFLOW(skip, *pp, (4 * 4), p_end))
+                        HGOTO_ERROR(H5E_OHDR, H5E_OVERFLOW, FAIL,
+                                    "ran off end of input buffer while decoding");
+                    for (int i = 0; i < 4; i++)
                         UINT32DECODE(*pp, dim[i]);
-                } /* end if */
+                }
 
                 /* Allocate space for the field's datatype */
                 if (NULL == (temp_type = H5T__alloc())) {
@@ -341,14 +453,15 @@ H5O__dtype_decode_helper(unsigned *ioflags /*in,out*/, const uint8_t **pp, H5T_t
                 }
 
                 /* Decode the field's datatype information */
-                if ((can_upgrade = H5O__dtype_decode_helper(ioflags, pp, temp_type)) < 0) {
+                if ((can_upgrade = H5O__dtype_decode_helper(ioflags, pp, temp_type, skip, p_end)) < 0) {
                     dt->shared->u.compnd.memb[dt->shared->u.compnd.nmembs].name =
                         H5MM_xfree(dt->shared->u.compnd.memb[dt->shared->u.compnd.nmembs].name);
                     if (H5T_close_real(temp_type) < 0)
                         HDONE_ERROR(H5E_DATATYPE, H5E_CANTRELEASE, FAIL, "can't release datatype info")
                     HGOTO_ERROR(H5E_DATATYPE, H5E_CANTDECODE, FAIL, "unable to decode member type")
-                } /* end if */
-                HDassert(temp_type->shared->size > 0);
+                }
+                if (temp_type->shared->size == 0)
+                    HGOTO_ERROR(H5E_DATATYPE, H5E_CANTDECODE, FAIL, "type size can't be zero")
 
                 /* Upgrade the version if we can and it is necessary */
                 if (can_upgrade && temp_type->shared->version > version) {
@@ -356,7 +469,7 @@ H5O__dtype_decode_helper(unsigned *ioflags /*in,out*/, const uint8_t **pp, H5T_t
 
                     /* Pass "can_upgrade" flag down to parent type */
                     ret_value = TRUE;
-                } /* end if */
+                }
 
                 /* Go create the array datatype now, for older versions of the datatype message */
                 if (version == H5O_DTYPE_VERSION_1) {
@@ -371,7 +484,7 @@ H5O__dtype_decode_helper(unsigned *ioflags /*in,out*/, const uint8_t **pp, H5T_t
                                             "can't release datatype info")
                             HGOTO_ERROR(H5E_DATATYPE, H5E_CANTREGISTER, FAIL,
                                         "unable to create array datatype")
-                        } /* end if */
+                        }
 
                         /* Close the base type for the array */
                         if (H5T_close_real(temp_type) < 0) {
@@ -394,16 +507,15 @@ H5O__dtype_decode_helper(unsigned *ioflags /*in,out*/, const uint8_t **pp, H5T_t
                             /* Set the return value to indicate that we should freely
                              * upgrade parent types */
                             ret_value = TRUE;
-                        } /* end else */
-                    }     /* end if */
-                }         /* end if */
+                        }
+                    }
+                }
 
                 /* Keep track of the maximum member version found */
                 if (temp_type->shared->version > max_version)
                     max_version = temp_type->shared->version;
 
-                /*
-                 * Set the "force conversion" flag if VL datatype fields exist in this
+                /* Set the "force conversion" flag if VL datatype fields exist in this
                  * type or any component types
                  */
                 if (temp_type->shared->force_conv == TRUE)
@@ -416,29 +528,30 @@ H5O__dtype_decode_helper(unsigned *ioflags /*in,out*/, const uint8_t **pp, H5T_t
                 /* Set the field datatype (finally :-) */
                 dt->shared->u.compnd.memb[dt->shared->u.compnd.nmembs].type = temp_type;
 
-                /* Check if this field overlaps with a prior field */
-                /* (probably indicates that the file is corrupt) */
+                /* Check if this field overlaps with a prior field
+                 * (probably indicates that the file is corrupt)
+                 */
                 if (dt->shared->u.compnd.nmembs > 0 &&
                     dt->shared->u.compnd.memb[dt->shared->u.compnd.nmembs].offset < max_memb_pos) {
-                    for (i = 0; i < dt->shared->u.compnd.nmembs; i++)
+                    for (unsigned u = 0; u < dt->shared->u.compnd.nmembs; u++)
                         if ((dt->shared->u.compnd.memb[dt->shared->u.compnd.nmembs].offset >=
-                                 dt->shared->u.compnd.memb[i].offset &&
+                                 dt->shared->u.compnd.memb[u].offset &&
                              dt->shared->u.compnd.memb[dt->shared->u.compnd.nmembs].offset <
-                                 (dt->shared->u.compnd.memb[i].offset + dt->shared->u.compnd.memb[i].size)) ||
+                                 (dt->shared->u.compnd.memb[u].offset + dt->shared->u.compnd.memb[u].size)) ||
                             (dt->shared->u.compnd.memb[dt->shared->u.compnd.nmembs].offset <
-                                 dt->shared->u.compnd.memb[i].offset &&
+                                 dt->shared->u.compnd.memb[u].offset &&
                              (dt->shared->u.compnd.memb[dt->shared->u.compnd.nmembs].offset +
                               dt->shared->u.compnd.memb[dt->shared->u.compnd.nmembs].size) >
-                                 dt->shared->u.compnd.memb[i].offset))
+                                 dt->shared->u.compnd.memb[u].offset))
                             HGOTO_ERROR(H5E_DATATYPE, H5E_CANTDECODE, FAIL,
                                         "member overlaps with previous member")
-                } /* end if */
+                }
 
                 /* Update the maximum member position covered */
                 max_memb_pos =
                     MAX(max_memb_pos, (dt->shared->u.compnd.memb[dt->shared->u.compnd.nmembs].offset +
                                        dt->shared->u.compnd.memb[dt->shared->u.compnd.nmembs].size));
-            } /* end for */
+            }
 
             /* Check if the compound type is packed */
             H5T__update_packed(dt);
@@ -451,14 +564,17 @@ H5O__dtype_decode_helper(unsigned *ioflags /*in,out*/, const uint8_t **pp, H5T_t
                 /* We won't mark the message dirty since there were no
                  * errors in the file, simply type versions that we will no
                  * longer encode. */
-            } /* end if */
+            }
 
             /* Check that no member of this compound has a version greater
              * than the compound itself. */
             H5O_DTYPE_CHECK_VERSION(dt, version, max_version, ioflags, "compound", FAIL)
         } break;
 
-        case H5T_REFERENCE: /* Reference datatypes...  */
+        case H5T_REFERENCE:
+            /*
+             * Reference datatypes...
+             */
             dt->shared->u.atomic.order   = H5T_ORDER_NONE;
             dt->shared->u.atomic.prec    = 8 * dt->shared->size;
             dt->shared->u.atomic.offset  = 0;
@@ -501,7 +617,7 @@ H5O__dtype_decode_helper(unsigned *ioflags /*in,out*/, const uint8_t **pp, H5T_t
             nmembs = flags & 0xffff;
             if (NULL == (dt->shared->parent = H5T__alloc()))
                 HGOTO_ERROR(H5E_RESOURCE, H5E_CANTALLOC, FAIL, "can't allocate parent datatype")
-            if (H5O__dtype_decode_helper(ioflags, pp, dt->shared->parent) < 0)
+            if (H5O__dtype_decode_helper(ioflags, pp, dt->shared->parent, skip, p_end) < 0)
                 HGOTO_ERROR(H5E_DATATYPE, H5E_CANTDECODE, FAIL, "unable to decode parent datatype")
             if (dt->shared->parent->shared->size != dt->shared->size)
                 HGOTO_ERROR(H5E_DATATYPE, H5E_BADSIZE, FAIL, "ENUM datatype size does not match parent")
@@ -520,37 +636,74 @@ H5O__dtype_decode_helper(unsigned *ioflags /*in,out*/, const uint8_t **pp, H5T_t
             /* Names */
             for (dt->shared->u.enumer.nmembs = 0; dt->shared->u.enumer.nmembs < nmembs;
                  dt->shared->u.enumer.nmembs++) {
+
+                size_t actual_name_length = 0; /* Actual length of name */
+
+                /* Get the length of the enum name */
+                if (!skip) {
+                    /* There is a realistic buffer end, so check bounds */
+
+                    size_t max = (size_t)(p_end - *pp + 1); /* Max possible name length */
+
+                    actual_name_length = HDstrnlen((const char *)*pp, max);
+                    if (actual_name_length == max)
+                        HGOTO_ERROR(H5E_OHDR, H5E_NOSPACE, FAIL, "enum name not null terminated")
+                }
+                else {
+                    /* The buffer end can't be determined when it's an unbounded buffer
+                     * passed via H5Tdecode(), so don't bounds check and hope for
+                     * the best.
+                     */
+                    actual_name_length = HDstrlen((const char *)*pp);
+                }
+
+                if (H5_DTYPE_IS_BUFFER_OVERFLOW(skip, *pp, actual_name_length, p_end))
+                    HGOTO_ERROR(H5E_OHDR, H5E_OVERFLOW, FAIL, "ran off end of input buffer while decoding");
                 if (NULL == (dt->shared->u.enumer.name[dt->shared->u.enumer.nmembs] =
                                  H5MM_xstrdup((const char *)*pp)))
                     HGOTO_ERROR(H5E_RESOURCE, H5E_CANTCOPY, FAIL, "can't duplicate enum name string")
 
                 /* Version 3 of the datatype message eliminated the padding to multiple of 8 bytes */
-                if (version >= H5O_DTYPE_VERSION_3)
+                if (version >= H5O_DTYPE_VERSION_3) {
                     /* Advance past name, including null terminator */
-                    *pp += HDstrlen((const char *)*pp) + 1;
-                else
+                    if (H5_DTYPE_IS_BUFFER_OVERFLOW(skip, *pp, actual_name_length + 1, p_end))
+                        HGOTO_ERROR(H5E_OHDR, H5E_OVERFLOW, FAIL,
+                                    "ran off end of input buffer while decoding");
+                    *pp += actual_name_length + 1;
+                }
+                else {
                     /* Advance multiple of 8 w/ null terminator */
-                    *pp += ((HDstrlen((const char *)*pp) + 8) / 8) * 8;
-            } /* end for */
-            HDassert(dt->shared->u.enumer.nmembs == nmembs);
+                    if (H5_DTYPE_IS_BUFFER_OVERFLOW(skip, *pp, ((actual_name_length + 8) / 8) * 8, p_end))
+                        HGOTO_ERROR(H5E_OHDR, H5E_OVERFLOW, FAIL,
+                                    "ran off end of input buffer while decoding");
+                    *pp += ((actual_name_length + 8) / 8) * 8;
+                }
+            }
+            if (dt->shared->u.enumer.nmembs != nmembs)
+                HGOTO_ERROR(H5E_OHDR, H5E_OVERFLOW, FAIL, "incorrect number of enum members decoded");
 
             /* Values */
+            if (H5_DTYPE_IS_BUFFER_OVERFLOW(skip, *pp, nmembs * dt->shared->parent->shared->size, p_end))
+                HGOTO_ERROR(H5E_OHDR, H5E_OVERFLOW, FAIL, "ran off end of input buffer while decoding");
             H5MM_memcpy(dt->shared->u.enumer.value, *pp, nmembs * dt->shared->parent->shared->size);
             *pp += nmembs * dt->shared->parent->shared->size;
         } break;
 
-        case H5T_VLEN: /* Variable length datatypes...  */
+        case H5T_VLEN:
+            /*
+             * Variable length datatypes...
+             */
             /* Set the type of VL information, either sequence or string */
             dt->shared->u.vlen.type = (H5T_vlen_type_t)(flags & 0x0f);
             if (dt->shared->u.vlen.type == H5T_VLEN_STRING) {
                 dt->shared->u.vlen.pad  = (H5T_str_t)((flags >> 4) & 0x0f);
                 dt->shared->u.vlen.cset = (H5T_cset_t)((flags >> 8) & 0x0f);
-            } /* end if */
+            }
 
             /* Decode base type of VL information */
             if (NULL == (dt->shared->parent = H5T__alloc()))
                 HGOTO_ERROR(H5E_DATATYPE, H5E_NOSPACE, FAIL, "memory allocation failed")
-            if (H5O__dtype_decode_helper(ioflags, pp, dt->shared->parent) < 0)
+            if (H5O__dtype_decode_helper(ioflags, pp, dt->shared->parent, skip, p_end) < 0)
                 HGOTO_ERROR(H5E_DATATYPE, H5E_CANTDECODE, FAIL, "unable to decode VL parent type")
 
             /* Check if the parent of this vlen has a version greater than the
@@ -565,8 +718,13 @@ H5O__dtype_decode_helper(unsigned *ioflags /*in,out*/, const uint8_t **pp, H5T_t
                 HGOTO_ERROR(H5E_DATATYPE, H5E_CANTINIT, FAIL, "invalid datatype location")
             break;
 
-        case H5T_ARRAY: /* Array datatypes */
+        case H5T_ARRAY:
+            /*
+             * Array datatypes...
+             */
             /* Decode the number of dimensions */
+            if (H5_DTYPE_IS_BUFFER_OVERFLOW(skip, *pp, 1, p_end))
+                HGOTO_ERROR(H5E_OHDR, H5E_OVERFLOW, FAIL, "ran off end of input buffer while decoding");
             dt->shared->u.array.ndims = *(*pp)++;
 
             /* Double-check the number of dimensions */
@@ -574,23 +732,32 @@ H5O__dtype_decode_helper(unsigned *ioflags /*in,out*/, const uint8_t **pp, H5T_t
                 HGOTO_ERROR(H5E_DATATYPE, H5E_CANTLOAD, FAIL, "too many dimensions for array datatype")
 
             /* Skip reserved bytes, if version has them */
-            if (version < H5O_DTYPE_VERSION_3)
+            if (version < H5O_DTYPE_VERSION_3) {
+                if (H5_DTYPE_IS_BUFFER_OVERFLOW(skip, *pp, 3, p_end))
+                    HGOTO_ERROR(H5E_OHDR, H5E_OVERFLOW, FAIL, "ran off end of input buffer while decoding");
                 *pp += 3;
+            }
 
             /* Decode array dimension sizes & compute number of elements */
-            for (i = 0, dt->shared->u.array.nelem = 1; i < (unsigned)dt->shared->u.array.ndims; i++) {
-                UINT32DECODE(*pp, dt->shared->u.array.dim[i]);
-                dt->shared->u.array.nelem *= dt->shared->u.array.dim[i];
-            } /* end for */
+            dt->shared->u.array.nelem = 1;
+            if (H5_DTYPE_IS_BUFFER_OVERFLOW(skip, *pp, (dt->shared->u.array.ndims * 4), p_end))
+                HGOTO_ERROR(H5E_OHDR, H5E_OVERFLOW, FAIL, "ran off end of input buffer while decoding");
+            for (unsigned u = 0; u < dt->shared->u.array.ndims; u++) {
+                UINT32DECODE(*pp, dt->shared->u.array.dim[u]);
+                dt->shared->u.array.nelem *= dt->shared->u.array.dim[u];
+            }
 
             /* Skip array dimension permutations, if version has them */
-            if (version < H5O_DTYPE_VERSION_3)
+            if (version < H5O_DTYPE_VERSION_3) {
+                if (H5_DTYPE_IS_BUFFER_OVERFLOW(skip, *pp, (dt->shared->u.array.ndims * 4), p_end))
+                    HGOTO_ERROR(H5E_OHDR, H5E_OVERFLOW, FAIL, "ran off end of input buffer while decoding");
                 *pp += dt->shared->u.array.ndims * 4;
+            }
 
             /* Decode base type of array */
             if (NULL == (dt->shared->parent = H5T__alloc()))
                 HGOTO_ERROR(H5E_DATATYPE, H5E_NOSPACE, FAIL, "memory allocation failed")
-            if (H5O__dtype_decode_helper(ioflags, pp, dt->shared->parent) < 0)
+            if (H5O__dtype_decode_helper(ioflags, pp, dt->shared->parent, skip, p_end) < 0)
                 HGOTO_ERROR(H5E_DATATYPE, H5E_CANTDECODE, FAIL, "unable to decode array parent type")
 
             /* Check if the parent of this array has a version greater than the
@@ -600,8 +767,7 @@ H5O__dtype_decode_helper(unsigned *ioflags /*in,out*/, const uint8_t **pp, H5T_t
             /* There should be no array datatypes with version < 2. */
             H5O_DTYPE_CHECK_VERSION(dt, version, H5O_DTYPE_VERSION_2, ioflags, "array", FAIL)
 
-            /*
-             * Set the "force conversion" flag if a VL base datatype is used or
+            /* Set the "force conversion" flag if a VL base datatype is used or
              * or if any components of the base datatype are VL types.
              */
             if (dt->shared->parent->shared->force_conv == TRUE)
@@ -612,7 +778,7 @@ H5O__dtype_decode_helper(unsigned *ioflags /*in,out*/, const uint8_t **pp, H5T_t
         case H5T_NCLASSES:
         default:
             HGOTO_ERROR(H5E_DATATYPE, H5E_UNSUPPORTED, FAIL, "unknown datatype class found")
-    } /* end switch */
+    }
 
 done:
     /* Cleanup on error */
@@ -1150,27 +1316,36 @@ done:
     Pointer to the new message in native order on success, NULL on failure
  DESCRIPTION
         This function decodes the "raw" disk form of a simple datatype message
-    into a struct in memory native format.  The struct is allocated within this
-    function using malloc() and is returned to the caller.
+        into a struct in memory native format.  The struct is allocated within this
+        function using malloc() and is returned to the caller.
 --------------------------------------------------------------------------*/
 static void *
 H5O__dtype_decode(H5F_t H5_ATTR_UNUSED *f, H5O_t H5_ATTR_UNUSED *open_oh, unsigned H5_ATTR_UNUSED mesg_flags,
-                  unsigned *ioflags /*in,out*/, size_t H5_ATTR_UNUSED p_size, const uint8_t *p)
+                  unsigned *ioflags /*in,out*/, size_t p_size, const uint8_t *p)
 {
-    H5T_t *dt        = NULL;
-    void  *ret_value = NULL; /* Return value */
+    hbool_t        skip;
+    H5T_t         *dt        = NULL;
+    const uint8_t *p_end     = p + p_size - 1;
+    void          *ret_value = NULL;
 
     FUNC_ENTER_PACKAGE
 
-    /* check args */
+    HDassert(f);
     HDassert(p);
 
     /* Allocate datatype message */
     if (NULL == (dt = H5T__alloc()))
         HGOTO_ERROR(H5E_RESOURCE, H5E_NOSPACE, NULL, "memory allocation failed")
 
+    /* If we are decoding a buffer from H5Tdecode(), we won't have the size
+     * of the buffer and bounds checking will be impossible. In this case,
+     * the library will have set p_size to SIZE_MAX and we can use that
+     * as a signal to skip bounds checking.
+     */
+    skip = (p_size == SIZE_MAX ? TRUE : FALSE);
+
     /* Perform actual decode of message */
-    if (H5O__dtype_decode_helper(ioflags, &p, dt) < 0)
+    if (H5O__dtype_decode_helper(ioflags, &p, dt, skip, p_end) < 0)
         HGOTO_ERROR(H5E_DATATYPE, H5E_CANTDECODE, NULL, "can't decode type")
 
     /* Set return value */
