@@ -839,7 +839,7 @@ bit.\n";
             fprintf(rawoutstream, " *\t\t\t");
     }
 
-    fprintf(rawoutstream, " *\n * Modifications:\n *\n");
+    fprintf(rawoutstream, " *\n");
     fprintf(rawoutstream, " *\tDO NOT MAKE MODIFICATIONS TO THIS FILE!\n");
     fprintf(rawoutstream, " *\tIt was generated by code in `H5detect.c'.\n");
 
