@@ -1,6 +1,5 @@
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
  * Copyright by The HDF Group.                                               *
- * Copyright by the Board of Trustees of the University of Illinois.         *
  * All rights reserved.                                                      *
  *                                                                           *
  * This file is part of HDF5.  The full HDF5 copyright notice, including     *
@@ -26,6 +25,9 @@
  */
 #ifdef H5_HAVE_WIN32_API
 
+/* __int64 is the correct type for the st_size field of the _stati64 struct.
+ * MSDN isn't very clear about this.
+ */
 typedef struct _stati64 h5_stat_t;
 typedef __int64         h5_stat_size_t;
 
@@ -50,15 +52,17 @@ struct timezone {
 #define HDgetcwd(S, Z)       _getcwd(S, Z)
 #define HDgetdcwd(D, S, Z)   _getdcwd(D, S, Z)
 #define HDgetdrive()         _getdrive()
-#define HDgetlogin()         Wgetlogin()
 #define HDgettimeofday(V, Z) Wgettimeofday(V, Z)
 #define HDisatty(F)          _isatty(F)
 #define HDlseek(F, O, W)     _lseeki64(F, O, W)
 #define HDlstat(S, B)        _lstati64(S, B)
-#define HDmemset(X, C, Z)    memset((void *)(X), C, Z) /* Cast avoids MSVC warning */
 #define HDmkdir(S, M)        _mkdir(S)
-#define HDnanosleep(N, O)    Wnanosleep(N, O)
-#define HDoff_t              __int64
+
+/* off_t exists on Windows, but is always a 32-bit long, even on 64-bit Windows,
+ * so we define HDoff_t to be __int64, which is the type of the st_size field
+ * of the _stati64 struct.
+ */
+#define HDoff_t __int64
 
 /* Note that the variadic HDopen macro is using a VC++ extension
  * where the comma is dropped if nothing is passed to the ellipsis.
@@ -77,7 +81,8 @@ struct timezone {
 #define HDsleep(S)            Sleep(S * 1000)
 #define HDstat(S, B)          _stati64(S, B)
 #define HDstrcasecmp(A, B)    _stricmp(A, B)
-#define HDstrdup(S)           _strdup(S)
+#define HDstrcasestr(A, B)    StrStrIA(A, B)
+#define HDstrndup(S, N)       H5_strndup(S, N)
 #define HDstrtok_r(X, Y, Z)   strtok_s(X, Y, Z)
 #define HDtzset()             _tzset()
 #define HDunlink(S)           _unlink(S)
@@ -92,15 +97,15 @@ struct timezone {
 #ifdef __cplusplus
 extern "C" {
 #endif /* __cplusplus */
-H5_DLL int    Wgettimeofday(struct timeval *tv, struct timezone *tz);
-H5_DLL int    Wsetenv(const char *name, const char *value, int overwrite);
-H5_DLL int    Wflock(int fd, int operation);
-H5_DLL char * Wgetlogin(void);
-H5_DLL herr_t H5_expand_windows_env_vars(char **env_var);
+H5_DLL int      Wgettimeofday(struct timeval *tv, struct timezone *tz);
+H5_DLL int      Wsetenv(const char *name, const char *value, int overwrite);
+H5_DLL int      Wflock(int fd, int operation);
+H5_DLL herr_t   H5_expand_windows_env_vars(char **env_var);
 H5_DLL wchar_t *H5_get_utf16_str(const char *s);
 H5_DLL int      Wopen_utf8(const char *path, int oflag, ...);
 H5_DLL int      Wremove_utf8(const char *path);
 H5_DLL int      H5_get_win32_times(H5_timevals_t *tvs);
+H5_DLL char    *H5_strndup(const char *s, size_t n);
 #ifdef __cplusplus
 }
 #endif /* __cplusplus */
