@@ -1,6 +1,5 @@
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
  * Copyright by The HDF Group.                                               *
- * Copyright by the Board of Trustees of the University of Illinois.         *
  * All rights reserved.                                                      *
  *                                                                           *
  * This file is part of HDF5.  The full HDF5 copyright notice, including     *
@@ -12,14 +11,14 @@
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 
 /*
- * Programmer:  Robb Matzke <matzke@llnl.gov>
+ * Programmer:  Robb Matzke
  *              Tuesday, June 16, 1998
  *
  * Purpose:	Tests functions in H5Tbit.c
  */
 #include "h5test.h"
 
-#define H5T_PACKAGE
+#define H5T_FRIEND /*suppress error about including H5Tpkg	  */
 #include "H5Tpkg.h"
 
 #define NTESTS 100000
@@ -38,8 +37,6 @@
  * Programmer:	Robb Matzke
  *              Tuesday, June 16, 1998
  *
- * Modifications:
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
@@ -155,8 +152,6 @@ failed:
  * Programmer:	Robb Matzke
  *              Tuesday, June 16, 1998
  *
- * Modifications:
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
@@ -281,8 +276,6 @@ failed:
  * Programmer:	Raymond Lu
  *              Monday, April 12, 2004
  *
- * Modifications:
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
@@ -420,8 +413,6 @@ failed:
  * Programmer:	Raymond Lu
  *              Monday, April 12, 2004
  *
- * Modifications:
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
@@ -511,8 +502,6 @@ failed:
  * Programmer:	Raymond Lu
  *              Monday, April 12, 2004
  *
- * Modifications:
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
@@ -585,8 +574,6 @@ failed:
  * Programmer:	Raymond Lu
  *              Monday, April 12, 2004
  *
- * Modifications:
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
@@ -689,8 +676,6 @@ failed:
  * Programmer:	Robb Matzke
  *              Tuesday, June 16, 1998
  *
- * Modifications:
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
@@ -809,8 +794,6 @@ failed:
  * Programmer:	Robb Matzke
  *              Tuesday, June 16, 1998
  *
- * Modifications:
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
@@ -918,13 +901,11 @@ failed:
 }
 
 /*-------------------------------------------------------------------------
- * Function:	main
+ * Function:    main
  *
  * Purpose:
  *
- * Return:	Success:
- *
- *		Failure:
+ * Return:      EXIT_SUCCESS/EXIT_FAILURE
  *
  * Programmer:	Robb Matzke
  *              Tuesday, June 16, 1998
@@ -952,11 +933,11 @@ main(void)
 
     if (nerrors) {
         HDprintf("***** %u FAILURE%s! *****\n", nerrors, 1 == nerrors ? "" : "S");
-        exit(EXIT_FAILURE);
+        HDexit(EXIT_FAILURE);
     }
     HDprintf("All bit tests passed.\n");
 
     H5close();
 
-    return 0;
-}
+    HDexit(EXIT_SUCCESS);
+} /* end main() */
