@@ -1,12 +1,11 @@
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
  * Copyright by The HDF Group.                                               *
- * Copyright by the Board of Trustees of the University of Illinois.         *
  * All rights reserved.                                                      *
  *                                                                           *
  * This file is part of HDF5.  The full HDF5 copyright notice, including     *
  * terms governing use, modification, and redistribution, is contained in    *
  * the COPYING file, which can be found at the root of the source code       *
- * distribution tree, or in https://support.hdfgroup.org/ftp/HDF5/releases.  *
+ * distribution tree, or in https://www.hdfgroup.org/licenses.               *
  * If you do not have access to either file, you may request a copy from     *
  * help@hdfgroup.org.                                                        *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
@@ -21,65 +20,64 @@
 #include "H5srcdir.h"
 
 #ifdef H5_USE_16_API
-int main(void)
+int
+main(void)
 {
     HDfprintf(stderr, "Test skipped because backward compatibility with v1.6 is configured in\n");
     return 0;
 }
 #else /* H5_USE_16_API */
 
-const char *FILENAME[] = {
-    "errors",
-    NULL
-};
+const char *FILENAME[] = {"errors", NULL};
 
 #define DATAFILE "filter_error"
 
-#define DIM0    100
-#define DIM1    200
+#define DIM0 100
+#define DIM1 200
 
-int    ipoints2[DIM0][DIM1], icheck2[DIM0][DIM1];
+int **ipoints2      = NULL;
+int **icheck2       = NULL;
+int  *ipoints2_data = NULL;
+int  *icheck2_data  = NULL;
 
-hid_t   ERR_CLS;
-hid_t   ERR_CLS2;
-hid_t   ERR_STACK;
+hid_t ERR_CLS;
+hid_t ERR_CLS2;
+hid_t ERR_STACK;
 
-hid_t   ERR_MAJ_TEST;
-hid_t   ERR_MAJ_IO;
-hid_t   ERR_MAJ_API;
+hid_t ERR_MAJ_TEST;
+hid_t ERR_MAJ_IO;
+hid_t ERR_MAJ_API;
 
-hid_t   ERR_MIN_SUBROUTINE;
-hid_t   ERR_MIN_ERRSTACK;
-hid_t   ERR_MIN_CREATE;
-hid_t   ERR_MIN_WRITE;
-hid_t   ERR_MIN_GETNUM;
+hid_t ERR_MIN_SUBROUTINE;
+hid_t ERR_MIN_ERRSTACK;
+hid_t ERR_MIN_CREATE;
+hid_t ERR_MIN_WRITE;
+hid_t ERR_MIN_GETNUM;
 
-#define DSET_NAME               "a_dataset"
-#define FAKE_ID                 (hid_t)0
+#define DSET_NAME "a_dataset"
+#define FAKE_ID   (hid_t)0
 
-#define ERR_CLS_NAME            "Error Test"
-#define ERR_CLS2_NAME           "Second Test"
-#define PROG_NAME               "Error Program"
-#define PROG2_NAME              "Second Program"
-#define PROG_VERS               "1.0"
+#define ERR_CLS_NAME  "Error Test"
+#define ERR_CLS2_NAME "Second Test"
+#define PROG_NAME     "Error Program"
+#define PROG2_NAME    "Second Program"
+#define PROG_VERS     "1.0"
 
-#define ERR_MAJ_TEST_MSG             "Error in test"
-#define ERR_MAJ_IO_MSG               "Error in IO"
-#define ERR_MAJ_API_MSG              "Error in API"
-#define ERR_MIN_SUBROUTINE_MSG       "Error in subroutine"
-#define ERR_MIN_ERRSTACK_MSG         "Error in error stack"
-#define ERR_MIN_CREATE_MSG           "Error in H5Dcreate2"
-#define ERR_MIN_WRITE_MSG            "Error in H5Dwrite"
-#define ERR_MIN_GETNUM_MSG           "Error in H5Eget_num"
+#define ERR_MAJ_TEST_MSG       "Error in test"
+#define ERR_MAJ_IO_MSG         "Error in IO"
+#define ERR_MAJ_API_MSG        "Error in API"
+#define ERR_MIN_SUBROUTINE_MSG "Error in subroutine"
+#define ERR_MIN_ERRSTACK_MSG   "Error in error stack"
+#define ERR_MIN_CREATE_MSG     "Error in H5Dcreate2"
+#define ERR_MIN_WRITE_MSG      "Error in H5Dwrite"
+#define ERR_MIN_GETNUM_MSG     "Error in H5Eget_num"
 
-#define MSG_SIZE                64
-#define LONG_DESC_SIZE          8192
+#define MSG_SIZE       64
+#define LONG_DESC_SIZE 8192
 
-#define DSET_FILTER_NAME    "dataset_with_filter"
-
-static herr_t custom_print_cb(unsigned n, const H5E_error2_t *err_desc,
-    void *client_data);
+#define DSET_FILTER_NAME "dataset_with_filter"
 
+static herr_t custom_print_cb(unsigned n, const H5E_error2_t *err_desc, void *client_data);
 
 /*-------------------------------------------------------------------------
  * Function:    test_error
@@ -94,13 +92,13 @@ static herr_t custom_print_cb(unsigned n, const H5E_error2_t *err_desc,
 static herr_t
 test_error(hid_t file)
 {
-    hid_t        dataset = -1;
-    hid_t       space = -1;
+    hid_t       dataset   = -1;
+    hid_t       space     = -1;
     hid_t       estack_id = -1;
-    hsize_t        dims[2];
-    const char          *FUNC_test_error = "test_error";
-    H5E_auto2_t         old_func;
-    void                *old_data = NULL;
+    hsize_t     dims[2];
+    const char *FUNC_test_error = "test_error";
+    H5E_auto2_t old_func;
+    void       *old_data = NULL;
 
     HDfprintf(stderr, "\nTesting error API based on data I/O\n");
 
@@ -111,12 +109,15 @@ test_error(hid_t file)
         TEST_ERROR;
 
     /* Test H5E_BEGIN_TRY */
-    H5E_BEGIN_TRY {
+    H5E_BEGIN_TRY
+    {
         dataset = H5Dcreate2(FAKE_ID, DSET_NAME, H5T_STD_I32BE, space, H5P_DEFAULT, H5P_DEFAULT, H5P_DEFAULT);
-    } H5E_END_TRY;
+    }
+    H5E_END_TRY;
 
     /* Create the dataset */
-    if ((dataset = H5Dcreate2(file, DSET_NAME, H5T_STD_I32BE, space, H5P_DEFAULT, H5P_DEFAULT, H5P_DEFAULT)) < 0) {
+    if ((dataset = H5Dcreate2(file, DSET_NAME, H5T_STD_I32BE, space, H5P_DEFAULT, H5P_DEFAULT, H5P_DEFAULT)) <
+        0) {
         H5Epush(H5E_DEFAULT, __FILE__, FUNC_test_error, __LINE__, ERR_CLS, ERR_MAJ_IO, ERR_MIN_CREATE,
                 "H5Dcreate2 failed");
         goto error;
@@ -127,13 +128,8 @@ test_error(hid_t file)
         TEST_ERROR;
     if (old_data != NULL)
         TEST_ERROR;
-#ifdef H5_USE_16_API
-    if (old_func != (H5E_auto_t)H5Eprint)
+    if (old_func == NULL)
         TEST_ERROR;
-#else /* H5_USE_16_API */
-    if (old_func != (H5E_auto2_t)H5Eprint2)
-        TEST_ERROR;
-#endif /* H5_USE_16_API */
 
     if (H5Eset_auto2(H5E_DEFAULT, NULL, NULL) < 0)
         TEST_ERROR;
@@ -160,16 +156,15 @@ test_error(hid_t file)
     }
 
     /* In case program comes to this point, close dataset */
-    if(H5Dclose(dataset) < 0)
+    if (H5Dclose(dataset) < 0)
         TEST_ERROR;
 
     TEST_ERROR;
 
-  error:
+error:
     return -1;
 } /* end test_error() */
 
-
 /*-------------------------------------------------------------------------
  * Function:    init_error
  *
@@ -183,23 +178,23 @@ test_error(hid_t file)
 static herr_t
 init_error(void)
 {
-    ssize_t cls_size = (ssize_t)HDstrlen(ERR_CLS_NAME) + 1;
-    ssize_t msg_size = (ssize_t)HDstrlen(ERR_MIN_SUBROUTINE_MSG) + 1;
-    char   *cls_name = NULL;
-    char   *msg = NULL;
+    ssize_t    cls_size = (ssize_t)HDstrlen(ERR_CLS_NAME) + 1;
+    ssize_t    msg_size = (ssize_t)HDstrlen(ERR_MIN_SUBROUTINE_MSG) + 1;
+    char      *cls_name = NULL;
+    char      *msg      = NULL;
     H5E_type_t msg_type;
 
     if (NULL == (cls_name = (char *)HDmalloc(HDstrlen(ERR_CLS_NAME) + 1)))
-        TEST_ERROR
+        TEST_ERROR;
     if (NULL == (msg = (char *)HDmalloc(HDstrlen(ERR_MIN_SUBROUTINE_MSG) + 1)))
-        TEST_ERROR
+        TEST_ERROR;
 
     if ((ERR_CLS = H5Eregister_class(ERR_CLS_NAME, PROG_NAME, PROG_VERS)) < 0)
         TEST_ERROR;
 
     if (cls_size != H5Eget_class_name(ERR_CLS, cls_name, (size_t)cls_size) + 1)
         TEST_ERROR;
-    if (HDstrcmp(ERR_CLS_NAME, cls_name))
+    if (HDstrcmp(ERR_CLS_NAME, cls_name) != 0)
         TEST_ERROR;
 
     if ((ERR_MAJ_TEST = H5Ecreate_msg(ERR_CLS, H5E_MAJOR, ERR_MAJ_TEST_MSG)) < 0)
@@ -224,7 +219,7 @@ init_error(void)
         TEST_ERROR;
     if (msg_type != H5E_MINOR)
         TEST_ERROR;
-    if (HDstrcmp(msg, ERR_MIN_SUBROUTINE_MSG))
+    if (HDstrcmp(msg, ERR_MIN_SUBROUTINE_MSG) != 0)
         TEST_ERROR;
 
     /* Register another class for later testing. */
@@ -245,7 +240,6 @@ error:
     return -1;
 } /* end init_error() */
 
-
 /*-------------------------------------------------------------------------
  * Function:    error_stack
  *
@@ -259,8 +253,8 @@ error:
 static herr_t
 error_stack(void)
 {
-    ssize_t err_num;
-    const char          *FUNC_error_stack = "error_stack";
+    ssize_t     err_num;
+    const char *FUNC_error_stack = "error_stack";
 
     if ((err_num = H5Eget_num(H5E_DEFAULT)) < 0)
         TEST_ERROR;
@@ -287,7 +281,6 @@ error:
     return -1;
 } /* end error_stack() */
 
-
 /*-------------------------------------------------------------------------
  * Function:    long_desc_cb
  *
@@ -301,7 +294,7 @@ error:
 static herr_t
 long_desc_cb(unsigned H5_ATTR_UNUSED n, const H5E_error2_t *err_desc, void *client_data)
 {
-    char *real_desc  = (char *)client_data;
+    char *real_desc = (char *)client_data;
 
     if (err_desc->desc != NULL && HDstrcmp(err_desc->desc, real_desc) == 0)
         return 0;
@@ -309,7 +302,6 @@ long_desc_cb(unsigned H5_ATTR_UNUSED n, const H5E_error2_t *err_desc, void *clie
         return -1;
 } /* end long_desc_cb() */
 
-
 /*-------------------------------------------------------------------------
  * Function:    test_long_desc
  *
@@ -326,15 +318,15 @@ long_desc_cb(unsigned H5_ATTR_UNUSED n, const H5E_error2_t *err_desc, void *clie
  *      'full_desc' in the code below, but early (4.4.7, at least) gcc only
  *      allows diagnostic pragmas to be toggled outside of functions.
  */
-H5_GCC_DIAG_OFF(format-nonliteral)
+H5_GCC_CLANG_DIAG_OFF("format-nonliteral")
 static herr_t
 test_long_desc(void)
 {
-    const char          *format = "Testing very long description string, %s";
-    char                *long_desc = NULL;
-    char                *full_desc = NULL;
-    size_t              u;
-    const char          *test_FUNC = "test_long_desc";
+    const char *format    = "Testing very long description string, %s";
+    char       *long_desc = NULL;
+    char       *full_desc = NULL;
+    size_t      u;
+    const char *test_FUNC = "test_long_desc";
 
     /* Allocate space for the error description info */
     if (NULL == (long_desc = (char *)HDmalloc(LONG_DESC_SIZE)))
@@ -352,7 +344,8 @@ test_long_desc(void)
         TEST_ERROR;
 
     /* Push an error with a long description */
-    if (H5Epush(H5E_DEFAULT, __FILE__, test_FUNC, __LINE__, ERR_CLS, ERR_MAJ_TEST, ERR_MIN_SUBROUTINE, format, long_desc) < 0)
+    if (H5Epush(H5E_DEFAULT, __FILE__, test_FUNC, __LINE__, ERR_CLS, ERR_MAJ_TEST, ERR_MIN_SUBROUTINE, format,
+                long_desc) < 0)
         TEST_ERROR;
 
     /* Create the string that should be in the description. Must use HDsnprintf here
@@ -381,8 +374,7 @@ error:
 
     return -1;
 } /* end test_long_desc() */
-H5_GCC_DIAG_ON(format-nonliteral)
-
+H5_GCC_CLANG_DIAG_ON("format-nonliteral")
 
 /*-------------------------------------------------------------------------
  * Function:    dump_error
@@ -413,7 +405,6 @@ error:
     return -1;
 } /* end dump_error() */
 
-
 /*-------------------------------------------------------------------------
  * Function:    custom_print_cb
  *
@@ -425,13 +416,13 @@ error:
  *-------------------------------------------------------------------------
  */
 static herr_t
-custom_print_cb(unsigned n, const H5E_error2_t *err_desc, void* client_data)
+custom_print_cb(unsigned n, const H5E_error2_t *err_desc, void *client_data)
 {
-    FILE                *stream  = (FILE *)client_data;
-    char                maj[MSG_SIZE];
-    char                min[MSG_SIZE];
-    char                cls[MSG_SIZE];
-    const int           indent = 4;
+    FILE     *stream = (FILE *)client_data;
+    char      maj[MSG_SIZE];
+    char      min[MSG_SIZE];
+    char      cls[MSG_SIZE];
+    const int indent = 4;
 
     /* Get descriptions for the major and minor error numbers */
     if (H5Eget_class_name(err_desc->cls_id, cls, MSG_SIZE) < 0)
@@ -443,9 +434,8 @@ custom_print_cb(unsigned n, const H5E_error2_t *err_desc, void* client_data)
     if (H5Eget_msg(err_desc->min_num, NULL, min, MSG_SIZE) < 0)
         TEST_ERROR;
 
-    HDfprintf(stream, "%*serror #%03d: %s in %s(): line %u\n",
-        indent, "", n, err_desc->file_name,
-        err_desc->func_name, err_desc->line);
+    HDfprintf(stream, "%*serror #%03d: %s in %s(): line %u\n", indent, "", n, err_desc->file_name,
+              err_desc->func_name, err_desc->line);
     HDfprintf(stream, "%*sclass: %s\n", indent * 2, "", cls);
     HDfprintf(stream, "%*smajor: %s\n", indent * 2, "", maj);
     HDfprintf(stream, "%*sminor: %s\n", indent * 2, "", min);
@@ -456,7 +446,6 @@ error:
     return -1;
 } /* end custom_print_cb() */
 
-
 /*-------------------------------------------------------------------------
  * Function:    test_create
  *
@@ -470,41 +459,42 @@ error:
 static herr_t
 test_create(void)
 {
-    const char *err_func = "test_create";       /* Function name for pushing error */
-    const char *err_msg = "Error message";      /* Error message for pushing error */
-    ssize_t     err_num;                        /* Number of errors on stack */
-    hid_t       estack_id = -1;                 /* Error stack ID */
+    const char *err_func = "test_create";   /* Function name for pushing error */
+    const char *err_msg  = "Error message"; /* Error message for pushing error */
+    ssize_t     err_num;                    /* Number of errors on stack */
+    hid_t       estack_id = -1;             /* Error stack ID */
 
     /* Create an empty error stack */
     if ((estack_id = H5Ecreate_stack()) < 0)
-        TEST_ERROR
+        TEST_ERROR;
 
     /* Check the number of errors on stack */
     err_num = H5Eget_num(estack_id);
     if (err_num != 0)
-        TEST_ERROR
+        TEST_ERROR;
 
     /* Push an error with a long description */
-    if (H5Epush(estack_id, __FILE__, err_func, __LINE__, ERR_CLS, ERR_MAJ_TEST, ERR_MIN_SUBROUTINE, "%s", err_msg) < 0)
+    if (H5Epush(estack_id, __FILE__, err_func, __LINE__, ERR_CLS, ERR_MAJ_TEST, ERR_MIN_SUBROUTINE, "%s",
+                err_msg) < 0)
         TEST_ERROR;
 
     /* Check the number of errors on stack */
     err_num = H5Eget_num(estack_id);
     if (err_num != 1)
-        TEST_ERROR
+        TEST_ERROR;
 
     /* Clear the error stack */
     if (H5Eclear2(estack_id) < 0)
-        TEST_ERROR
+        TEST_ERROR;
 
     /* Check the number of errors on stack */
     err_num = H5Eget_num(estack_id);
     if (err_num != 0)
-        TEST_ERROR
+        TEST_ERROR;
 
     /* Close error stack */
-    if(H5Eclose_stack(estack_id) < 0)
-        TEST_ERROR
+    if (H5Eclose_stack(estack_id) < 0)
+        TEST_ERROR;
 
     return 0;
 
@@ -515,7 +505,7 @@ error:
 /*-------------------------------------------------------------------------
  * Function:    test_copy
  *
- * Purpose:     Test copyinging an error stack
+ * Purpose:     Test copying an error stack
  *
  * Return:      Success:    0
  *              Failure:    -1
@@ -525,52 +515,55 @@ error:
 static herr_t
 test_copy(void)
 {
-    const char *err_func = "test_copy";         /* Function name for pushing error */
-    const char *err_msg = "Error message";      /* Error message for pushing error */
-    ssize_t     err_num;                        /* Number of errors on stack */
-    hid_t       estack_id = -1;                 /* Error stack ID */
-    herr_t      ret;                            /* Generic return value */
+    const char *err_func = "test_copy";     /* Function name for pushing error */
+    const char *err_msg  = "Error message"; /* Error message for pushing error */
+    ssize_t     err_num;                    /* Number of errors on stack */
+    hid_t       estack_id = -1;             /* Error stack ID */
+    herr_t      ret;                        /* Generic return value */
 
     /* Push an error with a long description */
-    if (H5Epush(H5E_DEFAULT, __FILE__, err_func, __LINE__, ERR_CLS, ERR_MAJ_TEST, ERR_MIN_SUBROUTINE, "%s", err_msg) < 0)
+    if (H5Epush(H5E_DEFAULT, __FILE__, err_func, __LINE__, ERR_CLS, ERR_MAJ_TEST, ERR_MIN_SUBROUTINE, "%s",
+                err_msg) < 0)
         TEST_ERROR;
 
     /* Check the number of errors on stack */
     err_num = H5Eget_num(H5E_DEFAULT);
     if (err_num != 1)
-        TEST_ERROR
+        TEST_ERROR;
 
     /* Copy error stack, which clears the original */
     if ((estack_id = H5Eget_current_stack()) < 0)
-        TEST_ERROR
+        TEST_ERROR;
 
     /* Check the number of errors on stack copy */
     err_num = H5Eget_num(estack_id);
     if (err_num != 1)
-        TEST_ERROR
+        TEST_ERROR;
 
     /* Check the number of errors on original stack */
     err_num = H5Eget_num(H5E_DEFAULT);
     if (err_num != 0)
-        TEST_ERROR
+        TEST_ERROR;
 
     /* Put the stack copy as the default.  It closes the stack copy, too. */
     if (H5Eset_current_stack(estack_id) < 0)
-        TEST_ERROR
+        TEST_ERROR;
 
     /* Check the number of errors on default stack */
     err_num = H5Eget_num(H5E_DEFAULT);
     if (err_num != 1)
-        TEST_ERROR
+        TEST_ERROR;
 
     /* Try to close error stack copy.  Should fail because
      * the current H5Eset_current_stack closes the stack to be set.
      */
-    H5E_BEGIN_TRY {
-       ret = H5Eclose_stack(estack_id);
-    } H5E_END_TRY
+    H5E_BEGIN_TRY
+    {
+        ret = H5Eclose_stack(estack_id);
+    }
+    H5E_END_TRY
     if (ret >= 0)
-        TEST_ERROR
+        TEST_ERROR;
 
     return 0;
 
@@ -578,6 +571,122 @@ error:
     return -1;
 } /* end test_copy() */
 
+/*-------------------------------------------------------------------------
+ * Function:    test_append
+ *
+ * Purpose:     Test appending one error stack to another
+ *
+ * Return:      Success:    0
+ *              Failure:    -1
+ *
+ *-------------------------------------------------------------------------
+ */
+static herr_t
+test_append(void)
+{
+    const char *err_func = "test_append";      /* Function name for pushing error */
+    const char *err_msg1 = "Error message #1"; /* Error message #1 for pushing error */
+    const char *err_msg2 = "Error message #2"; /* Error message #2 for pushing error */
+    ssize_t     err_num;                       /* Number of errors on stack */
+    hid_t       estack_id1 = -1;               /* Error stack ID */
+    hid_t       estack_id2 = -1;               /* Error stack ID */
+    herr_t      ret;                           /* Generic return value */
+
+    /* Push an error */
+    if (H5Epush(H5E_DEFAULT, __FILE__, err_func, __LINE__, ERR_CLS, ERR_MAJ_TEST, ERR_MIN_SUBROUTINE, "%s",
+                err_msg1) < 0)
+        TEST_ERROR;
+
+    /* Copy error stack, which clears the original */
+    if ((estack_id1 = H5Eget_current_stack()) < 0)
+        TEST_ERROR;
+
+    /* Check the number of errors on stack #1 */
+    err_num = H5Eget_num(estack_id1);
+    if (err_num != 1)
+        TEST_ERROR;
+
+    /* Create another stack, from scratch */
+    if ((estack_id2 = H5Ecreate_stack()) < 0)
+        TEST_ERROR;
+
+    /* Check the number of errors on stack #2 */
+    err_num = H5Eget_num(estack_id2);
+    if (err_num != 0)
+        TEST_ERROR;
+
+    /* Push an error on stack #2 */
+    if (H5Epush(estack_id2, __FILE__, err_func, __LINE__, ERR_CLS, ERR_MAJ_IO, ERR_MIN_CREATE, "%s",
+                err_msg2) < 0)
+        TEST_ERROR;
+
+    /* Check the number of errors on stack #2 */
+    err_num = H5Eget_num(estack_id2);
+    if (err_num != 1)
+        TEST_ERROR;
+
+    /* Try to append bad error stack IDs */
+    H5E_BEGIN_TRY
+    {
+        ret = H5Eappend_stack(H5E_DEFAULT, H5E_DEFAULT, FALSE);
+    }
+    H5E_END_TRY
+    if (ret >= 0)
+        TEST_ERROR;
+    H5E_BEGIN_TRY
+    {
+        ret = H5Eappend_stack(estack_id1, H5E_DEFAULT, FALSE);
+    }
+    H5E_END_TRY
+    if (ret >= 0)
+        TEST_ERROR;
+    H5E_BEGIN_TRY
+    {
+        ret = H5Eappend_stack(H5E_DEFAULT, estack_id2, FALSE);
+    }
+    H5E_END_TRY
+    if (ret >= 0)
+        TEST_ERROR;
+
+    /* Append error stack #2 to error stack #1, without closing stack #2 */
+    if (H5Eappend_stack(estack_id1, estack_id2, FALSE) < 0)
+        TEST_ERROR;
+
+    /* Check the number of errors on stack #1 */
+    err_num = H5Eget_num(estack_id1);
+    if (err_num != 2)
+        TEST_ERROR;
+
+    /* Check the number of errors on stack #2 */
+    err_num = H5Eget_num(estack_id2);
+    if (err_num != 1)
+        TEST_ERROR;
+
+    /* Append error stack #2 to error stack #1, and close stack #2 */
+    if (H5Eappend_stack(estack_id1, estack_id2, TRUE) < 0)
+        TEST_ERROR;
+
+    /* Try to close error stack #2.  Should fail because H5Eappend_stack
+     * should have already closed it.
+     */
+    H5E_BEGIN_TRY
+    {
+        ret = H5Eclose_stack(estack_id2);
+    }
+    H5E_END_TRY
+    if (ret >= 0)
+        TEST_ERROR;
+
+    /* Check the number of errors on stack #1 */
+    err_num = H5Eget_num(estack_id1);
+    if (err_num != 3)
+        TEST_ERROR;
+
+    return 0;
+
+error:
+    return -1;
+} /* end test_append() */
 
 /*-------------------------------------------------------------------------
  * Function:    close_error
@@ -614,7 +723,6 @@ error:
     return -1;
 } /* end close_error() */
 
-
 /*-------------------------------------------------------------------------
  * Function:    test_filter_error
  *
@@ -629,17 +737,17 @@ error:
  *-------------------------------------------------------------------------
  */
 static herr_t
-test_filter_error(const char *fname)
+test_filter_error(const char *fname, hid_t fapl)
 {
     const char *pathname = H5_get_srcdir_filename(fname); /* Corrected test file name */
-    hid_t       file = -1;
-    hid_t       dataset = -1;
+    hid_t       file     = -1;
+    hid_t       dataset  = -1;
     int         buf[20];
 
     HDfprintf(stderr, "\nTesting error message during data reading when filter isn't registered\n");
 
     /* Open the file */
-    if ((file = H5Fopen(pathname, H5F_ACC_RDONLY, H5P_DEFAULT)) < 0)
+    if ((file = H5Fopen(pathname, H5F_ACC_RDONLY, fapl)) < 0)
         TEST_ERROR;
 
     /* Open the regular dataset */
@@ -651,10 +759,10 @@ test_filter_error(const char *fname)
 
     /* Close/release resources */
     if (H5Dclose(dataset) < 0)
-        TEST_ERROR
+        TEST_ERROR;
 
     if (H5Fclose(file) < 0)
-        TEST_ERROR
+        TEST_ERROR;
 
     return 0;
 
@@ -662,7 +770,6 @@ error:
     return -1;
 } /* end test_filter_error() */
 
-
 /*-------------------------------------------------------------------------
  * Function:    main
  *
@@ -673,11 +780,18 @@ error:
 int
 main(void)
 {
-    hid_t       file = -1;
-    hid_t       fapl = -1;
+    hid_t       file      = -1;
+    hid_t       fapl      = -1;
     hid_t       estack_id = -1;
     char        filename[1024];
-    const char  *FUNC_main = "main";
+    const char *env_h5_drvr; /* File driver value from environment */
+    const char *FUNC_main = "main";
+    int         i;
+
+    /* Get the VFD to use */
+    env_h5_drvr = HDgetenv(HDF5_DRIVER);
+    if (env_h5_drvr == NULL)
+        env_h5_drvr = "nomatch";
 
     HDfprintf(stderr, "   This program tests the Error API.  There're supposed to be some error messages\n");
 
@@ -688,6 +802,21 @@ main(void)
     if ((fapl = h5_fileaccess()) < 0)
         TEST_ERROR;
 
+    /* Set up data arrays */
+    if (NULL == (ipoints2_data = (int *)HDcalloc(DIM0 * DIM1, sizeof(int))))
+        TEST_ERROR;
+    if (NULL == (ipoints2 = (int **)HDcalloc(DIM0, sizeof(ipoints2_data))))
+        TEST_ERROR;
+    for (i = 0; i < DIM0; i++)
+        ipoints2[i] = ipoints2_data + (i * DIM1);
+
+    if (NULL == (icheck2_data = (int *)HDcalloc(DIM0 * DIM1, sizeof(int))))
+        TEST_ERROR;
+    if (NULL == (icheck2 = (int **)HDcalloc(DIM0, sizeof(icheck2_data))))
+        TEST_ERROR;
+    for (i = 0; i < DIM0; i++)
+        icheck2[i] = icheck2_data + (i * DIM1);
+
     h5_fixname(FILENAME[0], fapl, filename, sizeof(filename));
     if ((file = H5Fcreate(filename, H5F_ACC_TRUNC, H5P_DEFAULT, fapl)) < 0)
         TEST_ERROR;
@@ -696,7 +825,7 @@ main(void)
     if (error_stack() < 0) {
         /* Push an error onto error stack */
         if (H5Epush(ERR_STACK, __FILE__, FUNC_main, __LINE__, ERR_CLS, ERR_MAJ_TEST, ERR_MIN_ERRSTACK,
-                "Error stack test failed") < 0)
+                    "Error stack test failed") < 0)
             TEST_ERROR;
 
         /* Delete an error from the top of error stack */
@@ -740,6 +869,10 @@ main(void)
     if (H5Fclose(file) < 0)
         TEST_ERROR;
 
+    /* Test appending error stacks */
+    if (test_append() < 0)
+        TEST_ERROR;
+
     /* Close error information */
     if (close_error() < 0)
         TEST_ERROR;
@@ -749,17 +882,34 @@ main(void)
      * the test file was pre-generated.
      */
     h5_fixname(DATAFILE, H5P_DEFAULT, filename, sizeof filename);
-    if (test_filter_error(filename) < 0)
+    if (!h5_using_default_driver(env_h5_drvr) && HDstrcmp(env_h5_drvr, "stdio")) {
+        /* If not using the library's default VFD or the stdio VFD, force
+         * the library's default VFD here. The test file was pre-generated
+         * and can cause issues with many VFDs.
+         */
+        if (H5Pset_driver(fapl, H5_DEFAULT_VFD, NULL) < 0)
+            TEST_ERROR;
+    }
+    if (test_filter_error(filename, fapl) < 0)
         TEST_ERROR;
 
     h5_clean_files(FILENAME, fapl);
 
+    HDfree(ipoints2);
+    HDfree(ipoints2_data);
+    HDfree(icheck2);
+    HDfree(icheck2_data);
+
     HDfprintf(stderr, "\nAll error API tests passed.\n");
     return 0;
 
 error:
+    HDfree(ipoints2);
+    HDfree(ipoints2_data);
+    HDfree(icheck2);
+    HDfree(icheck2_data);
+
     HDfprintf(stderr, "\n***** ERROR TEST FAILED (real problem)! *****\n");
     return 1;
 }
 #endif /* H5_USE_16_API */
-
