@@ -115,6 +115,13 @@ const char *LIBVER_NAMES[] = {"earliest", /* H5F_LIBVER_EARLIEST = 0  */
 /* Previous error reporting function */
 static H5E_auto2_t err_func = NULL;
 
+/* Global variables for testing */
+size_t   n_tests_run_g     = 0;
+size_t   n_tests_passed_g  = 0;
+size_t   n_tests_failed_g  = 0;
+size_t   n_tests_skipped_g = 0;
+uint64_t vol_cap_flags_g   = H5VL_CAP_FLAG_NONE;
+
 static herr_t h5_errors(hid_t estack, void *client_data);
 static char  *h5_fixname_real(const char *base_name, hid_t fapl, const char *_suffix, char *fullname,
                               size_t size, hbool_t nest_printf, hbool_t subst_for_superblock);
@@ -131,8 +138,6 @@ static char  *h5_fixname_real(const char *base_name, hid_t fapl, const char *_su
  * Programmer:  Robb Matzke
  *    Wednesday, March  4, 1998
  *
- * Modifications:
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
@@ -917,8 +922,6 @@ error:
  * Programmer:  Robb Matzke
  *              Friday, November 20, 1998
  *
- * Modifications:
- *
  *-------------------------------------------------------------------------
  */
 void
@@ -937,8 +940,6 @@ h5_no_hwconv(void)
  * Programmer:  Albert Cheng
  *              2002/04/22
  *
- * Modifications:
- *
  *-------------------------------------------------------------------------
  */
 void
@@ -1009,12 +1010,6 @@ h5_show_hostname(void)
  *              object.
  * Return:      0 if all is fine; otherwise non-zero.
  * Programmer:  Albert Cheng, 2002/05/21.
- * Modifications:
- *          Bill Wendling, 2002/05/31
- *          Modified so that the HDF5_MPI_INFO environment variable can
- *          be a semicolon separated list of "key=value" pairings. Most
- *          of the code is to remove any whitespaces which might be
- *          surrounding the "key=value" pairs.
  */
 int
 h5_set_info_object(void)
@@ -1108,7 +1103,6 @@ h5_set_info_object(void)
  * Purpose:     Display content of an MPI Info object
  * Return:      void
  * Programmer:  Albert Cheng 2002/05/21
- * Modifications:
  */
 void
 h5_dump_info_object(MPI_Info info)
@@ -1338,8 +1332,6 @@ print_func(const char *format, ...)
  *
  * Programmer:
  *
- * Modifications:
- *
  *-------------------------------------------------------------------------
  */
 int
@@ -1390,11 +1382,6 @@ h5_szip_can_encode(void)
  * Programmer:  Leon Arber
  *              4/4/05
  *
- * Modifications:
- *    Use original getenv if MPI is not initialized. This happens
- *    one uses the PHDF5 library to build a serial nature code.
- *    Albert 2006/04/07
- *
  *-------------------------------------------------------------------------
  */
 char *
@@ -1552,7 +1539,7 @@ h5_verify_cached_stabs_cb(hid_t oid, const char H5_ATTR_UNUSED *name, const H5O_
 /*-------------------------------------------------------------------------
  * Function:    h5_verify_cached_stabs
  *
- * Purpose:     Verify that all groups in every file in base_name have
+ * Purpose:     Verifies that all groups in every file in base_name have
  *              their symbol table information cached (if present, and if
  *              the parent group also uses a symbol table).  Does not
  *              check that the root group's symbol table information is
@@ -1565,8 +1552,6 @@ h5_verify_cached_stabs_cb(hid_t oid, const char H5_ATTR_UNUSED *name, const H5O_
  * Programmer:  Neil Fortner
  *              Tuesday, April 12, 2011
  *
- * Modifications:
- *
  *-------------------------------------------------------------------------
  */
 herr_t
