@@ -1,6 +1,5 @@
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
  * Copyright by The HDF Group.                                               *
- * Copyright by the Board of Trustees of the University of Illinois.         *
  * All rights reserved.                                                      *
  *                                                                           *
  * This file is part of HDF5.  The full HDF5 copyright notice, including     *
@@ -162,6 +161,9 @@ create_symbol_datatype(void)
  *              Buffer for the created name.  Must be pre-allocated.
  *              Since the name is formulaic, this isn't considered an issue.
  *
+ *              size_t name_buf_length
+ *              The length in bytes of the name_buf buffer
+ *
  *              unsigned level
  *              The dataset's level
  *
@@ -175,11 +177,11 @@ create_symbol_datatype(void)
  *-------------------------------------------------------------------------
  */
 int
-generate_name(char *name_buf, unsigned level, unsigned count)
+generate_name(char *name_buf, size_t name_buf_length, unsigned level, unsigned count)
 {
     HDassert(name_buf);
 
-    HDsprintf(name_buf, "%u-%04u", level, count);
+    HDsnprintf(name_buf, name_buf_length, "%u-%04u", level, count);
 
     return 0;
 } /* end generate_name() */
@@ -187,7 +189,7 @@ generate_name(char *name_buf, unsigned level, unsigned count)
 /*-------------------------------------------------------------------------
  * Function:    generate_symbols
  *
- * Purpose:     Initializes the global dataset infomration arrays.
+ * Purpose:     Initializes the global dataset information arrays.
  *
  * Parameters:  N/A
  *
@@ -202,13 +204,12 @@ generate_symbols(void)
     unsigned u, v; /* Local index variables */
 
     for (u = 0; u < NLEVELS; u++) {
-        symbol_info[u] = (symbol_info_t *)HDmalloc(symbol_count[u] * sizeof(symbol_info_t));
+        symbol_info[u] = HDmalloc(symbol_count[u] * sizeof(symbol_info_t));
         for (v = 0; v < symbol_count[u]; v++) {
             char name_buf[64];
 
-            generate_name(name_buf, u, v);
-            symbol_info[u][v].name = (char *)HDmalloc(HDstrlen(name_buf) + 1);
-            HDstrcpy(symbol_info[u][v].name, name_buf);
+            generate_name(name_buf, sizeof(name_buf), u, v);
+            symbol_info[u][v].name     = HDstrdup(name_buf);
             symbol_info[u][v].dsid     = -1;
             symbol_info[u][v].nrecords = 0;
         } /* end for */
