@@ -2244,5 +2244,9 @@ test_array(void)
 void
 cleanup_array(void)
 {
-    HDremove(FILENAME);
+    H5E_BEGIN_TRY
+    {
+        H5Fdelete(FILENAME, H5P_DEFAULT);
+    }
+    H5E_END_TRY;
 } /* end cleanup_array() */
