@@ -1,6 +1,5 @@
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
  * Copyright by The HDF Group.                                               *
- * Copyright by the Board of Trustees of the University of Illinois.         *
  * All rights reserved.                                                      *
  *                                                                           *
  * This file is part of HDF5.  The full HDF5 copyright notice, including     *
@@ -23,12 +22,14 @@
  *
  * Programmer: Albert Cheng
  *             September 20, 2009
- * Modifications:
- *   Added abort signal intercept. AKC - 2009/10/16 -
  */
 
 #include "h5test.h"
 
+#ifdef H5_HAVE_WIN32_API
+#include <crtdbg.h>
+#endif
+
 #define progname "tcheck_version"
 
 /* prototypes */
@@ -102,18 +103,37 @@ parse(int ac, char **av)
  * some systems may produce extra messages and/or produce core dump.
  * This tries to eliminate those side effects.
  */
-void
+H5_ATTR_NORETURN void
 abort_intercept(int H5_ATTR_UNUSED sig)
 {
     HDexit(6);
 }
 
+#ifdef H5_HAVE_WIN32_API
+/* Turns off the modal dialog that is raised when the Windows CRT calls abort().
+ *
+ * Returning TRUE here lets Windows know that we've handled the abort() and that there
+ * is no need to alert the user with a modal dialog box.
+ */
+int
+handle_crt_abort(int reportType, char *message, int *returnValue)
+{
+    return TRUE;
+}
+#endif
+
 int
 main(int ac, char **av)
 {
+#ifdef H5_HAVE_WIN32_API
+    (void)_CrtSetReportHook2(_CRT_RPTHOOK_INSTALL, handle_crt_abort);
+#endif
     parse(ac, av);
     HDsignal(SIGABRT, &abort_intercept);
     H5check_version(major, minor, release);
     HDsignal(SIGABRT, SIG_DFL);
+#ifdef H5_HAVE_WIN32_API
+    (void)_CrtSetReportHook2(_CRT_RPTHOOK_REMOVE, handle_crt_abort);
+#endif
     return 0;
 }
