@@ -30,11 +30,12 @@
 #include "H5FDsubfiling.h"
 #include "H5FDioc.h"
 
-#define SUBFILING_TEST_DIR H5FD_SUBFILING_NAME
-
 /* The smallest Subfiling stripe size used for testing */
 #define SUBFILING_MIN_STRIPE_SIZE 128
 
+/* Temporary test directory */
+#define SUBFILING_CONFIG_FILE_DIR "subfiling_config_file_dir"
+
 #ifndef PATH_MAX
 #define PATH_MAX 4096
 #endif
@@ -76,6 +77,8 @@ static long long stripe_size_g          = -1;
 static long      ioc_per_node_g         = -1;
 static int       ioc_thread_pool_size_g = -1;
 
+static char *config_dir = NULL;
+
 int nerrors      = 0;
 int curr_nerrors = 0;
 
@@ -90,6 +93,7 @@ static hid_t create_subfiling_ioc_fapl(MPI_Comm comm, MPI_Info info, hbool_t cus
 static void test_create_and_close(void);
 static void test_config_file(void);
 static void test_stripe_sizes(void);
+static void test_selection_strategies(void);
 static void test_read_different_stripe_size(void);
 static void test_subfiling_precreate_rank_0(void);
 static void test_subfiling_write_many_read_one(void);
@@ -100,6 +104,7 @@ static test_func tests[] = {
     test_create_and_close,
     test_config_file,
     test_stripe_sizes,
+    test_selection_strategies,
     test_read_different_stripe_size,
     test_subfiling_precreate_rank_0,
     test_subfiling_write_many_read_one,
@@ -279,8 +284,8 @@ test_config_file(void)
         config_filename = HDmalloc(PATH_MAX);
         VRFY(config_filename, "HDmalloc succeeded");
 
-        HDsnprintf(config_filename, PATH_MAX, H5FD_SUBFILING_CONFIG_FILENAME_TEMPLATE, SUBF_FILENAME,
-                   (uint64_t)file_info.st_ino);
+        HDsnprintf(config_filename, PATH_MAX, "%s/" H5FD_SUBFILING_CONFIG_FILENAME_TEMPLATE, config_dir,
+                   SUBF_FILENAME, (uint64_t)file_info.st_ino);
 
         config_file = HDfopen(config_filename, "r");
         VRFY(config_file, "HDfopen succeeded");
@@ -420,7 +425,10 @@ test_stripe_sizes(void)
     VRFY(tmp_filename, "HDmalloc succeeded");
 
     dxpl_id = H5Pcreate(H5P_DATASET_XFER);
-    VRFY((dxpl_id >= 0), "DCPL creation succeeded");
+    VRFY((dxpl_id >= 0), "DXPL creation succeeded");
+
+    /* Set selection I/O mode on DXPL */
+    VRFY((H5Pset_selection_io(dxpl_id, H5D_SELECTION_IO_MODE_ON) >= 0), "H5Pset_selection_io succeeded");
 
     for (size_t i = 0; i < SUBF_NITER; i++) {
         H5FD_subfiling_params_t cfg;
@@ -789,6 +797,200 @@ test_stripe_sizes(void)
 #undef SUBF_FILENAME
 #undef SUBF_NITER
 
+/*
+ * Test the different I/O Concentator selection strategies
+ * for the Subfiling VFD
+ */
+#define SUBF_FILENAME        "test_subfiling_selection_strategies.h5"
+#define NUM_RANKS_CHOICES    2
+#define NUM_CRITERIA_FORMATS 2
+static void
+test_selection_strategies(void)
+{
+    H5FD_subfiling_params_t cfg;
+    hid_t                   file_id      = H5I_INVALID_HID;
+    hid_t                   fapl_id      = H5I_INVALID_HID;
+    char                   *tmp_filename = NULL;
+
+    curr_nerrors = nerrors;
+
+    if (MAINPROCESS)
+        TESTING_2("I/O concentrator selection strategies");
+
+    tmp_filename = HDmalloc(PATH_MAX);
+    VRFY(tmp_filename, "HDmalloc succeeded");
+
+    for (H5FD_subfiling_ioc_select_t strategy = 0; strategy < ioc_selection_options; strategy++) {
+        /* Skip 1 IOC per node strategy since we assume it's
+         * the default strategy tested in this file. Skip
+         * "with config" strategy since it isn't supported.
+         */
+        if (strategy == SELECT_IOC_ONE_PER_NODE || strategy == SELECT_IOC_WITH_CONFIG)
+            continue;
+
+        /* Test with 1 MPI rank and then all MPI ranks */
+        for (size_t num_ranks_choice = 0; num_ranks_choice < NUM_RANKS_CHOICES; num_ranks_choice++) {
+            int num_active_ranks = mpi_size;
+
+            if (num_ranks_choice == 0)
+                num_active_ranks = 1;
+
+            /* Test with a selection strategy criteria string
+             * in the 'integer:[integer|string]' form and in
+             * the form of just a single value.
+             */
+            for (size_t criteria_format_choice = 0; criteria_format_choice < NUM_CRITERIA_FORMATS;
+                 criteria_format_choice++) {
+                MPI_Comm file_comm = comm_g;
+                char     criteria_buf[256];
+                char     sel_criteria[128]; /* Use char buffer for criteria as we may support
+                                               the "with config" strategy in the future */
+                int expected_num_subfiles;
+
+                cfg.ioc_selection = strategy;
+                cfg.stripe_size   = H5FD_SUBFILING_DEFAULT_STRIPE_SIZE;
+                cfg.stripe_count  = H5FD_SUBFILING_DEFAULT_STRIPE_COUNT;
+
+                switch (strategy) {
+                    case SELECT_IOC_EVERY_NTH_RANK: {
+                        int stride;
+
+                        /* Try to select a reasonable stride value */
+                        if (num_active_ranks <= 2)
+                            stride = 1;
+                        else if (num_active_ranks <= 8)
+                            stride = 2;
+                        else if (num_active_ranks <= 32)
+                            stride = 4;
+                        else if (num_active_ranks <= 128)
+                            stride = 8;
+                        else
+                            stride = 16;
+
+                        HDsnprintf(sel_criteria, 128, "%d", stride);
+
+                        expected_num_subfiles = ((num_active_ranks - 1) / stride) + 1;
+
+                        break;
+                    }
+
+                    case SELECT_IOC_TOTAL: {
+                        int n_iocs;
+
+                        /* Try to select a reasonable number of IOCs */
+                        if (num_active_ranks <= 2)
+                            n_iocs = 1;
+                        else if (num_active_ranks <= 8)
+                            n_iocs = 2;
+                        else if (num_active_ranks <= 32)
+                            n_iocs = 4;
+                        else if (num_active_ranks <= 128)
+                            n_iocs = 8;
+                        else
+                            n_iocs = 16;
+
+                        HDsnprintf(sel_criteria, 128, "%d", n_iocs);
+
+                        expected_num_subfiles = n_iocs;
+
+                        break;
+                    }
+
+                    case SELECT_IOC_ONE_PER_NODE:
+                    case SELECT_IOC_WITH_CONFIG:
+                    case ioc_selection_options:
+                    default:
+                        HDprintf("invalid IOC selection strategy\n");
+                        MPI_Abort(comm_g, -1);
+                }
+
+                if (criteria_format_choice == 0) {
+                    HDsnprintf(criteria_buf, 256, "%d:%s", strategy, sel_criteria);
+                }
+                else if (criteria_format_choice == 1) {
+                    HDsnprintf(criteria_buf, 256, "%s", sel_criteria);
+                }
+
+                VRFY(HDsetenv(H5FD_SUBFILING_IOC_SELECTION_CRITERIA, criteria_buf, 1) >= 0,
+                     "HDsetenv succeeded");
+
+                HDassert(num_active_ranks == mpi_size || num_active_ranks == 1);
+
+                if ((num_active_ranks == mpi_size) || (mpi_rank == 0)) {
+                    h5_stat_t file_info;
+                    FILE     *subfile_ptr;
+                    int       num_digits;
+
+                    if (num_active_ranks < mpi_size)
+                        file_comm = MPI_COMM_SELF;
+
+                    fapl_id = create_subfiling_ioc_fapl(file_comm, info_g, TRUE, &cfg,
+                                                        H5FD_IOC_DEFAULT_THREAD_POOL_SIZE);
+                    VRFY((fapl_id >= 0), "FAPL creation succeeded");
+
+                    file_id = H5Fcreate(SUBF_FILENAME, H5F_ACC_TRUNC, H5P_DEFAULT, fapl_id);
+                    VRFY((file_id >= 0), "H5Fcreate succeeded");
+
+                    /*
+                     * Get the file inode value so we can construct the subfile names
+                     */
+                    VRFY((HDstat(SUBF_FILENAME, &file_info) >= 0), "HDstat succeeded");
+
+                    num_digits = (int)(HDlog10(expected_num_subfiles) + 1);
+
+                    /* Ensure all the subfiles are present */
+                    for (int i = 0; i < expected_num_subfiles; i++) {
+                        HDsnprintf(tmp_filename, PATH_MAX, H5FD_SUBFILING_FILENAME_TEMPLATE, SUBF_FILENAME,
+                                   (uint64_t)file_info.st_ino, num_digits, i + 1, expected_num_subfiles);
+
+                        /* Ensure file exists */
+                        subfile_ptr = HDfopen(tmp_filename, "r");
+                        VRFY(subfile_ptr, "HDfopen on subfile succeeded");
+                        VRFY((HDfclose(subfile_ptr) >= 0), "HDfclose on subfile succeeded");
+                    }
+
+                    /* Ensure no extra subfiles are present */
+                    HDsnprintf(tmp_filename, PATH_MAX, H5FD_SUBFILING_FILENAME_TEMPLATE, SUBF_FILENAME,
+                               (uint64_t)file_info.st_ino, num_digits, expected_num_subfiles + 1,
+                               expected_num_subfiles);
+
+                    /* Ensure file doesn't exist */
+                    subfile_ptr = HDfopen(tmp_filename, "r");
+                    VRFY(subfile_ptr == NULL, "HDfopen on subfile correctly failed");
+
+                    VRFY((H5Fclose(file_id) >= 0), "File close succeeded");
+
+                    mpi_code_g = MPI_Barrier(file_comm);
+                    VRFY((mpi_code_g == MPI_SUCCESS), "MPI_Barrier succeeded");
+
+                    H5E_BEGIN_TRY
+                    {
+                        H5Fdelete(SUBF_FILENAME, fapl_id);
+                    }
+                    H5E_END_TRY;
+
+                    VRFY((H5Pclose(fapl_id) >= 0), "FAPL close succeeded");
+
+                    VRFY(HDunsetenv(H5FD_SUBFILING_IOC_SELECTION_CRITERIA) >= 0, "HDunsetenv succeeded");
+                }
+
+                mpi_code_g = MPI_Barrier(comm_g);
+                VRFY((mpi_code_g == MPI_SUCCESS), "MPI_Barrier succeeded");
+            }
+        }
+    }
+
+    mpi_code_g = MPI_Barrier(comm_g);
+    VRFY((mpi_code_g == MPI_SUCCESS), "MPI_Barrier succeeded");
+
+    HDfree(tmp_filename);
+
+    CHECK_PASSED();
+}
+#undef SUBF_FILENAME
+#undef NUM_RANKS_CHOICES
+#undef NUM_CRITERIA_FORMATS
+
 /*
  * Test that opening a file with a different stripe
  * size/count than was used when creating the file
@@ -812,12 +1014,19 @@ test_read_different_stripe_size(void)
     hid_t                   file_id      = H5I_INVALID_HID;
     hid_t                   fapl_id      = H5I_INVALID_HID;
     hid_t                   dset_id      = H5I_INVALID_HID;
+    hid_t                   dxpl_id      = H5I_INVALID_HID;
     hid_t                   fspace_id    = H5I_INVALID_HID;
     char                   *tmp_filename = NULL;
     void                   *buf          = NULL;
 
     curr_nerrors = nerrors;
 
+    dxpl_id = H5Pcreate(H5P_DATASET_XFER);
+    VRFY((dxpl_id >= 0), "DXPL creation succeeded");
+
+    /* Set selection I/O mode on DXPL */
+    VRFY((H5Pset_selection_io(dxpl_id, H5D_SELECTION_IO_MODE_ON) >= 0), "H5Pset_selection_io succeeded");
+
     if (MAINPROCESS)
         TESTING_2("file re-opening with different stripe size");
 
@@ -867,7 +1076,7 @@ test_read_different_stripe_size(void)
     for (size_t i = 0; i < count[0]; i++)
         ((SUBF_C_TYPE *)buf)[i] = (SUBF_C_TYPE)((size_t)mpi_rank + i);
 
-    VRFY((H5Dwrite(dset_id, SUBF_HDF5_TYPE, H5S_BLOCK, fspace_id, H5P_DEFAULT, buf) >= 0),
+    VRFY((H5Dwrite(dset_id, SUBF_HDF5_TYPE, H5S_BLOCK, fspace_id, dxpl_id, buf) >= 0),
          "Dataset write succeeded");
 
     HDfree(buf);
@@ -934,7 +1143,7 @@ test_read_different_stripe_size(void)
     buf = HDcalloc(1, count[0] * sizeof(SUBF_C_TYPE));
     VRFY(buf, "HDcalloc succeeded");
 
-    VRFY((H5Dread(dset_id, SUBF_HDF5_TYPE, H5S_BLOCK, fspace_id, H5P_DEFAULT, buf) >= 0),
+    VRFY((H5Dread(dset_id, SUBF_HDF5_TYPE, H5S_BLOCK, fspace_id, dxpl_id, buf) >= 0),
          "Dataset read succeeded");
 
     for (size_t i = 0; i < count[0]; i++) {
@@ -986,6 +1195,7 @@ test_read_different_stripe_size(void)
     }
     H5E_END_TRY;
 
+    VRFY((H5Pclose(dxpl_id) >= 0), "DXPL close succeeded");
     VRFY((H5Pclose(fapl_id) >= 0), "FAPL close succeeded");
 
     HDfree(tmp_filename);
@@ -1015,11 +1225,18 @@ test_subfiling_precreate_rank_0(void)
     hid_t   file_id   = H5I_INVALID_HID;
     hid_t   fapl_id   = H5I_INVALID_HID;
     hid_t   dset_id   = H5I_INVALID_HID;
+    hid_t   dxpl_id   = H5I_INVALID_HID;
     hid_t   fspace_id = H5I_INVALID_HID;
     void   *buf       = NULL;
 
     curr_nerrors = nerrors;
 
+    dxpl_id = H5Pcreate(H5P_DATASET_XFER);
+    VRFY((dxpl_id >= 0), "DXPL creation succeeded");
+
+    /* Set selection I/O mode on DXPL */
+    VRFY((H5Pset_selection_io(dxpl_id, H5D_SELECTION_IO_MODE_ON) >= 0), "H5Pset_selection_io succeeded");
+
     if (MAINPROCESS)
         TESTING_2("file pre-creation on rank 0");
 
@@ -1079,7 +1296,7 @@ test_subfiling_precreate_rank_0(void)
         for (size_t i = 0; i < dset_dims[0]; i++)
             ((SUBF_C_TYPE *)buf)[i] = (SUBF_C_TYPE)((i / n_elements_per_rank) + (i % n_elements_per_rank));
 
-        VRFY((H5Dwrite(dset_id, SUBF_HDF5_TYPE, H5S_BLOCK, fspace_id, H5P_DEFAULT, buf) >= 0),
+        VRFY((H5Dwrite(dset_id, SUBF_HDF5_TYPE, H5S_BLOCK, fspace_id, dxpl_id, buf) >= 0),
              "Dataset write succeeded");
 
         HDfree(buf);
@@ -1158,7 +1375,7 @@ test_subfiling_precreate_rank_0(void)
     buf = HDcalloc(1, count[0] * sizeof(SUBF_C_TYPE));
     VRFY(buf, "HDcalloc succeeded");
 
-    VRFY((H5Dread(dset_id, SUBF_HDF5_TYPE, H5S_BLOCK, fspace_id, H5P_DEFAULT, buf) >= 0),
+    VRFY((H5Dread(dset_id, SUBF_HDF5_TYPE, H5S_BLOCK, fspace_id, dxpl_id, buf) >= 0),
          "Dataset read succeeded");
 
     for (size_t i = 0; i < n_elements_per_rank; i++) {
@@ -1181,6 +1398,7 @@ test_subfiling_precreate_rank_0(void)
     H5E_END_TRY;
 
     VRFY((H5Pclose(fapl_id) >= 0), "FAPL close succeeded");
+    VRFY((H5Pclose(dxpl_id) >= 0), "DXPL close succeeded");
 
     CHECK_PASSED();
 }
@@ -1206,11 +1424,18 @@ test_subfiling_write_many_read_one(void)
     hid_t   file_id   = H5I_INVALID_HID;
     hid_t   fapl_id   = H5I_INVALID_HID;
     hid_t   dset_id   = H5I_INVALID_HID;
+    hid_t   dxpl_id   = H5I_INVALID_HID;
     hid_t   fspace_id = H5I_INVALID_HID;
     void   *buf       = NULL;
 
     curr_nerrors = nerrors;
 
+    dxpl_id = H5Pcreate(H5P_DATASET_XFER);
+    VRFY((dxpl_id >= 0), "DXPL creation succeeded");
+
+    /* Set selection I/O mode on DXPL */
+    VRFY((H5Pset_selection_io(dxpl_id, H5D_SELECTION_IO_MODE_ON) >= 0), "H5Pset_selection_io succeeded");
+
     if (MAINPROCESS)
         TESTING_2("reading back file with single MPI rank");
 
@@ -1262,7 +1487,7 @@ test_subfiling_write_many_read_one(void)
     for (size_t i = 0; i < count[0]; i++)
         ((SUBF_C_TYPE *)buf)[i] = (SUBF_C_TYPE)((size_t)mpi_rank + i);
 
-    VRFY((H5Dwrite(dset_id, SUBF_HDF5_TYPE, H5S_BLOCK, fspace_id, H5P_DEFAULT, buf) >= 0),
+    VRFY((H5Dwrite(dset_id, SUBF_HDF5_TYPE, H5S_BLOCK, fspace_id, dxpl_id, buf) >= 0),
          "Dataset write succeeded");
 
     HDfree(buf);
@@ -1287,7 +1512,7 @@ test_subfiling_write_many_read_one(void)
         buf = HDcalloc(1, target_size);
         VRFY(buf, "HDcalloc succeeded");
 
-        VRFY((H5Dread(dset_id, SUBF_HDF5_TYPE, H5S_BLOCK, H5S_ALL, H5P_DEFAULT, buf) >= 0),
+        VRFY((H5Dread(dset_id, SUBF_HDF5_TYPE, H5S_BLOCK, H5S_ALL, dxpl_id, buf) >= 0),
              "Dataset read succeeded");
 
         for (size_t i = 0; i < (size_t)mpi_size; i++) {
@@ -1317,6 +1542,7 @@ test_subfiling_write_many_read_one(void)
     VRFY((mpi_code_g == MPI_SUCCESS), "MPI_Barrier succeeded");
 
     VRFY((H5Sclose(fspace_id) >= 0), "File dataspace close succeeded");
+    VRFY((H5Pclose(dxpl_id) >= 0), "DXPL close succeeded");
 
     CHECK_PASSED();
 }
@@ -1344,11 +1570,18 @@ test_subfiling_write_many_read_few(void)
     hid_t    file_id   = H5I_INVALID_HID;
     hid_t    fapl_id   = H5I_INVALID_HID;
     hid_t    dset_id   = H5I_INVALID_HID;
+    hid_t    dxpl_id   = H5I_INVALID_HID;
     hid_t    fspace_id = H5I_INVALID_HID;
     void    *buf       = NULL;
 
     curr_nerrors = nerrors;
 
+    dxpl_id = H5Pcreate(H5P_DATASET_XFER);
+    VRFY((dxpl_id >= 0), "DXPL creation succeeded");
+
+    /* Set selection I/O mode on DXPL */
+    VRFY((H5Pset_selection_io(dxpl_id, H5D_SELECTION_IO_MODE_ON) >= 0), "H5Pset_selection_io succeeded");
+
     if (MAINPROCESS)
         TESTING_2("reading back file with fewer MPI ranks than written with");
 
@@ -1410,7 +1643,7 @@ test_subfiling_write_many_read_few(void)
     for (size_t i = 0; i < count[0]; i++)
         ((SUBF_C_TYPE *)buf)[i] = (SUBF_C_TYPE)((size_t)mpi_rank + i);
 
-    VRFY((H5Dwrite(dset_id, SUBF_HDF5_TYPE, H5S_BLOCK, fspace_id, H5P_DEFAULT, buf) >= 0),
+    VRFY((H5Dwrite(dset_id, SUBF_HDF5_TYPE, H5S_BLOCK, fspace_id, dxpl_id, buf) >= 0),
          "Dataset write succeeded");
 
     HDfree(buf);
@@ -1465,7 +1698,7 @@ test_subfiling_write_many_read_few(void)
         buf = HDcalloc(1, target_size);
         VRFY(buf, "HDcalloc succeeded");
 
-        VRFY((H5Dread(dset_id, SUBF_HDF5_TYPE, H5S_BLOCK, H5S_ALL, H5P_DEFAULT, buf) >= 0),
+        VRFY((H5Dread(dset_id, SUBF_HDF5_TYPE, H5S_BLOCK, H5S_ALL, dxpl_id, buf) >= 0),
              "Dataset read succeeded");
 
         for (size_t i = 0; i < (size_t)mpi_size; i++) {
@@ -1500,6 +1733,7 @@ test_subfiling_write_many_read_few(void)
     VRFY((mpi_code_g == MPI_SUCCESS), "MPI_Barrier succeeded");
 
     VRFY((H5Sclose(fspace_id) >= 0), "File dataspace close succeeded");
+    VRFY((H5Pclose(dxpl_id) >= 0), "DXPL close succeeded");
 
     CHECK_PASSED();
 }
@@ -1518,19 +1752,30 @@ test_subfiling_write_many_read_few(void)
 static void
 test_subfiling_h5fuse(void)
 {
-    hsize_t start[1];
-    hsize_t count[1];
-    hsize_t dset_dims[1];
-    size_t  target_size;
-    hid_t   file_id   = H5I_INVALID_HID;
-    hid_t   fapl_id   = H5I_INVALID_HID;
-    hid_t   dset_id   = H5I_INVALID_HID;
-    hid_t   fspace_id = H5I_INVALID_HID;
-    void   *buf       = NULL;
-    int     skip_test = 0;
+#if defined(H5_HAVE_FORK) && defined(H5_HAVE_WAITPID)
+    h5_stat_t file_info;
+    uint64_t  file_inode;
+    hsize_t   start[1];
+    hsize_t   count[1];
+    hsize_t   dset_dims[1];
+    size_t    target_size;
+    hid_t     file_id   = H5I_INVALID_HID;
+    hid_t     fapl_id   = H5I_INVALID_HID;
+    hid_t     dset_id   = H5I_INVALID_HID;
+    hid_t     dxpl_id   = H5I_INVALID_HID;
+    hid_t     fspace_id = H5I_INVALID_HID;
+    void     *buf       = NULL;
+    int       skip_test = 0;
+#endif
 
     curr_nerrors = nerrors;
 
+    dxpl_id = H5Pcreate(H5P_DATASET_XFER);
+    VRFY((dxpl_id >= 0), "DXPL creation succeeded");
+
+    /* Set selection I/O mode on DXPL */
+    VRFY((H5Pset_selection_io(dxpl_id, H5D_SELECTION_IO_MODE_ON) >= 0), "H5Pset_selection_io succeeded");
+
     if (MAINPROCESS)
         TESTING_2("h5fuse utility");
 
@@ -1569,6 +1814,22 @@ test_subfiling_h5fuse(void)
     file_id = H5Fcreate(SUBF_FILENAME, H5F_ACC_TRUNC, H5P_DEFAULT, fapl_id);
     VRFY((file_id >= 0), "H5Fcreate succeeded");
 
+    /*
+     * Retrieve the HDF5 file's inode number before operating on
+     * it, since it might change after fusing
+     */
+    HDcompile_assert(sizeof(uint64_t) >= sizeof(ino_t));
+    if (MAINPROCESS) {
+        VRFY((HDstat(SUBF_FILENAME, &file_info) >= 0), "HDstat succeeded");
+
+        file_inode = (uint64_t)file_info.st_ino;
+    }
+
+    if (mpi_size > 1) {
+        mpi_code_g = MPI_Bcast(&file_inode, 1, MPI_UINT64_T, 0, comm_g);
+        VRFY((mpi_code_g == MPI_SUCCESS), "MPI_Bcast succeeded");
+    }
+
     /* Calculate target size for dataset to stripe it across available IOCs */
     target_size = (stripe_size_g > 0) ? (size_t)stripe_size_g : H5FD_SUBFILING_DEFAULT_STRIPE_SIZE;
 
@@ -1607,7 +1868,7 @@ test_subfiling_h5fuse(void)
     for (size_t i = 0; i < count[0]; i++)
         ((SUBF_C_TYPE *)buf)[i] = (SUBF_C_TYPE)((size_t)mpi_rank + i);
 
-    VRFY((H5Dwrite(dset_id, SUBF_HDF5_TYPE, H5S_BLOCK, fspace_id, H5P_DEFAULT, buf) >= 0),
+    VRFY((H5Dwrite(dset_id, SUBF_HDF5_TYPE, H5S_BLOCK, fspace_id, dxpl_id, buf) >= 0),
          "Dataset write succeeded");
 
     HDfree(buf);
@@ -1618,33 +1879,31 @@ test_subfiling_h5fuse(void)
     VRFY((H5Fclose(file_id) >= 0), "File close succeeded");
 
     if (MAINPROCESS) {
-        h5_stat_t file_info;
-        pid_t     pid = 0;
-        pid_t     tmppid;
-        int       status;
+        pid_t pid = 0;
+        pid_t tmppid;
+        int   status;
 
         pid = HDfork();
         VRFY(pid >= 0, "HDfork succeeded");
 
         if (pid == 0) {
             char *tmp_filename;
-            char *args[6];
+            char *args[7];
 
             tmp_filename = HDmalloc(PATH_MAX);
             VRFY(tmp_filename, "HDmalloc succeeded");
 
-            VRFY((HDstat(SUBF_FILENAME, &file_info) >= 0), "HDstat succeeded");
-
             /* Generate name for configuration file */
-            HDsnprintf(tmp_filename, PATH_MAX, H5FD_SUBFILING_CONFIG_FILENAME_TEMPLATE, SUBF_FILENAME,
-                       (uint64_t)file_info.st_ino);
+            HDsnprintf(tmp_filename, PATH_MAX, "%s/" H5FD_SUBFILING_CONFIG_FILENAME_TEMPLATE, config_dir,
+                       SUBF_FILENAME, file_inode);
 
             args[0] = HDstrdup("env");
             args[1] = HDstrdup("sh");
             args[2] = HDstrdup("h5fuse.sh");
-            args[3] = HDstrdup("-f");
-            args[4] = tmp_filename;
-            args[5] = NULL;
+            args[3] = HDstrdup("-q");
+            args[4] = HDstrdup("-f");
+            args[5] = tmp_filename;
+            args[6] = NULL;
 
             /* Call h5fuse script from MPI rank 0 */
             HDexecvp("env", args);
@@ -1683,7 +1942,7 @@ test_subfiling_h5fuse(void)
         buf = HDcalloc(1, target_size);
         VRFY(buf, "HDcalloc succeeded");
 
-        VRFY((H5Dread(dset_id, SUBF_HDF5_TYPE, H5S_BLOCK, H5S_ALL, H5P_DEFAULT, buf) >= 0),
+        VRFY((H5Dread(dset_id, SUBF_HDF5_TYPE, H5S_BLOCK, H5S_ALL, dxpl_id, buf) >= 0),
              "Dataset read succeeded");
 
         for (size_t i = 0; i < (size_t)mpi_size; i++) {
@@ -1704,13 +1963,59 @@ test_subfiling_h5fuse(void)
     mpi_code_g = MPI_Barrier(comm_g);
     VRFY((mpi_code_g == MPI_SUCCESS), "MPI_Barrier succeeded");
 
-    H5E_BEGIN_TRY
-    {
-        H5Fdelete(SUBF_FILENAME, fapl_id);
+    /*
+     * Since we've now fused the file back together, the Subfiling
+     * VFD will no longer be able to work with it. The main HDF5
+     * file should be able to be deleted using the sec2 VFD, but we
+     * have to delete the extra files manually.
+     */
+    if (MAINPROCESS) {
+        char *filename_buf;
+        int   num_subfiles = num_iocs_g;
+        int   num_digits   = (int)(HDlog10(num_subfiles) + 1);
+
+        /* Delete the regular HDF5 file */
+        H5Pset_fapl_sec2(fapl_id);
+
+        H5E_BEGIN_TRY
+        {
+            H5Fdelete(SUBF_FILENAME, fapl_id);
+        }
+        H5E_END_TRY;
+
+        filename_buf = HDmalloc(PATH_MAX);
+        VRFY(filename_buf, "HDmalloc succeeded");
+
+        /* Generate name for configuration file */
+        HDsnprintf(filename_buf, PATH_MAX, "%s/" H5FD_SUBFILING_CONFIG_FILENAME_TEMPLATE, config_dir,
+                   SUBF_FILENAME, file_inode);
+
+        /* Delete the configuration file */
+        if (HDremove(filename_buf) < 0) {
+            HDprintf("couldn't remove Subfiling VFD configuration file '%s'\n", filename_buf);
+            nerrors++;
+        }
+
+        for (int i = 0; i < num_subfiles; i++) {
+            /* Generate name for each subfile */
+            HDsnprintf(filename_buf, PATH_MAX, H5FD_SUBFILING_FILENAME_TEMPLATE, SUBF_FILENAME, file_inode,
+                       num_digits, i + 1, num_subfiles);
+
+            /* Delete the subfile */
+            if (HDremove(filename_buf) < 0) {
+                HDprintf("couldn't remove subfile '%s'\n", filename_buf);
+                nerrors++;
+            }
+        }
+
+        HDfree(filename_buf);
     }
-    H5E_END_TRY;
 
     VRFY((H5Pclose(fapl_id) >= 0), "FAPL close succeeded");
+    VRFY((H5Pclose(dxpl_id) >= 0), "DXPL close succeeded");
+
+    mpi_code_g = MPI_Barrier(comm_g);
+    VRFY((mpi_code_g == MPI_SUCCESS), "MPI_Barrier succeeded");
 
     CHECK_PASSED();
 #else
@@ -1751,14 +2056,33 @@ parse_subfiling_env_vars(void)
         if (ioc_thread_pool_size_g <= 0)
             ioc_thread_pool_size_g = -1;
     }
+
+    if (NULL != (env_value = HDgetenv(H5FD_SUBFILING_CONFIG_FILE_PREFIX))) {
+        HDassert(config_dir);
+
+        HDstrncpy(config_dir, env_value, PATH_MAX);
+
+        /* Just in case.. */
+        config_dir[PATH_MAX - 1] = '\0';
+
+        if (*config_dir == '\0') {
+            *config_dir       = '.';
+            *(config_dir + 1) = '\0';
+        }
+    }
 }
 
 int
 main(int argc, char **argv)
 {
     unsigned seed;
-    int      required = MPI_THREAD_MULTIPLE;
-    int      provided = 0;
+    hbool_t  must_unset_stripe_size_env      = FALSE;
+    hbool_t  must_unset_ioc_per_node_env     = FALSE;
+    hbool_t  must_unset_ioc_thread_count_env = FALSE;
+    hbool_t  must_unset_config_dir_env       = FALSE;
+    char    *env_value                       = NULL;
+    int      required                        = MPI_THREAD_MULTIPLE;
+    int      provided                        = 0;
 
     HDcompile_assert(SUBFILING_MIN_STRIPE_SIZE <= H5FD_SUBFILING_DEFAULT_STRIPE_SIZE);
 
@@ -1852,9 +2176,6 @@ main(int argc, char **argv)
 
     H5open();
 
-    /* Enable selection I/O using internal temporary workaround */
-    H5_use_selection_io_g = TRUE;
-
     if (MAINPROCESS) {
         HDprintf("Testing Subfiling VFD functionality\n");
     }
@@ -1885,6 +2206,18 @@ main(int argc, char **argv)
     if (MAINPROCESS)
         HDprintf("Using seed: %u\n\n", seed);
 
+    /* Allocate buffer for possible config file directory specified */
+    config_dir = HDmalloc(PATH_MAX);
+    if (!config_dir) {
+        if (MAINPROCESS)
+            HDprintf("couldn't allocate space for subfiling config file directory buffer\n");
+        nerrors++;
+        goto exit;
+    }
+
+    /* Initialize to current working directory for now */
+    HDsnprintf(config_dir, PATH_MAX, ".");
+
     /* Grab values from environment variables if set */
     parse_subfiling_env_vars();
 
@@ -1942,6 +2275,8 @@ main(int argc, char **argv)
             nerrors++;
             goto exit;
         }
+
+        must_unset_stripe_size_env = TRUE;
     }
     if (ioc_per_node_g < 0) {
         const char *ioc_per_node_str;
@@ -1957,6 +2292,8 @@ main(int argc, char **argv)
             nerrors++;
             goto exit;
         }
+
+        must_unset_ioc_per_node_env = TRUE;
     }
     if (ioc_thread_pool_size_g < 0) {
         if (HDsetenv(H5FD_IOC_THREAD_POOL_SIZE, "2", 1) < 0) {
@@ -1965,6 +2302,61 @@ main(int argc, char **argv)
             nerrors++;
             goto exit;
         }
+
+        must_unset_ioc_thread_count_env = TRUE;
+    }
+
+    if (!(env_value = HDgetenv(H5FD_SUBFILING_CONFIG_FILE_PREFIX))) {
+        int rand_value = 0;
+
+        if (MAINPROCESS)
+            rand_value = rand() % 2;
+
+        mpi_code_g = MPI_Bcast(&rand_value, 1, MPI_INT, 0, comm_g);
+        VRFY((mpi_code_g == MPI_SUCCESS), "MPI_Bcast succeeded");
+
+        /* Randomly set config file prefix to either "." or a real
+         * directory to test both cases
+         */
+        if (rand_value == 0) {
+            int mkdir_success = 0;
+
+            if (MAINPROCESS) {
+                if ((HDmkdir(SUBFILING_CONFIG_FILE_DIR, (mode_t)0755) < 0) && (errno != EEXIST)) {
+                    HDprintf("couldn't create temporary testing directory\n");
+                    mkdir_success = 0;
+                }
+                else
+                    mkdir_success = 1;
+            }
+
+            mpi_code_g = MPI_Bcast(&mkdir_success, 1, MPI_INT, 0, comm_g);
+            VRFY((mpi_code_g == MPI_SUCCESS), "MPI_Bcast succeeded");
+
+            if (!mkdir_success) {
+                if (MAINPROCESS)
+                    HDprintf("HDmkdir failed\n");
+                nerrors++;
+                goto exit;
+            }
+
+            if (HDsetenv(H5FD_SUBFILING_CONFIG_FILE_PREFIX, SUBFILING_CONFIG_FILE_DIR, 1) < 0) {
+                if (MAINPROCESS)
+                    HDprintf("HDsetenv failed\n");
+                nerrors++;
+                goto exit;
+            }
+        }
+        else {
+            if (HDsetenv(H5FD_SUBFILING_CONFIG_FILE_PREFIX, ".", 1) < 0) {
+                if (MAINPROCESS)
+                    HDprintf("HDsetenv failed\n");
+                nerrors++;
+                goto exit;
+            }
+        }
+
+        must_unset_config_dir_env = TRUE;
     }
 
     /* Grab values from environment variables */
@@ -2004,6 +2396,22 @@ main(int argc, char **argv)
         HDputs("All Subfiling VFD tests passed\n");
 
 exit:
+    if (must_unset_stripe_size_env)
+        HDunsetenv(H5FD_SUBFILING_STRIPE_SIZE);
+    if (must_unset_ioc_per_node_env)
+        HDunsetenv(H5FD_SUBFILING_IOC_PER_NODE);
+    if (must_unset_ioc_thread_count_env)
+        HDunsetenv(H5FD_IOC_THREAD_POOL_SIZE);
+    if (must_unset_config_dir_env)
+        HDunsetenv(H5FD_SUBFILING_CONFIG_FILE_PREFIX);
+
+    if (MAINPROCESS) {
+        if (HDrmdir(SUBFILING_CONFIG_FILE_DIR) < 0 && (errno != ENOENT)) {
+            HDprintf("couldn't remove temporary testing directory\n");
+            nerrors++;
+        }
+    }
+
     if (nerrors) {
         if (MAINPROCESS)
             HDprintf("*** %d TEST ERROR%s OCCURRED ***\n", nerrors, nerrors > 1 ? "S" : "");
