@@ -502,6 +502,8 @@ main(int argc, char **argv)
             "Collective MD read with multi chunk I/O (H5D__chunk_addrmap)", PARATESTFILE);
     AddTest("LC_coll_MD_read", test_link_chunk_io_sort_chunk_issue, NULL,
             "Collective MD read with link chunk I/O (H5D__sort_chunk)", PARATESTFILE);
+    AddTest("GH_coll_MD_wr", test_collective_global_heap_write, NULL,
+            "Collective MD write of global heap data", PARATESTFILE);
 
     /* Display testing information */
     TestInfo(argv[0]);
