@@ -1,6 +1,5 @@
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
  * Copyright by The HDF Group.                                               *
- * Copyright by the Board of Trustees of the University of Illinois.         *
  * All rights reserved.                                                      *
  *                                                                           *
  * This file is part of HDF5.  The full HDF5 copyright notice, including     *
@@ -31,44 +30,61 @@ const char *outfile = NULL;
  * Command-line options: The user can specify short or long-named
  * parameters.
  */
-static const char *        s_opts   = "a:b:c:d:e:f:hi:j:k:l:m:no:q:s:t:u:v*z:E*G:LM:P:S:T:VXW";
-static struct long_options l_opts[] = {{"alignment", require_arg, 'a'},
-                                       {"block", require_arg, 'b'},
-                                       {"compact", require_arg, 'c'},
-                                       {"indexed", require_arg, 'd'},
-                                       {"file", require_arg, 'e'},
-                                       {"filter", require_arg, 'f'},
-                                       {"help", no_arg, 'h'},
-                                       {"infile", require_arg, 'i'}, /* for backward compatibility */
-                                       {"low", require_arg, 'j'},
-                                       {"high", require_arg, 'k'},
-                                       {"layout", require_arg, 'l'},
-                                       {"minimum", require_arg, 'm'},
-                                       {"native", no_arg, 'n'},
-                                       {"outfile", require_arg, 'o'}, /* for backward compatibility */
-                                       {"sort_by", require_arg, 'q'},
-                                       {"ssize", require_arg, 's'},
-                                       {"threshold", require_arg, 't'},
-                                       {"ublock", require_arg, 'u'},
-                                       {"verbose", optional_arg, 'v'},
-                                       {"sort_order", require_arg, 'z'},
-                                       {"enable-error-stack", optional_arg, 'E'},
-                                       {"fs_pagesize", require_arg, 'G'},
-                                       {"latest", no_arg, 'L'},
-                                       {"metadata_block_size", require_arg, 'M'},
-                                       {"fs_persist", require_arg, 'P'},
-                                       {"fs_strategy", require_arg, 'S'},
-                                       {"fs_threshold", require_arg, 'T'},
-                                       {"version", no_arg, 'V'},
-                                       {"merge", no_arg, 'X'},
-                                       {"prune", no_arg, 'W'},
-                                       {"src-vol-value", require_arg, '1'},
-                                       {"src-vol-name", require_arg, '2'},
-                                       {"src-vol-info", require_arg, '3'},
-                                       {"dst-vol-value", require_arg, '4'},
-                                       {"dst-vol-name", require_arg, '5'},
-                                       {"dst-vol-info", require_arg, '6'},
-                                       {NULL, 0, '\0'}};
+static const char *s_opts = "a:b:c:d:e:f:hi:j:k:l:m:no:q:s:t:u:v*z:E*G:LM:P:S:T:VXWY:Z:1:2:3:4:5:6:7:8:9:0:";
+static struct h5_long_options l_opts[] = {{"alignment", require_arg, 'a'},
+                                          {"block", require_arg, 'b'},
+                                          {"compact", require_arg, 'c'},
+                                          {"indexed", require_arg, 'd'},
+                                          {"file", require_arg, 'e'},
+                                          {"filter", require_arg, 'f'},
+                                          {"help", no_arg, 'h'},
+                                          {"infile", require_arg, 'i'}, /* for backward compatibility */
+                                          {"low", require_arg, 'j'},
+                                          {"high", require_arg, 'k'},
+                                          {"layout", require_arg, 'l'},
+                                          {"minimum", require_arg, 'm'},
+                                          {"native", no_arg, 'n'},
+                                          {"outfile", require_arg, 'o'}, /* for backward compatibility */
+                                          {"sort_by", require_arg, 'q'},
+                                          {"ssize", require_arg, 's'},
+                                          {"threshold", require_arg, 't'},
+                                          {"ublock", require_arg, 'u'},
+                                          {"verbose", optional_arg, 'v'},
+                                          {"sort_order", require_arg, 'z'},
+                                          {"enable-error-stack", optional_arg, 'E'},
+                                          {"fs_pagesize", require_arg, 'G'},
+                                          {"latest", no_arg, 'L'},
+                                          {"metadata_block_size", require_arg, 'M'},
+                                          {"fs_persist", require_arg, 'P'},
+                                          {"fs_strategy", require_arg, 'S'},
+                                          {"fs_threshold", require_arg, 'T'},
+                                          {"version", no_arg, 'V'},
+                                          {"merge", no_arg, 'X'},
+                                          {"prune", no_arg, 'W'},
+                                          {"src-vol-value", require_arg, '1'},
+                                          {"src-vol-name", require_arg, '2'},
+                                          {"src-vol-info", require_arg, '3'},
+                                          {"dst-vol-value", require_arg, '4'},
+                                          {"dst-vol-name", require_arg, '5'},
+                                          {"dst-vol-info", require_arg, '6'},
+                                          {"src-vfd-value", require_arg, '7'},
+                                          {"src-vfd-name", require_arg, '8'},
+                                          {"src-vfd-info", require_arg, '9'},
+                                          {"dst-vfd-value", require_arg, '0'},
+                                          {"dst-vfd-name", require_arg, 'Y'},
+                                          {"dst-vfd-info", require_arg, 'Z'},
+                                          {NULL, 0, '\0'}};
+
+static H5FD_onion_fapl_info_t onion_fa_in_g = {
+    H5FD_ONION_FAPL_INFO_VERSION_CURR,
+    H5P_DEFAULT,                   /* backing_fapl_id                */
+    32,                            /* page_size                      */
+    H5FD_ONION_STORE_TARGET_ONION, /* store_target                   */
+    H5FD_ONION_FAPL_INFO_REVISION_ID_LATEST,
+    0,            /* force_write_open               */
+    0,            /* creation_flags                 */
+    "input file", /* comment                        */
+};
 
 /*-------------------------------------------------------------------------
  * Function: usage
@@ -115,6 +131,24 @@ usage(const char *prog)
     PRINTVALSTREAM(rawoutstream,
                    "   --dst-vol-info          VOL-specific info to pass to the VOL connector used for\n");
     PRINTVALSTREAM(rawoutstream, "                           opening the output HDF5 file specified\n");
+    PRINTVALSTREAM(rawoutstream,
+                   "   --src-vfd-value         Value (ID) of the VFL driver to use for opening the\n");
+    PRINTVALSTREAM(rawoutstream, "                           input HDF5 file specified\n");
+    PRINTVALSTREAM(rawoutstream,
+                   "   --src-vfd-name          Name of the VFL driver to use for opening the input\n");
+    PRINTVALSTREAM(rawoutstream, "                           HDF5 file specified\n");
+    PRINTVALSTREAM(rawoutstream,
+                   "   --src-vfd-info          VFD-specific info to pass to the VFL driver used for\n");
+    PRINTVALSTREAM(rawoutstream, "                           opening the input HDF5 file specified\n");
+    PRINTVALSTREAM(rawoutstream,
+                   "   --dst-vfd-value         Value (ID) of the VFL driver to use for opening the\n");
+    PRINTVALSTREAM(rawoutstream, "                           output HDF5 file specified\n");
+    PRINTVALSTREAM(rawoutstream,
+                   "   --dst-vfd-name          Name of the VFL driver to use for opening the output\n");
+    PRINTVALSTREAM(rawoutstream, "                           HDF5 file specified\n");
+    PRINTVALSTREAM(rawoutstream,
+                   "   --dst-vfd-info          VFD-specific info to pass to the VFL driver used for\n");
+    PRINTVALSTREAM(rawoutstream, "                           opening the output HDF5 file specified\n");
     PRINTVALSTREAM(rawoutstream, "   -L, --latest            Use latest version of file format\n");
     PRINTVALSTREAM(rawoutstream,
                    "                           This option will take precedence over the options\n");
@@ -489,29 +523,35 @@ parse_command_line(int argc, const char *const *argv, pack_opt_t *options)
 {
     h5tools_vol_info_t in_vol_info;
     h5tools_vol_info_t out_vol_info;
-    hbool_t            custom_in_fapl  = FALSE;
-    hbool_t            custom_out_fapl = FALSE;
-    hid_t              tmp_fapl        = H5I_INVALID_HID;
+    h5tools_vfd_info_t in_vfd_info;
+    h5tools_vfd_info_t out_vfd_info;
+    hbool_t            custom_in_vol  = FALSE;
+    hbool_t            custom_in_vfd  = FALSE;
+    hbool_t            custom_out_vol = FALSE;
+    hbool_t            custom_out_vfd = FALSE;
+    hid_t              tmp_fapl       = H5I_INVALID_HID;
     int                bound, opt;
     int                ret_value = 0;
 
     /* Initialize fapl info structs */
     HDmemset(&in_vol_info, 0, sizeof(h5tools_vol_info_t));
     HDmemset(&out_vol_info, 0, sizeof(h5tools_vol_info_t));
+    HDmemset(&in_vfd_info, 0, sizeof(h5tools_vfd_info_t));
+    HDmemset(&out_vfd_info, 0, sizeof(h5tools_vfd_info_t));
 
     /* parse command line options */
-    while (EOF != (opt = get_option(argc, argv, s_opts, l_opts))) {
+    while (EOF != (opt = H5_get_option(argc, argv, s_opts, l_opts))) {
         switch ((char)opt) {
 
             /* -i for backward compatibility */
             case 'i':
-                infile = opt_arg;
+                infile = H5_optarg;
                 has_i++;
                 break;
 
             /* -o for backward compatibility */
             case 'o':
-                outfile = opt_arg;
+                outfile = H5_optarg;
                 has_o++;
                 break;
 
@@ -528,8 +568,8 @@ parse_command_line(int argc, const char *const *argv, pack_opt_t *options)
                 goto done;
 
             case 'v':
-                if (opt_arg != NULL) {
-                    if (2 == HDatoi(opt_arg))
+                if (H5_optarg != NULL) {
+                    if (2 == HDatoi(H5_optarg))
                         options->verbose = 2;
                 }
                 else
@@ -538,7 +578,7 @@ parse_command_line(int argc, const char *const *argv, pack_opt_t *options)
 
             case 'f':
                 /* parse the -f filter option */
-                if (h5repack_addfilter(opt_arg, options) < 0) {
+                if (h5repack_addfilter(H5_optarg, options) < 0) {
                     error_msg("in parsing filter\n");
                     h5tools_setstatus(EXIT_FAILURE);
                     ret_value = -1;
@@ -548,7 +588,7 @@ parse_command_line(int argc, const char *const *argv, pack_opt_t *options)
 
             case 'l':
                 /* parse the -l layout option */
-                if (h5repack_addlayout(opt_arg, options) < 0) {
+                if (h5repack_addlayout(H5_optarg, options) < 0) {
                     error_msg("in parsing layout\n");
                     h5tools_setstatus(EXIT_FAILURE);
                     ret_value = -1;
@@ -557,9 +597,9 @@ parse_command_line(int argc, const char *const *argv, pack_opt_t *options)
                 break;
 
             case 'm':
-                options->min_comp = HDstrtoull(opt_arg, NULL, 0);
+                options->min_comp = HDstrtoull(H5_optarg, NULL, 0);
                 if ((int)options->min_comp <= 0) {
-                    error_msg("invalid minimum compress size <%s>\n", opt_arg);
+                    error_msg("invalid minimum compress size <%s>\n", H5_optarg);
                     h5tools_setstatus(EXIT_FAILURE);
                     ret_value = -1;
                     goto done;
@@ -567,8 +607,8 @@ parse_command_line(int argc, const char *const *argv, pack_opt_t *options)
                 break;
 
             case 'e':
-                if ((ret_value = read_info(opt_arg, options)) < 0) {
-                    error_msg("failed to read from repack options file <%s>\n", opt_arg);
+                if ((ret_value = read_info(H5_optarg, options)) < 0) {
+                    error_msg("failed to read from repack options file <%s>\n", H5_optarg);
                     h5tools_setstatus(EXIT_FAILURE);
                     ret_value = -1;
                     goto done;
@@ -584,7 +624,7 @@ parse_command_line(int argc, const char *const *argv, pack_opt_t *options)
                 break;
 
             case 'j':
-                bound = HDatoi(opt_arg);
+                bound = HDatoi(H5_optarg);
                 if (bound < H5F_LIBVER_EARLIEST || bound > H5F_LIBVER_LATEST) {
                     error_msg("in parsing low bound\n");
                     h5tools_setstatus(EXIT_FAILURE);
@@ -595,7 +635,7 @@ parse_command_line(int argc, const char *const *argv, pack_opt_t *options)
                 break;
 
             case 'k':
-                bound = HDatoi(opt_arg);
+                bound = HDatoi(H5_optarg);
                 if (bound < H5F_LIBVER_EARLIEST || bound > H5F_LIBVER_LATEST) {
                     error_msg("in parsing high bound\n");
                     h5tools_setstatus(EXIT_FAILURE);
@@ -614,13 +654,13 @@ parse_command_line(int argc, const char *const *argv, pack_opt_t *options)
                 break;
 
             case 'c':
-                options->grp_compact = HDatoi(opt_arg);
+                options->grp_compact = HDatoi(H5_optarg);
                 if (options->grp_compact > 0)
                     options->latest = TRUE; /* must use latest format */
                 break;
 
             case 'd':
-                options->grp_indexed = HDatoi(opt_arg);
+                options->grp_indexed = HDatoi(H5_optarg);
                 if (options->grp_indexed > 0)
                     options->latest = TRUE; /* must use latest format */
                 break;
@@ -628,10 +668,10 @@ parse_command_line(int argc, const char *const *argv, pack_opt_t *options)
             case 's': {
                 int   idx       = 0;
                 int   ssize     = 0;
-                char *msgPtr    = HDstrchr(opt_arg, ':');
+                char *msgPtr    = HDstrchr(H5_optarg, ':');
                 options->latest = TRUE; /* must use latest format */
                 if (msgPtr == NULL) {
-                    ssize = HDatoi(opt_arg);
+                    ssize = HDatoi(H5_optarg);
                     for (idx = 0; idx < 5; idx++)
                         options->msg_size[idx] = ssize;
                 }
@@ -640,7 +680,7 @@ parse_command_line(int argc, const char *const *argv, pack_opt_t *options)
 
                     HDstrcpy(msgType, msgPtr + 1);
                     msgPtr[0] = '\0';
-                    ssize     = HDatoi(opt_arg);
+                    ssize     = HDatoi(H5_optarg);
                     if (!HDstrncmp(msgType, "dspace", 6))
                         options->msg_size[0] = ssize;
                     else if (!HDstrncmp(msgType, "dtype", 5))
@@ -655,25 +695,25 @@ parse_command_line(int argc, const char *const *argv, pack_opt_t *options)
             } break;
 
             case 'u':
-                options->ublock_filename = opt_arg;
+                options->ublock_filename = H5_optarg;
                 break;
 
             case 'b':
-                options->ublock_size = (hsize_t)HDatol(opt_arg);
+                options->ublock_size = (hsize_t)HDatol(H5_optarg);
                 break;
 
             case 'M':
-                options->meta_block_size = (hsize_t)HDatol(opt_arg);
+                options->meta_block_size = (hsize_t)HDatol(H5_optarg);
                 break;
 
             case 't':
-                options->threshold = (hsize_t)HDatol(opt_arg);
+                options->threshold = (hsize_t)HDatol(H5_optarg);
                 break;
 
             case 'a':
-                options->alignment = HDstrtoull(opt_arg, NULL, 0);
+                options->alignment = HDstrtoull(H5_optarg, NULL, 0);
                 if (options->alignment < 1) {
-                    error_msg("invalid alignment size\n", opt_arg);
+                    error_msg("invalid alignment size `%s`\n", H5_optarg);
                     h5tools_setstatus(EXIT_FAILURE);
                     ret_value = -1;
                     goto done;
@@ -683,7 +723,7 @@ parse_command_line(int argc, const char *const *argv, pack_opt_t *options)
             case 'S': {
                 char strategy[MAX_NC_NAME];
 
-                HDstrcpy(strategy, opt_arg);
+                HDstrcpy(strategy, H5_optarg);
                 if (!HDstrcmp(strategy, "FSM_AGGR"))
                     options->fs_strategy = H5F_FSPACE_STRATEGY_FSM_AGGR;
                 else if (!HDstrcmp(strategy, "PAGE"))
@@ -693,7 +733,7 @@ parse_command_line(int argc, const char *const *argv, pack_opt_t *options)
                 else if (!HDstrcmp(strategy, "NONE"))
                     options->fs_strategy = H5F_FSPACE_STRATEGY_NONE;
                 else {
-                    error_msg("invalid file space management strategy\n", opt_arg);
+                    error_msg("invalid file space management strategy `%s`\n", H5_optarg);
                     h5tools_setstatus(EXIT_FAILURE);
                     ret_value = -1;
                     goto done;
@@ -704,29 +744,29 @@ parse_command_line(int argc, const char *const *argv, pack_opt_t *options)
             } break;
 
             case 'P':
-                options->fs_persist = HDatoi(opt_arg);
+                options->fs_persist = HDatoi(H5_optarg);
                 if (options->fs_persist == 0)
                     /* To distinguish the "specified" zero value */
                     options->fs_persist = -1;
                 break;
 
             case 'T':
-                options->fs_threshold = HDatol(opt_arg);
+                options->fs_threshold = HDatol(H5_optarg);
                 if (options->fs_threshold == 0)
                     /* To distinguish the "specified" zero value */
                     options->fs_threshold = -1;
                 break;
 
             case 'G':
-                options->fs_pagesize = HDstrtoll(opt_arg, NULL, 0);
+                options->fs_pagesize = HDstrtoll(H5_optarg, NULL, 0);
                 if (options->fs_pagesize == 0)
                     /* To distinguish the "specified" zero value */
                     options->fs_pagesize = -1;
                 break;
 
             case 'q':
-                if (H5_INDEX_UNKNOWN == (sort_by = set_sort_by(opt_arg))) {
-                    error_msg("failed to set sort by form <%s>\n", opt_arg);
+                if (H5_INDEX_UNKNOWN == (sort_by = set_sort_by(H5_optarg))) {
+                    error_msg("failed to set sort by form <%s>\n", H5_optarg);
                     h5tools_setstatus(EXIT_FAILURE);
                     ret_value = -1;
                     goto done;
@@ -734,8 +774,8 @@ parse_command_line(int argc, const char *const *argv, pack_opt_t *options)
                 break;
 
             case 'z':
-                if (H5_ITER_UNKNOWN == (sort_order = set_sort_order(opt_arg))) {
-                    error_msg("failed to set sort order form <%s>\n", opt_arg);
+                if (H5_ITER_UNKNOWN == (sort_order = set_sort_order(H5_optarg))) {
+                    error_msg("failed to set sort order form <%s>\n", H5_optarg);
                     h5tools_setstatus(EXIT_FAILURE);
                     ret_value = -1;
                     goto done;
@@ -743,42 +783,74 @@ parse_command_line(int argc, const char *const *argv, pack_opt_t *options)
                 break;
 
             case 'E':
-                if (opt_arg != NULL)
-                    enable_error_stack = HDatoi(opt_arg);
+                if (H5_optarg != NULL)
+                    enable_error_stack = HDatoi(H5_optarg);
                 else
                     enable_error_stack = 1;
                 break;
 
             case '1':
                 in_vol_info.type    = VOL_BY_VALUE;
-                in_vol_info.u.value = (H5VL_class_value_t)HDatoi(opt_arg);
-                custom_in_fapl      = TRUE;
+                in_vol_info.u.value = (H5VL_class_value_t)HDatoi(H5_optarg);
+                custom_in_vol       = TRUE;
                 break;
 
             case '2':
                 in_vol_info.type   = VOL_BY_NAME;
-                in_vol_info.u.name = opt_arg;
-                custom_in_fapl     = TRUE;
+                in_vol_info.u.name = H5_optarg;
+                custom_in_vol      = TRUE;
                 break;
 
             case '3':
-                in_vol_info.info_string = opt_arg;
+                in_vol_info.info_string = H5_optarg;
                 break;
 
             case '4':
                 out_vol_info.type    = VOL_BY_VALUE;
-                out_vol_info.u.value = (H5VL_class_value_t)HDatoi(opt_arg);
-                custom_out_fapl      = TRUE;
+                out_vol_info.u.value = (H5VL_class_value_t)HDatoi(H5_optarg);
+                custom_out_vol       = TRUE;
                 break;
 
             case '5':
                 out_vol_info.type   = VOL_BY_NAME;
-                out_vol_info.u.name = opt_arg;
-                custom_out_fapl     = TRUE;
+                out_vol_info.u.name = H5_optarg;
+                custom_out_vol      = TRUE;
                 break;
 
             case '6':
-                out_vol_info.info_string = opt_arg;
+                out_vol_info.info_string = H5_optarg;
+                break;
+
+            case '7':
+                in_vfd_info.type    = VFD_BY_VALUE;
+                in_vfd_info.u.value = (H5FD_class_value_t)HDatoi(H5_optarg);
+                custom_in_vfd       = TRUE;
+                break;
+
+            case '8':
+                in_vfd_info.type   = VFD_BY_NAME;
+                in_vfd_info.u.name = H5_optarg;
+                custom_in_vfd      = TRUE;
+                break;
+
+            case '9':
+                in_vfd_info.info = (const void *)H5_optarg;
+                break;
+
+            case '0':
+                out_vfd_info.type    = VFD_BY_VALUE;
+                out_vfd_info.u.value = (H5FD_class_value_t)HDatoi(H5_optarg);
+                custom_out_vfd       = TRUE;
+                break;
+
+            case 'Y':
+                out_vfd_info.type   = VFD_BY_NAME;
+                out_vfd_info.u.name = H5_optarg;
+                custom_out_vfd      = TRUE;
+                break;
+
+            case 'Z':
+                out_vfd_info.info = (const void *)H5_optarg;
                 break;
 
             default:
@@ -788,9 +860,9 @@ parse_command_line(int argc, const char *const *argv, pack_opt_t *options)
 
     /* If neither -i nor -o given, get in and out files positionally */
     if (0 == (has_i + has_o)) {
-        if (argv[opt_ind] != NULL && argv[opt_ind + 1] != NULL) {
-            infile  = argv[opt_ind];
-            outfile = argv[opt_ind + 1];
+        if (argv[H5_optind] != NULL && argv[H5_optind + 1] != NULL) {
+            infile  = argv[H5_optind];
+            outfile = argv[H5_optind + 1];
 
             if (!HDstrcmp(infile, outfile)) {
                 error_msg("file names cannot be the same\n");
@@ -813,9 +885,27 @@ parse_command_line(int argc, const char *const *argv, pack_opt_t *options)
         ret_value = -1;
     }
 
+    /* If the input file uses the onion VFD, get the revision number */
+    if (in_vfd_info.u.name && !HDstrcmp(in_vfd_info.u.name, "onion")) {
+        if (in_vfd_info.info) {
+            errno                      = 0;
+            onion_fa_in_g.revision_num = HDstrtoull(in_vfd_info.info, NULL, 10);
+            if (errno == ERANGE) {
+                HDprintf("Invalid onion revision specified for the input file\n");
+                usage(h5tools_getprogname());
+                exit(EXIT_FAILURE);
+            }
+        }
+        else
+            onion_fa_in_g.revision_num = 0;
+
+        in_vfd_info.info = &onion_fa_in_g;
+    }
+
     /* Setup FAPL for input and output file accesses */
-    if (custom_in_fapl) {
-        if ((tmp_fapl = h5tools_get_fapl(options->fin_fapl, &in_vol_info, NULL)) < 0) {
+    if (custom_in_vol || custom_in_vfd) {
+        if ((tmp_fapl = h5tools_get_fapl(options->fin_fapl, custom_in_vol ? &in_vol_info : NULL,
+                                         custom_in_vfd ? &in_vfd_info : NULL)) < 0) {
             error_msg("failed to setup FAPL for input file\n");
             h5tools_setstatus(EXIT_FAILURE);
             ret_value = -1;
@@ -834,8 +924,9 @@ parse_command_line(int argc, const char *const *argv, pack_opt_t *options)
         options->fin_fapl = tmp_fapl;
     }
 
-    if (custom_out_fapl) {
-        if ((tmp_fapl = h5tools_get_fapl(options->fout_fapl, &out_vol_info, NULL)) < 0) {
+    if (custom_out_vol || custom_out_vfd) {
+        if ((tmp_fapl = h5tools_get_fapl(options->fout_fapl, custom_out_vol ? &out_vol_info : NULL,
+                                         custom_out_vfd ? &out_vfd_info : NULL)) < 0) {
             error_msg("failed to setup FAPL for output file\n");
             h5tools_setstatus(EXIT_FAILURE);
             ret_value = -1;
