@@ -1,6 +1,5 @@
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
  * Copyright by The HDF Group.                                               *
- * Copyright by the Board of Trustees of the University of Illinois.         *
  * All rights reserved.                                                      *
  *                                                                           *
  * This file is part of HDF5.  The full HDF5 copyright notice, including     *
@@ -24,8 +23,8 @@
  * parameters. The long-named ones can be partially spelled. When
  * adding more, make sure that they don't clash with each other.
  */
-static const char *        s_opts   = "h";
-static struct long_options l_opts[] = {{"help", no_arg, 'h'}, {"hel", no_arg, 'h'}, {NULL, 0, '\0'}};
+static const char            *s_opts   = "h";
+static struct h5_long_options l_opts[] = {{"help", no_arg, 'h'}, {"hel", no_arg, 'h'}, {NULL, 0, '\0'}};
 
 /*-------------------------------------------------------------------------
  * Function:    usage
@@ -61,7 +60,7 @@ parse_command_line(int argc, const char *const *argv)
     int opt;
 
     /* parse command line options */
-    while ((opt = get_option(argc, argv, s_opts, l_opts)) != EOF) {
+    while ((opt = H5_get_option(argc, argv, s_opts, l_opts)) != EOF) {
         switch ((char)opt) {
             case 'h':
                 usage(h5tools_getprogname());
@@ -75,7 +74,7 @@ parse_command_line(int argc, const char *const *argv)
     }
 
     /* check for file name to be processed */
-    if (argc <= opt_ind) {
+    if (argc <= H5_optind) {
         error_msg("missing file name\n");
         usage(h5tools_getprogname());
         h5tools_setstatus(EXIT_FAILURE);
@@ -100,7 +99,7 @@ leave(int ret)
 int
 main(int argc, char *argv[])
 {
-    char *  ifname;
+    char   *ifname;
     hid_t   ifile = H5I_INVALID_HID;
     hsize_t usize;
     htri_t  testval;
@@ -118,14 +117,14 @@ main(int argc, char *argv[])
     /* enable error reporting if command line option */
     h5tools_error_report();
 
-    if (argc <= (opt_ind)) {
+    if (argc <= (H5_optind)) {
         error_msg("missing file name\n");
         usage(h5tools_getprogname());
         h5tools_setstatus(EXIT_FAILURE);
         goto done;
     }
 
-    ifname = HDstrdup(argv[opt_ind]);
+    ifname = HDstrdup(argv[H5_optind]);
 
     testval = H5Fis_accessible(ifname, H5P_DEFAULT);
 
